@@ -11,7 +11,20 @@ import {
   DroppableFileInput as BasicDroppableInput,
 } from '../../../public/components/cluster-settings/basicauth-idp-form';
 
-export const controlButtonTest = (wrapper: ShallowWrapper) => {
+jest.mock('react-i18next', () => {
+  const reactI18next = require.requireActual('react-i18next');
+  return {
+    ...reactI18next,
+    withTranslation: () => (Component) => {
+      Component.defaultProps = { ...Component.defaultProps, t: (s) => s };
+      return Component;
+    },
+  };
+});
+
+const i18nNS = 'public';
+
+export const controlButtonTest = (wrapper: ShallowWrapper, i18nNamespace) => {
   expect(wrapper.find(ButtonBar).exists()).toBe(true);
   expect(
     wrapper
@@ -19,14 +32,14 @@ export const controlButtonTest = (wrapper: ShallowWrapper) => {
       .at(0)
       .childAt(0)
       .text(),
-  ).toEqual('Add');
+  ).toEqual(`${i18nNamespace}~Add`);
   expect(
     wrapper
       .find(Button)
       .at(1)
       .childAt(0)
       .text(),
-  ).toEqual('Cancel');
+  ).toEqual(`${i18nNamespace}~Cancel`);
 };
 
 describe('Add Identity Provider: BasicAuthentication', () => {
@@ -41,7 +54,7 @@ describe('Add Identity Provider: BasicAuthentication', () => {
   });
 
   it('should render correct Basic Authentication IDP page title', () => {
-    expect(wrapper.contains('Add Identity Provider: Basic Authentication')).toBeTruthy();
+    expect(wrapper.contains(`${i18nNS}~Add Identity Provider: Basic Authentication`)).toBeTruthy();
   });
 
   it('should render the form elements of AddBasicAuthPage component', () => {
@@ -52,7 +65,7 @@ describe('Add Identity Provider: BasicAuthentication', () => {
   });
 
   it('should render control buttons in a button bar', () => {
-    controlButtonTest(wrapper);
+    controlButtonTest(wrapper, 'public');
   });
 
   it('should prefill basic-auth in name field by default', () => {
