@@ -1,21 +1,28 @@
 import * as React from 'react';
 import { shallow } from 'enzyme';
-import { DragDropContext } from 'react-dnd';
-import HTML5Backend from 'react-dnd-html5-backend';
-
 import { NameValueEditor } from '../../../public/components/utils/name-value-editor';
 
-describe(NameValueEditor.displayName, () => {
-  const Editor = DragDropContext(HTML5Backend)(NameValueEditor);
+jest.mock('react-i18next', () => {
+  const reactI18next = require.requireActual('react-i18next');
+  return {
+    ...reactI18next,
+    withTranslation: () => (Component) => {
+      Component.defaultProps = { ...Component.defaultProps, t: (s) => s };
+      return Component;
+    },
+  };
+});
 
+describe('Name Value Editor', () => {
   describe('When supplied with attributes nameString and valueString', () => {
     it('renders header correctly', () => {
       const wrapper = shallow(
-        <Editor
+        <NameValueEditor
           nameValuePairs={[['name', 'value', 0]]}
           updateParentData={() => {}}
           nameString={'foo'}
           valueString={'bar'}
+          t={(key) => key}
         />,
       );
 
@@ -27,7 +34,11 @@ describe(NameValueEditor.displayName, () => {
   describe('When supplied with nameValuePairs', () => {
     it('renders PairElement correctly', () => {
       const wrapper = shallow(
-        <Editor nameValuePairs={[['name', 'value', 0]]} updateParentData={() => {}} />,
+        <NameValueEditor
+          nameValuePairs={[['name', 'value', 0]]}
+          updateParentData={() => {}}
+          t={(key) => key}
+        />,
       );
 
       expect(wrapper.html()).toContain('value="name"');
@@ -38,10 +49,11 @@ describe(NameValueEditor.displayName, () => {
   describe('When readOnly attribute is "true"', () => {
     it('does not render add button', () => {
       const wrapper = shallow(
-        <Editor
+        <NameValueEditor
           nameValuePairs={[['name', 'value', 0]]}
           updateParentData={() => {}}
           readOnly={true}
+          t={(key) => key}
         />,
       );
 
@@ -50,10 +62,11 @@ describe(NameValueEditor.displayName, () => {
 
     it('does not render PairElement buttons', () => {
       const wrapper = shallow(
-        <Editor
+        <NameValueEditor
           nameValuePairs={[['name', 'value', 0]]}
           updateParentData={() => {}}
           readOnly={true}
+          t={(key) => key}
         />,
       );
       expect(wrapper.html()).not.toContain('pairs-list__delete-icon');
@@ -64,11 +77,12 @@ describe(NameValueEditor.displayName, () => {
   describe('When readOnly attribute is "false"', () => {
     it('renders add button', () => {
       const wrapper = shallow(
-        <Editor
+        <NameValueEditor
           nameValuePairs={[['name', 'value', 0]]}
           updateParentData={() => {}}
           readOnly={false}
           allowSorting={true}
+          t={(key) => key}
         />,
       );
 
@@ -79,11 +93,12 @@ describe(NameValueEditor.displayName, () => {
   describe('When readOnly attribute is "false" and allowSorting is "true"', () => {
     it('renders PairElement buttons correctly', () => {
       const wrapper = shallow(
-        <Editor
+        <NameValueEditor
           nameValuePairs={[['name', 'value', 0]]}
           updateParentData={() => {}}
           readOnly={false}
           allowSorting={true}
+          t={(key) => key}
         />,
       );
 
@@ -95,10 +110,11 @@ describe(NameValueEditor.displayName, () => {
   describe('When allowSorting attribute is "false"', () => {
     it('renders PairElement buttons correctly', () => {
       const wrapper = shallow(
-        <Editor
+        <NameValueEditor
           nameValuePairs={[['name', 'value', 0]]}
           updateParentData={() => {}}
           allowSorting={false}
+          t={(key) => key}
         />,
       );
       expect(wrapper.html()).toContain('pairs-list__delete-icon');
