@@ -47,7 +47,7 @@ describe('featureReducer', () => {
       configResources: [],
       namespacedSet: null,
       safeResources: [],
-      preferredVersions: [],
+      groupVersionMap: {},
     });
     const initialState = Immutable.Map(defaults);
     const newState = featureReducer(initialState, action);
@@ -61,10 +61,12 @@ describe('featureReducer', () => {
         [FLAGS.MACHINE_CONFIG]: false,
         [FLAGS.MACHINE_AUTOSCALER]: false,
         [FLAGS.MACHINE_HEALTH_CHECK]: false,
+        [FLAGS.CONSOLE_LINK]: false,
         [FLAGS.CONSOLE_CLI_DOWNLOAD]: false,
         [FLAGS.CONSOLE_NOTIFICATION]: false,
         [FLAGS.CONSOLE_EXTERNAL_LOG_LINK]: false,
         [FLAGS.CONSOLE_YAML_SAMPLE]: false,
+        [FLAGS.CLUSTER_AUTOSCALER]: false,
       }),
     );
   });
