@@ -164,15 +164,16 @@ export const verifyNodeOSDMapping = (
   return filteredOsds.length === 0;
 };
 
-export const hasTaints = (node) => {
-  return !_.isEmpty(node.spec?.taints);
-};
+export const hasNoTaints = (node) => _.isEmpty(node.spec?.taints);
 
 export const hasOCSTaint = (node) => {
   const taints = node?.spec?.taints || [];
   return taints.some((taint) => _.isEqual(taint, ocsTaint));
 };
 
+export const createObjectFromJson = (objectJson) =>
+  execSync(`echo '${JSON.stringify(objectJson)}' | kubectl create -f -`);
+
 export type NodeType = {
   id: number;
   name: string;
