@@ -1,4 +1,5 @@
 import * as React from 'react';
+import { Trans, useTranslation } from 'react-i18next';
 import * as _ from 'lodash';
 import { match as RouterMatch } from 'react-router';
 // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
@@ -10,24 +11,24 @@ import { useK8sWatchResource } from '@console/internal/components/utils/k8s-watc
 import { StorageClassModel } from '@console/internal/models';
 import { fetchK8s } from '@console/internal/graphql/client';
 import { ClusterServiceVersionModel } from '@console/operator-lifecycle-manager';
-import { CreateOCS } from './install-lso-sc';
 import { LSOSubscriptionResource } from '../../../constants/resources';
 import { filterSCWithNoProv } from '../../../utils/install';
 import CreateSC from './create-sc/create-sc';
 import './attached-devices.scss';
 
-const goToLSOInstallationPage = () => {
+const goToLSOInstallationPage = () =>
   history.push(
     '/operatorhub/all-namespaces?details-item=local-storage-operator-redhat-operators-openshift-marketplace',
   );
-};
 
 export const CreateAttachedDevicesCluster: React.FC<CreateAttachedDevicesClusterProps> = ({
   match,
+  mode,
 }) => {
+  const { t } = useTranslation();
+
   const { appName, ns } = match.params;
   const [hasNoProvSC, setHasNoProvSC] = React.useState(false);
-  const [isNewSCToBeCreated, setIsNewSCToBeCreated] = React.useState<boolean>(false);
   const [isLsoPresent, setIsLsoPresent] = React.useState(false);
   const [allDataLoaded, setAllDataLoaded] = React.useState(false);
   const [lsoNs, setLsoNs] = React.useState('');
@@ -72,37 +73,36 @@ export const CreateAttachedDevicesCluster: React.FC<CreateAttachedDevicesCluster
 
   return !allDataLoaded && !subscriptionLoadError ? (
     <LoadingBox />
+  ) : subscriptionLoadError || !isLsoPresent ? (
+    <Alert
+      className="co-alert ceph-ocs-install__lso-install-alert"
+      variant="info"
+      title="Local Storage Operator Not Installed"
+      isInline
+    >
+      <Trans t={t} ns="ceph-storage-plugin">
+        Before we can create a storage cluster, the local storage operator needs to be installed.
+        When installation is finished come back to OpenShift Container Storage to create a storage
+        cluster.
+        <div className="ceph-ocs-install__lso-alert__button">
+          <Button type="button" variant="primary" onClick={goToLSOInstallationPage}>
+            Install
+          </Button>
+        </div>
+      </Trans>
+    </Alert>
   ) : (
-    <div className="co-m-pane__body">
-      {subscriptionLoadError || !isLsoPresent ? (
-        <Alert
-          className="co-alert ceph-ocs-install__lso-install-alert"
-          variant="info"
-          title="Local Storage Operator Not Installed"
-          isInline
-        >
-          Before we can create a storage cluster, the local storage operator needs to be installed.
-          When installation is finished come back to OpenShift Container Storage to create a storage
-          cluster.
-          <div className="ceph-ocs-install__lso-alert__button">
-            <Button type="button" variant="primary" onClick={goToLSOInstallationPage}>
-              Install
-            </Button>
-          </div>
-        </Alert>
-      ) : hasNoProvSC && !isNewSCToBeCreated ? (
-        <CreateOCS
-          match={match}
-          setIsNewSCToBeCreated={setIsNewSCToBeCreated}
-          setHasNoProvSC={setHasNoProvSC}
-        />
-      ) : (
-        <CreateSC match={match} lsoNs={lsoNs} />
-      )}
-    </div>
+    <CreateSC
+      hasNoProvSC={hasNoProvSC}
+      setHasNoProvSC={setHasNoProvSC}
+      match={match}
+      lsoNs={lsoNs}
+      mode={mode}
+    />
   );
 };
 
 type CreateAttachedDevicesClusterProps = {
   match: RouterMatch<{ appName: string; ns: string }>;
+  mode: string;
 };
