@@ -2,8 +2,8 @@ import * as _ from 'lodash';
 import { Map as ImmutableMap } from 'immutable';
 import { referenceForModel, GroupVersionKind } from '@console/internal/module/k8s';
 import { baseTemplates } from '@console/internal/models/yaml-templates';
-import { YAMLTemplate } from '@console/plugin-sdk';
-import { testedRegistry, getDuplicates } from '../plugin-test-utils';
+import { YAMLTemplate, isYAMLTemplate } from '@console/plugin-sdk';
+import { testedExtensions, getDuplicates } from '../plugin-test-utils';
 
 type TemplateEntry = [GroupVersionKind, ImmutableMap<string, string>];
 
@@ -28,7 +28,12 @@ describe('YAMLTemplate', () => {
   it('only one named template per model is allowed', () => {
     const baseTemplateEntries = _.values(baseTemplates.entrySeq().toObject()) as TemplateEntry[];
     const baseTemplateKeys = _.flatMap(baseTemplateEntries.map(entryToKeys));
-    const pluginTemplateKeys = _.flatMap(testedRegistry.getYAMLTemplates().map(extensionToKeys));
+    const pluginTemplateKeys = _.flatMap(
+      testedExtensions
+        .toArray()
+        .filter(isYAMLTemplate)
+        .map(extensionToKeys),
+    );
     const allTemplateKeys = baseTemplateKeys.concat(pluginTemplateKeys);
     const duplicateTemplateKeys = getDuplicates(allTemplateKeys);
 
