@@ -2,15 +2,23 @@ import * as React from 'react';
 // FIXME upgrading redux types is causing many errors at this time
 // eslint-disable-next-line @typescript-eslint/ban-ts-ignore
 // @ts-ignore
-import { connect, useSelector } from 'react-redux';
+import { connect } from 'react-redux';
 import * as _ from 'lodash';
 import { sortable } from '@patternfly/react-table';
+import { useTranslation } from 'react-i18next';
+import i18next from 'i18next';
 import {
   getName,
   getUID,
   getNodeRole,
   getLabels,
   getNodeMachineNameAndNamespace,
+  WithUserSettingsCompatibilityProps,
+  TableColumnsType,
+  withUserSettingsCompatibility,
+  COLUMN_MANAGEMENT_LOCAL_STORAGE_KEY,
+  COLUMN_MANAGEMENT_CONFIGMAP_KEY,
+  useUserSettingsCompatibility,
 } from '@console/shared';
 import { NodeModel, MachineModel } from '@console/internal/models';
 import { NodeKind, referenceForModel } from '@console/internal/module/k8s';
@@ -38,68 +46,81 @@ import { nodeStatus } from '../../status/node';
 import NodeRoles from './NodeRoles';
 import { menuActions } from './menu-actions';
 import NodeStatus from './NodeStatus';
-import { RootState } from '@console/internal/redux';
+import MarkAsSchedulablePopover from './popovers/MarkAsSchedulablePopover';
+
+// t('nodes~Name')
+// t('nodes~Status')
+// t('nodes~Role')
+// t('nodes~Pods')
+// t('nodes~Memory')
+// t('nodes~CPU')
+// t('nodes~Filesystem')
+// t('nodes~Created')
+// t('nodes~Instance type')
+// t('nodes~Machine')
+// t('nodes~Labels')
+// t('nodes~Zone')
 
 const nodeColumnInfo = Object.freeze({
   name: {
     classes: '',
     id: 'name',
-    title: 'Name',
+    title: 'nodes~Name',
   },
   status: {
     classes: '',
     id: 'status',
-    title: 'Status',
+    title: 'nodes~Status',
   },
   role: {
     classes: '',
     id: 'role',
-    title: 'Role',
+    title: 'nodes~Role',
   },
   pods: {
     classes: '',
     id: 'pods',
-    title: 'Pods',
+    title: 'nodes~Pods',
   },
   memory: {
     classes: '',
     id: 'memory',
-    title: 'Memory',
+    title: 'nodes~Memory',
   },
   cpu: {
     classes: '',
     id: 'cpu',
-    title: 'CPU',
+    title: 'nodes~CPU',
   },
   filesystem: {
     classes: '',
     id: 'filesystem',
-    title: 'Filesystem',
+    title: 'nodes~Filesystem',
   },
   created: {
     classes: '',
     id: 'created',
-    title: 'Created',
+    title: 'nodes~Created',
   },
   instanceType: {
     classes: '',
     id: 'instanceType',
-    title: 'Instance type',
+    title: 'nodes~Instance type',
   },
   machine: {
     classes: '',
     id: 'machine',
-    title: 'Machine',
+    title: 'nodes~Machine',
   },
   labels: {
     classes: '',
     id: 'labels',
-    title: 'Labels',
+    title: 'nodes~Labels',
   },
   zone: {
     classes: '',
     id: 'zone',
-    title: 'Zone',
+    title: 'nodes~Zone',
   },
 });
 
@@ -109,70 +130,70 @@ const kind = 'Node';
 const NodeTableHeader = () => {
   return [
     {
-      title: nodeColumnInfo.name.title,
+      title: i18next.t(nodeColumnInfo.name.title),
       id: nodeColumnInfo.name.id,
       sortField: 'metadata.name',
       transforms: [sortable],
       props: { className: nodeColumnInfo.name.classes },
     },
     {
-      title: nodeColumnInfo.status.title,
+      title: i18next.t(nodeColumnInfo.status.title),
       id: nodeColumnInfo.status.id,
       sortFunc: 'nodeReadiness',
       transforms: [sortable],
       props: { className: nodeColumnInfo.status.classes },
     },
     {
-      title: nodeColumnInfo.role.title,
+      title: i18next.t(nodeColumnInfo.role.title),
       id: nodeColumnInfo.role.id,
       sortFunc: 'nodeRoles',
       transforms: [sortable],
       props: { className: nodeColumnInfo.role.classes },
     },
     {
-      title: nodeColumnInfo.pods.title,
+      title: i18next.t(nodeColumnInfo.pods.title),
       id: nodeColumnInfo.pods.id,
       sortFunc: 'nodePods',
       transforms: [sortable],
       props: { className: nodeColumnInfo.pods.classes },
     },
     {
-      title: nodeColumnInfo.memory.title,
+      title: i18next.t(nodeColumnInfo.memory.title),
       id: nodeColumnInfo.memory.id,
       sortFunc: 'nodeMemory',
       transforms: [sortable],
       props: { className: nodeColumnInfo.memory.classes },
     },
     {
-      title: nodeColumnInfo.cpu.title,
+      title: i18next.t(nodeColumnInfo.cpu.title),
       id: nodeColumnInfo.cpu.id,
       sortFunc: 'nodeCPU',
       transforms: [sortable],
       props: { className: nodeColumnInfo.cpu.classes },
     },
     {
-      title: nodeColumnInfo.filesystem.title,
+      title: i18next.t(nodeColumnInfo.filesystem.title),
       id: nodeColumnInfo.filesystem.id,
       sortFunc: 'nodeFS',
       transforms: [sortable],
       props: { className: nodeColumnInfo.filesystem.classes },
     },
     {
-      title: nodeColumnInfo.created.title,
+      title: i18next.t(nodeColumnInfo.created.title),
       id: nodeColumnInfo.created.id,
       sortField: 'metadata.creationTimestamp',
       transforms: [sortable],
       props: { className: nodeColumnInfo.created.classes },
     },
     {
-      title: nodeColumnInfo.instanceType.title,
+      title: i18next.t(nodeColumnInfo.instanceType.title),
       id: nodeColumnInfo.instanceType.id,
       sortFunc: 'nodeInstanceType',
       transforms: [sortable],
       props: { className: nodeColumnInfo.instanceType.classes },
     },
     {
-      title: nodeColumnInfo.machine.title,
+      title: i18next.t(nodeColumnInfo.machine.title),
       id: nodeColumnInfo.machine.id,
       sortFunc: 'nodeMachine',
       transforms: [sortable],
@@ -180,7 +201,7 @@ const NodeTableHeader = () => {
       additional: true,
     },
     {
-      title: nodeColumnInfo.labels.title,
+      title: i18next.t(nodeColumnInfo.labels.title),
       id: nodeColumnInfo.labels.id,
       sortField: 'metadata.labels',
       transforms: [sortable],
@@ -188,7 +209,7 @@ const NodeTableHeader = () => {
       additional: true,
     },
     {
-      title: nodeColumnInfo.zone.title,
+      title: i18next.t(nodeColumnInfo.zone.title),
       id: nodeColumnInfo.zone.id,
       sortFunc: 'nodeZone',
       transforms: [sortable],
@@ -216,12 +237,10 @@ const getSelectedColumns = () => {
 
 const mapStateToProps = ({ UI }) => ({
   metrics: UI.getIn(['metrics', 'node']),
-  selectedColumns: UI.getIn(['columnManagement']),
 });
 
 type NodesRowMapFromStateProps = {
   metrics: NodeMetrics;
-  selectedColumns: Map<string, Set<string>>;
 };
 
 const NodesTableRow = connect<NodesRowMapFromStateProps, null, NodesTableRowProps>(mapStateToProps)(
@@ -231,8 +250,13 @@ const NodesTableRow = connect<NodesRowMapFromStateProps, null, NodesTableRowProp
     rowKey,
     style,
     metrics,
-    selectedColumns,
   }: NodesTableRowProps & NodesRowMapFromStateProps) => {
+    const [tableColumns, , loaded] = useUserSettingsCompatibility(
+      COLUMN_MANAGEMENT_CONFIGMAP_KEY,
+      COLUMN_MANAGEMENT_LOCAL_STORAGE_KEY,
+      undefined,
+      true,
+    );
     const nodeName = getName(node);
     const nodeUID = getUID(node);
     const usedMem = metrics?.usedMemory?.[nodeName];
@@ -242,6 +266,11 @@ const NodesTableRow = connect<NodesRowMapFromStateProps, null, NodesTableRowProp
         ? `${humanizeBinaryBytes(usedMem).string} / ${humanizeBinaryBytes(totalMem).string}`
         : '-';
     const cores = metrics?.cpu?.[nodeName];
+    const totalCores = metrics?.totalCPU?.[nodeName];
+    const cpu =
+      Number.isFinite(cores) && Number.isFinite(totalCores)
+        ? `${formatCores(cores)} / ${totalCores} cores`
+        : '-';
     const usedStrg = metrics?.usedStorage?.[nodeName];
     const totalStrg = metrics?.totalStorage?.[nodeName];
     const storage =
@@ -253,7 +282,10 @@ const NodesTableRow = connect<NodesRowMapFromStateProps, null, NodesTableRowProp
     const instanceType = node.metadata.labels?.['beta.kubernetes.io/instance-type'];
     const labels = getLabels(node);
     const zone = node.metadata.labels?.['topology.kubernetes.io/zone'];
-    const columns = new Set(selectedColumns?.get(columnManagementID) || getSelectedColumns());
+    const columns: Set<string> =
+      loaded && tableColumns?.[columnManagementID]?.length > 0
+        ? new Set(tableColumns[columnManagementID])
+        : getSelectedColumns();
     return (
       <TableRow id={nodeUID} index={index} trKey={rowKey} style={style}>
         <TableData className={nodeColumnInfo.name.classes}>
@@ -264,7 +296,11 @@ const NodesTableRow = connect<NodesRowMapFromStateProps, null, NodesTableRowProp
           columns={columns}
           columnID={nodeColumnInfo.status.id}
         >
-          <NodeStatus node={node} showPopovers />
+          {!node.spec.unschedulable ? (
+            <NodeStatus node={node} showPopovers />
+          ) : (
+            <MarkAsSchedulablePopover node={node} />
+          )}
         </TableData>
         <TableData
           className={nodeColumnInfo.role.classes}
@@ -292,7 +328,7 @@ const NodesTableRow = connect<NodesRowMapFromStateProps, null, NodesTableRowProp
           columns={columns}
           columnID={nodeColumnInfo.cpu.id}
         >
-          {cores ? `${formatCores(cores)} cores` : '-'}
+          {cpu}
         </TableData>
         <TableData
           className={nodeColumnInfo.filesystem.classes}
@@ -364,60 +400,52 @@ type NodesTableRowProps = {
   style: object;
 };
 
-const NodesTable: React.FC<NodesTableProps> = React.memo((props) => {
-  const Row = React.useCallback(
-    (rowArgs: RowFunctionArgs<NodeKind>) => (
-      <NodesTableRow
-        obj={rowArgs.obj}
-        index={rowArgs.index}
-        rowKey={rowArgs.key}
-        style={rowArgs.style}
+const NodesTable: React.FC<NodesTableProps &
+  WithUserSettingsCompatibilityProps<TableColumnsType>> = React.memo(
+  ({ userSettingState: tableColumns, ...props }) => {
+    const Row = React.useCallback(
+      (rowArgs: RowFunctionArgs<NodeKind>) => (
+        <NodesTableRow
+          obj={rowArgs.obj}
+          index={rowArgs.index}
+          rowKey={rowArgs.key}
+          style={rowArgs.style}
+        />
+      ),
+      [],
+    );
+    const { t } = useTranslation();
+    const selectedColumns: Set<string> =
+      tableColumns?.[columnManagementID]?.length > 0
+        ? new Set(tableColumns[columnManagementID])
+        : null;
+    return (
+      <Table
+        {...props}
+        activeColumns={selectedColumns}
+        columnManagementID={columnManagementID}
+        aria-label={t('nodes~Nodes')}
+        Header={NodeTableHeader}
+        Row={Row}
+        virtualize
       />
-    ),
-    [],
-  );
-  return (
-    <Table
-      {...props}
-      columnManagementID={columnManagementID}
-      aria-label="Nodes"
-      Header={NodeTableHeader}
-      Row={Row}
-      virtualize
-    />
-  );
-});
+    );
+  },
+);
 
 type NodesTableProps = React.ComponentProps<typeof Table> & {
   data: NodeKind[];
 };
 
-const filters = [
-  {
-    filterGroupName: 'Status',
-    type: 'node-status',
-    reducer: nodeStatus,
-    items: [
-      { id: 'Ready', title: 'Ready' },
-      { id: 'Not Ready', title: 'Not Ready' },
-    ],
-  },
-  {
-    filterGroupName: 'Role',
-    type: 'node-role',
-    reducer: getNodeRole,
-    items: [
-      {
-        id: 'master',
-        title: 'Master',
-      },
-      {
-        id: 'worker',
-        title: 'Worker',
-      },
-    ],
-  },
-];
+const NodesTableWithUserSettings = withUserSettingsCompatibility<
+  NodesTableProps & WithUserSettingsCompatibilityProps<TableColumnsType>,
+  TableColumnsType
+>(
+  COLUMN_MANAGEMENT_CONFIGMAP_KEY,
+  COLUMN_MANAGEMENT_LOCAL_STORAGE_KEY,
+  undefined,
+  true,
+)(NodesTable);
 
 const fetchNodeMetrics = (): Promise<NodeMetrics> => {
   const metrics = [
@@ -432,16 +460,20 @@ const fetchNodeMetrics = (): Promise<NodeMetrics> => {
     {
       key: 'usedStorage',
       query:
-        'sum by (instance) (node_filesystem_size_bytes{mountpoint="/var"} - node_filesystem_free_bytes{mountpoint="/var"})',
+        'sum by (instance) (node_filesystem_size_bytes{mountpoint="/"} - node_filesystem_free_bytes{mountpoint="/"})',
     },
     {
       key: 'totalStorage',
-      query: 'sum by (instance) (node_filesystem_size_bytes{mountpoint="/var"})',
+      query: 'sum by (instance) (node_filesystem_size_bytes{mountpoint="/"})',
     },
     {
       key: 'cpu',
       query: 'sum by(instance) (instance:node_cpu:rate:sum)',
     },
+    {
+      key: 'totalCPU',
+      query: 'sum by(instance) (instance:node_num_cpu:sum)',
+    },
     {
       key: 'pods',
       query: 'sum by(node)(kubelet_running_pods)',
@@ -468,44 +500,81 @@ const showMetrics = PROMETHEUS_BASE_PATH && window.innerWidth > 1200;
 const NodesPage = connect<{}, MapDispatchToProps>(
   null,
   mapDispatchToProps,
-)((props: MapDispatchToProps) => {
-  const { setNodeMetrics: setMetrics } = props;
-  const selectedColumns: Set<string> = new Set(
-    useSelector<RootState, string>(({ UI }) => UI.getIn(['columnManagement', columnManagementID])),
-  );
+)(
+  withUserSettingsCompatibility<
+    MapDispatchToProps & WithUserSettingsCompatibilityProps<TableColumnsType>,
+    TableColumnsType
+  >(
+    COLUMN_MANAGEMENT_CONFIGMAP_KEY,
+    COLUMN_MANAGEMENT_LOCAL_STORAGE_KEY,
+    undefined,
+    true,
+  )((props: MapDispatchToProps & WithUserSettingsCompatibilityProps<TableColumnsType>) => {
+    const { setNodeMetrics: setMetrics, userSettingState: tableColumns } = props;
 
-  React.useEffect(() => {
-    const updateMetrics = () =>
-      fetchNodeMetrics()
-        .then(setMetrics)
-        .catch((e) => {
-          // eslint-disable-next-line no-console
-          console.error('Error fetching node metrics: ', e);
-        });
-    updateMetrics();
-    if (showMetrics) {
-      const id = setInterval(updateMetrics, 30 * 1000);
-      return () => clearInterval(id);
-    }
-    return () => {};
-    // eslint-disable-next-line react-hooks/exhaustive-deps
-  }, []);
+    React.useEffect(() => {
+      const updateMetrics = () =>
+        fetchNodeMetrics()
+          .then(setMetrics)
+          .catch((e) => {
+            // eslint-disable-next-line no-console
+            console.error('Error fetching node metrics: ', e);
+          });
+      updateMetrics();
+      if (showMetrics) {
+        const id = setInterval(updateMetrics, 30 * 1000);
+        return () => clearInterval(id);
+      }
+      return () => {};
+      // eslint-disable-next-line react-hooks/exhaustive-deps
+    }, []);
+    const { t } = useTranslation();
+    const filters = [
+      {
+        filterGroupName: t('nodes~Status'),
+        type: 'node-status',
+        reducer: nodeStatus,
+        items: [
+          { id: 'Ready', title: t('nodes~Ready') },
+          { id: 'Not Ready', title: t('nodes~Not Ready') },
+        ],
+      },
+      {
+        filterGroupName: t('nodes~Role'),
+        type: 'node-role',
+        reducer: getNodeRole,
+        items: [
+          {
+            id: 'master',
+            title: t('nodes~Master'),
+          },
+          {
+            id: 'worker',
+            title: t('nodes~Worker'),
+          },
+        ],
+      },
+    ];
 
-  return (
-    <ListPage
-      {...props}
-      kind={kind}
-      ListComponent={NodesTable}
-      rowFilters={filters}
-      columnLayout={{
-        columns: NodeTableHeader().map((column) => _.pick(column, ['title', 'additional', 'id'])),
-        id: columnManagementID,
-        selectedColumns,
-        type: 'Node',
-      }}
-    />
-  );
-});
+    return (
+      <ListPage
+        {...props}
+        kind={kind}
+        ListComponent={NodesTableWithUserSettings}
+        rowFilters={filters}
+        columnLayout={{
+          columns: NodeTableHeader().map((column) => _.pick(column, ['title', 'additional', 'id'])),
+          id: columnManagementID,
+          selectedColumns:
+            tableColumns?.[columnManagementID]?.length > 0
+              ? new Set(tableColumns[columnManagementID])
+              : null,
+          type: 'Node',
+        }}
+      />
+    );
+  }),
+);
 
 type MapDispatchToProps = {
   setNodeMetrics: (metrics) => void;
