@@ -1,5 +1,7 @@
 import * as React from 'react';
 import * as _ from 'lodash';
+import { useTranslation } from 'react-i18next';
+import i18next from 'i18next';
 import { Gallery, GalleryItem, Alert } from '@patternfly/react-core';
 import HealthBody from '@console/shared/src/components/dashboard/status-card/HealthBody';
 import HealthItem from '@console/shared/src/components/dashboard/status-card/HealthItem';
@@ -31,6 +33,7 @@ import { ResourceLink } from '@console/internal/components/utils';
 import { NodeDashboardContext } from './NodeDashboardContext';
 import NodeStatus from '../NodeStatus';
 import { CONDITIONS_WARNING } from './messages';
+import MarkAsSchedulablePopover from '../popovers/MarkAsSchedulablePopover';
 
 import './node-health.scss';
 
@@ -63,9 +66,12 @@ export const HealthChecksPopup: React.FC<HealthChecksPopupProps> = ({
         : healthStateMapping[HealthState.OK].icon,
     };
   });
+  const { t } = useTranslation();
   return (
     <>
-      {`${MachineHealthCheckModel.labelPlural} automatically remediate node health issues.`}
+      {t('nodes~{{ machineHealthCheckLabelPlural }} automatically remediate node health issues.', {
+        machineHealthCheckLabelPlural: MachineHealthCheckModel.labelPlural,
+      })}
       {!!machineHealthChecks?.length && (
         <StatusPopupSection
           firstColumn={pluralize(
@@ -88,7 +94,7 @@ export const HealthChecksPopup: React.FC<HealthChecksPopupProps> = ({
         </StatusPopupSection>
       )}
       {!!conditions.length && (
-        <StatusPopupSection firstColumn="Conditions" secondColumn="Status">
+        <StatusPopupSection firstColumn={t('nodes~Conditions')} secondColumn={t('nodes~Status')}>
           {grouppedConditions.map((c) => (
             <Status {...c} key={c.title}>
               {c.title}
@@ -100,7 +106,7 @@ export const HealthChecksPopup: React.FC<HealthChecksPopupProps> = ({
         <Alert
           variant="warning"
           isInline
-          title={`${reboot ? 'Reboot' : 'Reprovision'} pending`}
+          title={reboot ? t('nodes~Reboot pending') : t('nodes~Reprovision pending')}
           className="co-node-health__popup-alert"
         >
           {CONDITIONS_WARNING(reboot)}
@@ -113,7 +119,9 @@ export const HealthChecksPopup: React.FC<HealthChecksPopupProps> = ({
           title="Multiple resources"
           className="co-node-health__popup-alert"
         >
-          {`Only one ${MachineHealthCheckModel.label} resource should match this node.`}
+          {t('nodes~Only one {{ machineHealthCheckLabel }} resource should match this node.', {
+            machineHealthCheckLabel: MachineHealthCheckModel.label,
+          })}
         </Alert>
       )}
       {disabledAlert && (
@@ -169,7 +177,7 @@ export const getMachineHealth = (
     return {
       state: HealthState.NOT_AVAILABLE,
       noIcon: true,
-      details: 'Not configured',
+      details: i18next.t('nodes~Not configured'),
     };
   }
   let failingConditions: number = 0;
@@ -187,6 +195,7 @@ export const getMachineHealth = (
       }),
     ),
   );
+
   return {
     state: failingConditions || matchingHC.length > 1 ? HealthState.WARNING : HealthState.OK,
     details:
@@ -210,6 +219,7 @@ type HealthChecksItemProps = {
 export const HealthChecksItem: React.FC<HealthChecksItemProps> = ({ disabledAlert }) => {
   const { obj, setHealthCheck } = React.useContext(NodeDashboardContext);
   const { name, namespace } = getNodeMachineNameAndNamespace(obj);
+  const { t } = useTranslation();
   const machineResource = React.useMemo(
     () => ({
       kind: referenceForModel(MachineModel),
@@ -244,7 +254,11 @@ export const HealthChecksItem: React.FC<HealthChecksItemProps> = ({ disabledAler
   });
 
   return (
-    <HealthItem title="Health Checks" popupTitle="Health Checks" {...healthState}>
+    <HealthItem
+      title={t('nodes~Health checks')}
+      popupTitle={t('nodes~Health checks')}
+      {...healthState}
+    >
       <HealthChecksPopup
         conditions={healthState.conditions}
         machineHealthChecks={healthState.matchingHC}
@@ -260,7 +274,11 @@ const NodeHealth: React.FC = () => {
     <HealthBody>
       <Gallery className="co-overview-status__health" hasGutter>
         <GalleryItem>
-          <NodeStatus node={obj} className="co-node-health__status" />
+          {!obj.spec.unschedulable ? (
+            <NodeStatus className="co-node-health__status" node={obj} showPopovers />
+          ) : (
+            <MarkAsSchedulablePopover node={obj} />
+          )}
         </GalleryItem>
         <GalleryItem>
           <HealthChecksItem />
