@@ -1,3 +1,13 @@
+import * as React from 'react';
+
+/**
+ * Console feature flags used to gate extension instances.
+ */
+export type ExtensionFlags = Partial<{
+  required: string[];
+  disallowed: string[];
+}>;
+
 /**
  * An extension of the Console application.
  *
@@ -13,22 +23,17 @@
  *
  * Each extension may specify `flags` referencing Console feature flags which
  * are required and/or disallowed in order to put this extension into effect.
- *
- * TODO(vojtech): write ESLint rule to guard against extension type duplicity
  */
-export type Extension<P = any> = {
+export type Extension<P extends {} = any> = {
   type: string;
   properties: P;
-  flags?: Partial<{
-    required: string[];
-    disallowed: string[];
-  }>;
+  flags?: ExtensionFlags;
 };
 
 /**
  * An extension that is always effective, regardless of feature flags.
  */
-export type AlwaysOnExtension<P = any> = Omit<Extension<P>, 'flags'>;
+export type AlwaysOnExtension<P extends {} = any> = Omit<Extension<P>, 'flags'>;
 
 /**
  * From plugin author perspective, a plugin is simply a list of extensions.
@@ -81,6 +86,13 @@ export type ExtensionTypeGuard<E extends Extension> = (e: E) => e is E;
  */
 export type LazyLoader<T extends {} = {}> = () => Promise<React.ComponentType<Partial<T>>>;
 
+/**
+ * Code reference, resolved to a function that returns the object `T`.
+ *
+ * TODO: Remove this once https://github.com/openshift/console/pull/7163 gets merged that adds support for dynamic extensions in static plugins.
+ */
+export type CodeRef<T> = () => Promise<T>;
+
 /**
  * From Console application perspective, a plugin is a list of extensions
  * enhanced with additional data.
@@ -93,7 +105,8 @@ export type ActivePlugin = {
 /**
  * Runtime extension interface, exposing additional metadata.
  */
-export type LoadedExtension<E extends Extension> = E & {
+export type LoadedExtension<E extends Extension = Extension> = E & {
+  pluginID: string;
   pluginName: string;
   uid: string;
 };
