@@ -1,3 +1,4 @@
+import { TFunction } from 'i18next';
 import { HealthState } from '@console/shared/src/components/dashboard/status-card/states';
 import { GridPosition } from '@console/shared/src/components/dashboard/DashboardGrid';
 import {
@@ -153,7 +154,7 @@ namespace ExtensionProperties {
     model: K8sKind;
 
     /** Function which will map various statuses to groups. */
-    mapper?: StatusGroupMapper;
+    mapper?: () => Promise<StatusGroupMapper>;
 
     /** Additional resources which will be fetched and passed to `mapper` function. */
     additionalResources?: WatchK8sResources<any>;
@@ -378,22 +379,24 @@ export type URLHealthHandler<R> = (
 
 export type PrometheusHealthPopupProps = {
   responses: { response: PrometheusResponse; error: any }[];
-  additionalResource?: FirehoseResult<K8sResourceKind | K8sResourceKind[]>;
+  k8sResult?: FirehoseResult<K8sResourceKind | K8sResourceKind[]>;
 };
 
 export type PrometheusHealthHandler = (
   responses: { response: PrometheusResponse; error: any }[],
+  t?: TFunction,
   additionalResource?: FirehoseResult<K8sResourceKind | K8sResourceKind[]>,
 ) => SubsystemHealth;
 
 export type ResourceHealthHandler<R extends ResourcesObject> = (
   resourcesResult: WatchK8sResults<R>,
+  t?: TFunction,
 ) => SubsystemHealth;
 
 export type OperatorHealthHandler = (resources: FirehoseResourcesResult) => OperatorHealth;
 
 export type OperatorHealth = {
-  health: HealthState;
+  health: keyof typeof HealthState;
   count?: number;
 };
 
@@ -414,7 +417,7 @@ export type OperatorStatusPriority = {
   title: string;
   priority: number;
   icon: React.ReactNode;
-  health: HealthState;
+  health: keyof typeof HealthState;
 };
 
 export type OperatorRowProps<R extends K8sResourceCommon = K8sResourceCommon> = {
