@@ -1,5 +1,7 @@
 import * as _ from 'lodash';
 import * as React from 'react';
+import { TFunction } from 'i18next';
+import { withTranslation } from 'react-i18next';
 import * as fuzzy from 'fuzzysearch';
 import {
   Dropdown,
@@ -41,6 +43,7 @@ export interface ResourceDropdownItems {
 
 interface ResourceDropdownProps {
   id?: string;
+  ariaLabel?: string;
   className?: string;
   dropDownClassName?: string;
   menuClassName?: string;
@@ -48,6 +51,7 @@ interface ResourceDropdownProps {
   title?: React.ReactNode;
   titlePrefix?: string;
   allApplicationsKey?: string;
+  userSettingsPrefix?: string;
   storageKey?: string;
   disabled?: boolean;
   allSelectorItem?: {
@@ -77,6 +81,7 @@ interface ResourceDropdownProps {
   autocompleteFilter?: (strText: string, item: object) => boolean;
   customResourceKey?: (key: string, resource: K8sResourceKind) => string;
   appendItems?: ResourceDropdownItems;
+  t: TFunction;
 }
 
 class ResourceDropdown extends React.Component<ResourceDropdownProps, State> {
@@ -118,7 +123,11 @@ class ResourceDropdown extends React.Component<ResourceDropdownProps, State> {
 
     if (loadError) {
       this.setState({
-        title: <span className="cos-error-title">Error Loading - {placeholder}</span>,
+        title: (
+          <span className="cos-error-title">
+            {this.props.t('console-shared~Error loading - {{placeholder}}', { placeholder })}
+          </span>
+        ),
       });
     }
 
@@ -268,6 +277,7 @@ class ResourceDropdown extends React.Component<ResourceDropdownProps, State> {
     return (
       <Dropdown
         id={this.props.id}
+        ariaLabel={this.props.ariaLabel}
         className={this.props.className}
         dropDownClassName={this.props.dropDownClassName}
         menuClassName={this.props.menuClassName}
@@ -280,6 +290,7 @@ class ResourceDropdown extends React.Component<ResourceDropdownProps, State> {
         selectedKey={this.props.selectedKey}
         title={this.props.title || this.state.title}
         autocompletePlaceholder={this.props.placeholder}
+        userSettingsPrefix={this.props.userSettingsPrefix}
         storageKey={this.props.storageKey}
         disabled={this.props.disabled}
       />
@@ -287,4 +298,4 @@ class ResourceDropdown extends React.Component<ResourceDropdownProps, State> {
   }
 }
 
-export default ResourceDropdown;
+export default withTranslation()(ResourceDropdown);
