@@ -10,6 +10,7 @@ import {
 } from '@patternfly/react-icons';
 import { DASH } from '../../constants';
 import { YellowExclamationTriangleIcon } from './icons';
+import NotStartedIcon from './NotStartedIcon';
 import StatusIconAndText from './StatusIconAndText';
 import { ErrorStatus, InfoStatus, ProgressStatus, SuccessStatus } from './statuses';
 import { StatusComponentProps } from './types';
@@ -28,7 +29,7 @@ export const Status: React.FC<StatusProps> = ({
       return <StatusIconAndText {...statusProps} icon={<HourglassStartIcon />} />;
 
     case 'Pending':
-      return <StatusIconAndText {...statusProps} icon={<HourglassHalfIcon />} />;
+      return <StatusIconAndText {...statusProps} icon={<HourglassHalfIcon color="inherit" />} />;
 
     case 'Planning':
       return <StatusIconAndText {...statusProps} icon={<ClipboardListIcon />} />;
@@ -84,6 +85,7 @@ export const Status: React.FC<StatusProps> = ({
     case 'Ready':
     case 'Up to date':
     case 'Provisioned as node':
+    case 'Preferred':
       return <SuccessStatus {...statusProps} />;
 
     case 'Info':
@@ -92,6 +94,9 @@ export const Status: React.FC<StatusProps> = ({
     case 'Unknown':
       return <StatusIconAndText {...statusProps} icon={<UnknownIcon />} />;
 
+    case 'PipelineNotStarted':
+      return <StatusIconAndText {...statusProps} icon={<NotStartedIcon />} />;
+
     default:
       return <>{status || DASH}</>;
   }
