@@ -1,39 +1,40 @@
 import * as React from 'react';
-import { InfoCircleIcon, HourglassHalfIcon, InProgressIcon } from '@patternfly/react-icons';
+import { HourglassHalfIcon, InProgressIcon } from '@patternfly/react-icons';
 import {
   RedExclamationCircleIcon,
   GreenCheckCircleIcon,
   YellowExclamationTriangleIcon,
+  BlueInfoCircleIcon,
 } from './icons';
 import GenericStatus from './GenericStatus';
 import { StatusComponentProps } from './types';
 
 export const ErrorStatus: React.FC<StatusComponentProps> = (props) => (
-  <GenericStatus {...props} Icon={RedExclamationCircleIcon} />
+  <GenericStatus {...props} Icon={RedExclamationCircleIcon} title={props.title || 'Error'} />
 );
 ErrorStatus.displayName = 'ErrorStatus';
 
 export const InfoStatus: React.FC<StatusComponentProps> = (props) => (
-  <GenericStatus {...props} Icon={InfoCircleIcon} />
+  <GenericStatus {...props} Icon={BlueInfoCircleIcon} title={props.title || 'Information'} />
 );
 InfoStatus.displayName = 'InfoStatus';
 
 export const PendingStatus: React.FC<StatusComponentProps> = (props) => (
-  <GenericStatus {...props} Icon={HourglassHalfIcon} />
+  <GenericStatus {...props} Icon={HourglassHalfIcon} title={props.title || 'Pending'} />
 );
 PendingStatus.displayName = 'PendingStatus';
 
 export const ProgressStatus: React.FC<StatusComponentProps> = (props) => (
-  <GenericStatus {...props} Icon={InProgressIcon} />
+  <GenericStatus {...props} Icon={InProgressIcon} title={props.title || 'In progress'} />
 );
 ProgressStatus.displayName = 'ProgressStatus';
 
 export const SuccessStatus: React.FC<StatusComponentProps> = (props) => (
-  <GenericStatus {...props} Icon={GreenCheckCircleIcon} />
+  <GenericStatus {...props} Icon={GreenCheckCircleIcon} title={props.title || 'Healthy'} />
 );
 SuccessStatus.displayName = 'SuccessStatus';
 
 export const WarningStatus: React.FC<StatusComponentProps> = (props) => (
-  <GenericStatus {...props} Icon={YellowExclamationTriangleIcon} />
+  <GenericStatus {...props} Icon={YellowExclamationTriangleIcon} title={props.title || 'Warning'} />
 );
 WarningStatus.displayName = 'WarningStatus';
