@@ -1,5 +1,3 @@
-/* eslint-disable no-console */
-
 export const newApplicationName = function(): string {
   const d = new Date();
   const month = d.getMonth() < 9 ? `0${d.getMonth() + 1}` : `${d.getMonth() + 1}`;
@@ -8,7 +6,12 @@ export const newApplicationName = function(): string {
   const minute = d.getMinutes() < 10 ? `0${d.getMinutes()}` : `${d.getMinutes()}`;
   const randomNumber = Math.round(Math.random() * 10000);
   const appName = `testapp-${month}${day}-${hour}${minute}-${randomNumber}`;
-  console.info('New application name', appName);
+  return appName;
+};
+
+export const newApplicationShortName = function(): string {
+  const randomNumber = Math.round(Math.random() * 10000);
+  const appName = `testapp-${randomNumber}`;
   return appName;
 };
 
@@ -20,6 +23,11 @@ export const newAppName = function(): string {
   const minute = d.getMinutes() < 10 ? `0${d.getMinutes()}` : `${d.getMinutes()}`;
   const randomNumber = Math.round(Math.random() * 10000);
   const nodeName = `app-${month}${day}-${hour}${minute}-${randomNumber}`;
-  console.info('New app name', nodeName);
+  return nodeName;
+};
+
+export const newAppShortName = function(): string {
+  const randomNumber = Math.round(Math.random() * 10000);
+  const nodeName = `app-${randomNumber}`;
   return nodeName;
 };
