@@ -1,5 +1,6 @@
 import * as React from 'react';
 import { Helmet } from 'react-helmet';
+import { useTranslation } from 'react-i18next';
 import { match as RMatch } from 'react-router';
 import { BuildConfigsPage } from '@console/internal/components/build-config';
 import { withStartGuide } from '../../../../public/components/start-guide';
@@ -13,19 +14,20 @@ export interface BuildConfigPageProps {
 }
 
 const BuildConfigPage: React.FC<BuildConfigPageProps> = ({ noProjectsAvailable, ...props }) => {
+  const { t } = useTranslation();
   const namespace = props.match.params.ns;
   return (
     <>
       <Helmet>
-        <title>Builds</title>
+        <title>{t('devconsole~Builds')}</title>
       </Helmet>
       {namespace ? (
         <div>
           <BuildConfigsPage {...props} mock={noProjectsAvailable} />
         </div>
       ) : (
-        <CreateProjectListPage title="Build Configs">
-          Select a project to view the list of build configs
+        <CreateProjectListPage title={t('devconsole~Build Configs')}>
+          {t('devconsole~Select a Project to view the list of BuildConfigs')}
         </CreateProjectListPage>
       )}
     </>
