@@ -1,13 +1,14 @@
 import * as React from 'react';
 import { Formik, FormikHelpers } from 'formik';
 import { connect } from 'react-redux';
-import { ALL_APPLICATIONS_KEY } from '@console/shared';
+import { useTranslation } from 'react-i18next';
+import { ALL_APPLICATIONS_KEY, usePostFormSubmitAction } from '@console/shared';
 import { history } from '@console/internal/components/utils';
 import { getActiveApplication } from '@console/internal/reducers/ui';
 import { RootState } from '@console/internal/redux';
 import { K8sResourceKind } from '@console/internal/module/k8s';
-import { doContextualBinding, sanitizeApplicationValue } from '../../utils/application-utils';
-import { ALLOW_SERVICE_BINDING } from '../../const';
+import { ALLOW_SERVICE_BINDING_FLAG } from '@console/topology/src/const';
+import { sanitizeApplicationValue } from '@console/topology/src/utils/application-utils';
 import { DeployImageFormData, FirehoseList, Resources } from './import-types';
 import { createOrUpdateDeployImageResources } from './deployImage-submit-utils';
 import { deployValidationSchema } from './deployImage-validation-utils';
@@ -32,8 +33,9 @@ const DeployImage: React.FC<Props> = ({
   projects,
   activeApplication,
   contextualSource,
-  serviceBindingAvailable,
 }) => {
+  const postFormCallback = usePostFormSubmitAction();
+  const { t } = useTranslation();
   const initialValues: DeployImageFormData = {
     project: {
       name: namespace || '',
@@ -54,7 +56,6 @@ const DeployImage: React.FC<Props> = ({
       image: '',
       tag: '',
       namespace: namespace || '',
-      grantAccess: true,
     },
     isi: {
       name: '',
@@ -155,14 +156,7 @@ const DeployImage: React.FC<Props> = ({
       const requests: Promise<K8sResourceKind[]> = createOrUpdateDeployImageResources(values);
       return requests;
     });
-
-    if (contextualSource) {
-      resourceActions
-        .then((resources) =>
-          doContextualBinding(resources, contextualSource, serviceBindingAvailable),
-        )
-        .catch(() => {});
-    }
+    resourceActions.then((resources) => postFormCallback(resources)).catch(() => {});
 
     return resourceActions
       .then(() => {
@@ -178,7 +172,7 @@ const DeployImage: React.FC<Props> = ({
       initialValues={initialValues}
       onSubmit={handleSubmit}
       onReset={history.goBack}
-      validationSchema={deployValidationSchema}
+      validationSchema={deployValidationSchema(t)}
     >
       {(formikProps) => <DeployImageForm {...formikProps} projects={projects} />}
     </Formik>
@@ -193,7 +187,7 @@ const mapStateToProps = (state: RootState, ownProps: OwnProps): StateProps => {
 
   return {
     activeApplication: activeApplication !== ALL_APPLICATIONS_KEY ? activeApplication : '',
-    serviceBindingAvailable: state.FLAGS.get(ALLOW_SERVICE_BINDING),
+    serviceBindingAvailable: state.FLAGS.get(ALLOW_SERVICE_BINDING_FLAG),
   };
 };
 
