@@ -1,8 +1,11 @@
 import * as React from 'react';
 import { RouteComponentProps } from 'react-router-dom';
-import { Helmet } from 'react-helmet';
+import Helmet from 'react-helmet';
+import { TFunction } from 'i18next';
+import { useTranslation } from 'react-i18next';
 import { PageHeading, Firehose, FirehoseResource } from '@console/internal/components/utils';
-import { ImageStreamModel } from '@console/internal/models';
+import DevPreviewBadge from '@console/shared/src/components/badges/DevPreviewBadge';
+import { ImageStreamModel, ProjectModel } from '@console/internal/models';
 import { QUERY_PROPERTIES } from '../../const';
 import NamespacedPage, { NamespacedPageVariants } from '../NamespacedPage';
 import QueryFocusApplication from '../QueryFocusApplication';
@@ -11,33 +14,43 @@ import { ImportTypes, ImportData } from './import-types';
 
 export type ImportPageProps = RouteComponentProps<{ ns?: string }>;
 
-const ImportFlows: { [name: string]: ImportData } = {
+const ImportFlows = (t: TFunction): { [name: string]: ImportData } => ({
   git: {
     type: ImportTypes.git,
-    title: 'Import from Git',
+    title: t('devconsole~Import from Git'),
     buildStrategy: 'Source',
     loader: () =>
       import('./GitImportForm' /* webpackChunkName: "git-import-form" */).then((m) => m.default),
   },
   docker: {
     type: ImportTypes.docker,
-    title: 'Import from Dockerfile',
+    title: t('devconsole~Import from Dockerfile'),
     buildStrategy: 'Docker',
     loader: () =>
       import('./GitImportForm' /* webpackChunkName: "git-import-form" */).then((m) => m.default),
   },
+  devfile: {
+    type: ImportTypes.devfile,
+    title: t('devconsole~Import from Devfile'),
+    buildStrategy: 'Devfile',
+    loader: () =>
+      import('./devfile/DevfileImportForm' /* webpackChunkName: "devfile-import-form" */).then(
+        (m) => m.default,
+      ),
+  },
   s2i: {
     type: ImportTypes.s2i,
-    title: 'Create Source-to-Image Application',
+    title: t('devconsole~Create Source-to-Image Application'),
     buildStrategy: 'Source',
     loader: () =>
       import('./SourceToImageForm' /* webpackChunkName: "source-to-image-form" */).then(
         (m) => m.default,
       ),
   },
-};
+});
 
 const ImportPage: React.FunctionComponent<ImportPageProps> = ({ match, location }) => {
+  const { t } = useTranslation();
   const namespace = match.params.ns;
   const searchParams = new URLSearchParams(location.search);
   const imageStreamName = searchParams.get('imagestream');
@@ -48,7 +61,7 @@ const ImportPage: React.FunctionComponent<ImportPageProps> = ({ match, location
   let importData: ImportData;
   let resources: FirehoseResource[];
   if (imageStreamName && imageStreamNamespace) {
-    importData = ImportFlows.s2i;
+    importData = ImportFlows(t).s2i;
     resources = [
       {
         kind: ImageStreamModel.kind,
@@ -58,22 +71,31 @@ const ImportPage: React.FunctionComponent<ImportPageProps> = ({ match, location
         namespace: imageStreamNamespace,
       },
       {
-        kind: 'Project',
+        kind: ProjectModel.kind,
         prop: 'projects',
         isList: true,
       },
     ];
   } else if (importType === ImportTypes.docker) {
-    importData = ImportFlows.docker;
+    importData = ImportFlows(t).docker;
     resources = [
       {
-        kind: 'Project',
+        kind: ProjectModel.kind,
+        prop: 'projects',
+        isList: true,
+      },
+    ];
+  } else if (importType === ImportTypes.devfile) {
+    importData = ImportFlows(t).devfile;
+    resources = [
+      {
+        kind: ProjectModel.kind,
         prop: 'projects',
         isList: true,
       },
     ];
   } else {
-    importData = ImportFlows.git;
+    importData = ImportFlows(t).git;
     resources = [
       {
         kind: ImageStreamModel.kind,
@@ -82,7 +104,7 @@ const ImportPage: React.FunctionComponent<ImportPageProps> = ({ match, location
         namespace: 'openshift',
       },
       {
-        kind: 'Project',
+        kind: ProjectModel.kind,
         prop: 'projects',
         isList: true,
       },
@@ -96,7 +118,10 @@ const ImportPage: React.FunctionComponent<ImportPageProps> = ({ match, location
           <Helmet>
             <title>{importData.title}</title>
           </Helmet>
-          <PageHeading title={importData.title} />
+          <PageHeading
+            title={importData.title}
+            badge={importType === ImportTypes.devfile ? <DevPreviewBadge /> : null}
+          />
           <div className="co-m-pane__body" style={{ paddingBottom: 0 }}>
             <Firehose resources={resources}>
               <ImportForm
