@@ -25,14 +25,14 @@ const ProgressiveList: React.FC<ProgressiveListProps> = ({
     },
   );
   return (
-    <React.Fragment>
+    <>
       {visibleItems.map((item: string) => (
         <React.Fragment key={item}>
           {validChildren.find(({ props }: React.ReactElement) => item === props.name)}
         </React.Fragment>
       ))}
       <ProgressiveListFooter text={text} items={items} onShowItem={onVisibleItemChange} />
-    </React.Fragment>
+    </>
   );
 };
 
