@@ -40,9 +40,6 @@ export interface NormalizedBuilderImages {
 
 export const imageStreamLabels = ['app.kubernetes.io/name', 'app.openshift.io/runtime'];
 
-export const getRuntime = (labels: { [key: string]: string }) =>
-  labels?.['app.openshift.io/runtime'] || labels?.['app.kubernetes.io/name'];
-
 export const getSampleRepo = (tag) => tag?.annotations?.sampleRepo ?? '';
 export const getSampleRef = (tag) => tag?.annotations?.sampleRef ?? '';
 export const getSampleContextDir = (tag) => tag?.annotations?.sampleContextDir ?? '';
