@@ -7,7 +7,7 @@ import {
   DeploymentModel,
   StatefulSetModel,
 } from '@console/internal/models';
-import { ModifyApplication, EditApplication } from '../actions/modify-application';
+import { EditApplication } from '@console/topology/src/actions/modify-application';
 
 const modifyWebConsoleApplicationRefs = [
   referenceForModel(DeploymentConfigModel),
@@ -29,7 +29,6 @@ export const getKebabActionsForKind = (resourceKind: K8sKind): KebabAction[] =>
 
   return _.includes(modifyWebConsoleApplicationRefs, referenceForModel(resourceKind))
     ? [
-        ModifyApplication,
         ...(_.includes(editApplicationRefs, referenceForModel(resourceKind))
           ? [EditApplication]
           : []),
