@@ -108,6 +108,20 @@ describe('Github Service', () => {
     });
   });
 
+  it('should use persisted git service metadata and detect java build type', () => {
+    const gitSource: GitSource = { url: 'https://github.com/rohitkrai03/spring-petclinic' };
+
+    const gitService = new GithubService(gitSource);
+
+    return nockBack('files-java.json').then(async ({ nockDone, context }) => {
+      const buildTypes: BuildType[] = await gitService.detectBuildTypes();
+      expect(buildTypes.length).toBeGreaterThanOrEqual(1);
+      expect(buildTypes[0].buildType).toBe('java');
+      context.assertScopesFinished();
+      nockDone();
+    });
+  });
+
   it('should detect Golang language', () => {
     const gitSource: GitSource = { url: 'https://github.com/redhat-developer/devconsole-git' };
 
@@ -122,6 +136,23 @@ describe('Github Service', () => {
     });
   });
 
+  it('should detect DotNet build type inside context directory', () => {
+    const gitSource: GitSource = {
+      url: 'https://github.com/redhat-developer/s2i-dotnetcore-ex',
+      contextDir: 'app',
+    };
+
+    const gitService = new GithubService(gitSource);
+
+    return nockBack('files-dotnet.json').then(async ({ nockDone, context }) => {
+      const buildTypes: BuildType[] = await gitService.detectBuildTypes();
+      expect(buildTypes.length).toBeGreaterThanOrEqual(1);
+      expect(buildTypes[0].buildType).toBe('dotnet');
+      context.assertScopesFinished();
+      nockDone();
+    });
+  });
+
   it('should detect Dockerfile', () => {
     const gitSource = { url: 'https://github.com/mikesparr/tutorial-react-docker' };
 
@@ -162,4 +193,30 @@ describe('Github Service', () => {
       nockDone();
     });
   });
+
+  it('should detect Devfile', () => {
+    const gitSource = { url: 'https://github.com/reginapizza/che' };
+
+    const gitService = new GithubService(gitSource);
+
+    return nockBack('devfile.json').then(async ({ nockDone, context }) => {
+      const isDevfilePresent = await gitService.isDevfilePresent();
+      expect(isDevfilePresent).toBe(true);
+      context.assertScopesFinished();
+      nockDone();
+    });
+  });
+
+  it('should not detect Devfile', () => {
+    const gitSource: GitSource = { url: 'https://github.com/redhat-developer/devconsole-git' };
+
+    const gitService = new GithubService(gitSource);
+
+    return nockBack('no-devfile.json').then(async ({ nockDone, context }) => {
+      const isDevfilePresent = await gitService.isDevfilePresent();
+      expect(isDevfilePresent).toBe(false);
+      context.assertScopesFinished();
+      nockDone();
+    });
+  });
 });
