@@ -4,7 +4,8 @@ import { setTrafficDistributionModal } from '../components/modals';
 
 export const setTrafficDistribution = (model: K8sKind, obj: K8sResourceKind): KebabOption => {
   return {
-    label: 'Set Traffic Distribution',
+    // t('knative-plugin~Set traffic distribution')
+    labelKey: 'knative-plugin~Set traffic distribution',
     callback: () =>
       setTrafficDistributionModal({
         obj,
