@@ -1,7 +1,7 @@
 import * as React from 'react';
 import classNames from 'classnames';
-import { TooltipPosition, Tooltip } from '@patternfly/react-core';
-import { ExternalLinkAltIcon } from '@patternfly/react-icons';
+import { useTranslation } from 'react-i18next';
+import { Tooltip } from '@patternfly/react-core';
 import {
   Node,
   AnchorEnd,
@@ -18,22 +18,23 @@ import {
   useCombineRefs,
   WithCreateConnectorProps,
 } from '@patternfly/react-topology';
-import SvgBoxedText from '@console/dev-console/src/components/svg/SvgBoxedText';
 import {
   NodeShadows,
   NODE_SHADOW_FILTER_ID,
   NODE_SHADOW_FILTER_ID_HOVER,
   nodeDragSourceSpec,
-  Decorator,
+} from '@console/topology/src/components/graph-view';
+import {
   useSearchFilter,
   useDisplayFilters,
   useAllowEdgeCreation,
   getFilterById,
   SHOW_LABELS_FILTER_ID,
-} from '@console/dev-console/src/components/topology';
-import BuildDecorator from '@console/dev-console/src/components/topology/components/nodes/build-decorators/BuildDecorator';
+} from '@console/topology/src/filters';
+import SvgBoxedText from '@console/topology/src/components/svg/SvgBoxedText';
 import { TYPE_KNATIVE_SERVICE, EVENT_MARKER_RADIUS } from '../../const';
 import RevisionTrafficSourceAnchor from '../anchors/RevisionTrafficSourceAnchor';
+import { getNodeDecorators } from '@console/topology/src/components/graph-view/components/nodes/decorators/getNodeDecorators';
 
 export type KnativeServiceGroupProps = {
   element: Node;
@@ -64,21 +65,18 @@ const KnativeServiceGroup: React.FC<KnativeServiceGroupProps> = ({
   onHideCreateConnector,
   onShowCreateConnector,
 }) => {
+  const { t } = useTranslation();
   const [hover, hoverRef] = useHover();
   const [innerHover, innerHoverRef] = useHover();
-  const [{ dragging, regrouping }, dragNodeRef] = useDragNode(
-    nodeDragSourceSpec(TYPE_KNATIVE_SERVICE, true, editAccess),
-    {
-      element,
-    },
-  );
+  const dragSpec = React.useMemo(() => nodeDragSourceSpec(TYPE_KNATIVE_SERVICE, true, editAccess), [
+    editAccess,
+  ]);
+  const dragProps = React.useMemo(() => ({ element }), [element]);
+  const [{ dragging, regrouping }, dragNodeRef] = useDragNode(dragSpec, dragProps);
   const [{ dragging: labelDragging, regrouping: labelRegrouping }, dragLabelRef] = useDragNode(
-    nodeDragSourceSpec(TYPE_KNATIVE_SERVICE, true, editAccess),
-    {
-      element,
-    },
+    dragSpec,
+    dragProps,
   );
-
   const nodeRefs = useCombineRefs(innerHoverRef, dragNodeRef);
   const hasChildren = element.getChildren()?.length > 0;
   const { data } = element.getData();
@@ -110,6 +108,17 @@ const KnativeServiceGroup: React.FC<KnativeServiceGroupProps> = ({
     }
   }, [editAccess, innerHover, onShowCreateConnector, onHideCreateConnector, allowEdgeCreation]);
 
+  const decorators = getNodeDecorators(
+    element,
+    element.getGraph().getData().decorators,
+    x + width / 2,
+    y + height / 2,
+    -1,
+    DECORATOR_RADIUS,
+    width,
+    height,
+  );
+
   return (
     <Tooltip
       content={tooltipLabel}
@@ -144,6 +153,11 @@ const KnativeServiceGroup: React.FC<KnativeServiceGroupProps> = ({
             })}
           >
             <rect
+              key={
+                hover || innerHover || dragging || labelDragging || contextMenuOpen || dropTarget
+                  ? 'rect-hover'
+                  : 'rect'
+              }
               ref={dndDropRef}
               className="odc-knative-service__bg"
               x={x}
@@ -160,21 +174,12 @@ const KnativeServiceGroup: React.FC<KnativeServiceGroupProps> = ({
             />
             {!hasChildren && (
               <text x={x + width / 2} y={y + height / 2} dy="0.35em" textAnchor="middle">
-                No Revisions
+                {t('knative-plugin~No Revisions')}
               </text>
             )}
           </g>
         </Layer>
-        {hasDataUrl && (
-          <Tooltip key="route" content="Open URL" position={TooltipPosition.right}>
-            <Decorator x={x + width} y={y} radius={DECORATOR_RADIUS} href={data.url} external>
-              <g transform="translate(-6.5, -6.5)">
-                <ExternalLinkAltIcon style={{ fontSize: DECORATOR_RADIUS }} alt="Open URL" />
-              </g>
-            </Decorator>
-          </Tooltip>
-        )}
-        <BuildDecorator x={x} y={y + height} radius={DECORATOR_RADIUS} workloadData={data} />
+        {decorators}
         {showLabels && (data.kind || element.getLabel()) && (
           <SvgBoxedText
             className="odc-knative-service__label odc-base-node__label"
