@@ -2,7 +2,7 @@ import { $, element, by } from 'protractor';
 
 export const modalDialog = $('.ReactModal__Content');
 
-export const warningMessage = $('[aria-label="Warning Alert"]');
+export const warningMessage = $('.modal-footer').$('[aria-label="Warning Alert"]');
 
 export const nameHelperMessage = $('#clone-dialog-vm-name-helper');
 
@@ -13,3 +13,5 @@ export const startOnCreationCheckBox = $('#clone-dialog-vm-start');
 
 export const confirmButton = $('#confirm-action');
 export const cancelButton = element(by.buttonText('Cancel'));
+
+export const errorHelper = modalDialog.$('.pf-c-form__helper-text');
