@@ -1,4 +1,4 @@
-import { $, $$ } from 'protractor';
+import { $, $$, element, by } from 'protractor';
 
 export const consoleSelectorDropdownId = '#console-type-selector';
 export const consoleNetworkInterfaceDropdownId = '#nic-dropdown';
@@ -25,13 +25,11 @@ export const vmDetailWorkloadProfile = (namespace, vmName) =>
   $(vmDetailItemId(namespace, vmName, 'workload-profile'));
 export const vmDetailTemplate = (namespace, vmName) =>
   $(`${vmDetailItemId(namespace, vmName, 'template')}`);
+export const vmDetailTemplateByTestID = (templateName) => $(`[data-test-id="${templateName}"]`);
 export const vmDetailNamespace = (namespace, vmName) =>
   $(vmDetailItemId(namespace, vmName, 'namespace'));
 export const vmDetailPod = (namespace, vmName) => $(vmDetailItemId(namespace, vmName, 'pod'));
 export const vmDetailNode = (namespace, vmName) => $(vmDetailItemId(namespace, vmName, 'node'));
-export const vmDetailCd = (namespace, vmName) => $(vmDetailItemId(namespace, vmName, 'cdrom'));
-export const vmDetailCdEditButton = (namespace, vmName) =>
-  $(vmDetailItemId(namespace, vmName, 'cdrom-edit'));
 export const vmDetailFlavor = (namespace, vmName) => $(vmDetailItemId(namespace, vmName, 'flavor'));
 export const vmDetailFlavorEditButton = (namespace, vmName) =>
   $(vmDetailItemId(namespace, vmName, 'flavor-edit'));
@@ -51,8 +49,6 @@ export const vmDetailBootOrder = (namespace, vmName) =>
   $(vmDetailItemId(namespace, vmName, 'boot-order')).$$('li');
 export const vmDetailBootOrderEditButton = (namespace, vmName) =>
   $(vmDetailItemId(namespace, vmName, 'boot-order-edit'));
-export const vmDetailStatusEditButton = (namespace, vmName) =>
-  $(vmDetailItemId(namespace, vmName, 'status-edit'));
 export const vmDetailLabelValue = async (labelKey) => {
   const filteredLabel = $$('.co-m-label').filter((elem) =>
     elem
@@ -65,6 +61,19 @@ export const vmDetailLabelValue = async (labelKey) => {
   return value;
 };
 
+// Guest agent data fields
+export const vmDetailHostname = (namespace, vmName) =>
+  $(vmDetailItemId(namespace, vmName, 'hostname'));
+export const vmDetailTimeZone = (namespace, vmName) =>
+  $(vmDetailItemId(namespace, vmName, 'timezone'));
+export const vmDetailActiveUsersListGuestAgentUnavail = () => $('#guest-agent-unavailable-msg');
+export const vmDetailActiveUsersListNoUsers = $('#no-active-users-msg');
+export const vmDetailsActiveUsersList = element(
+  by.xpath('//*[@aria-label="Users"]//*[@data-key="0-0"]//td'),
+);
+export const vmDetailstatusButton = (namespace, name) =>
+  $(`${vmDetailItemId(namespace, name, 'vm-statuses')} > .pf-c-button.pf-m-link.pf-m-inline`);
+
 export const vmDetailService = (serviceName) => $(`[data-test-id="${serviceName}"]`);
 
 // Scheduling view
@@ -84,3 +93,4 @@ export const vmDetailAffinity = (namespace, vmName) =>
   $(vmDetailItemId(namespace, vmName, 'affinity'));
 export const vmDetailAffinityEditButton = (namespace, vmName) =>
   $(vmDetailItemId(namespace, vmName, 'affinity-edit'));
+export const vmDeleteAlert = $('[aria-label="Warning Alert"]');
