@@ -6,64 +6,85 @@ import {
   iGetRelevantTemplateSelectors,
   iGetVmSettingValue,
 } from '../../selectors/immutable/vm-settings';
-import { VMSettingsField, VMWizardProps } from '../../types';
+import { VMSettingsField, VMWizardProps, VMWizardStorage } from '../../types';
 import { InternalActionType, UpdateOptions } from '../types';
 import { asDisabled, asHidden, asRequired } from '../../utils/utils';
 import { vmWizardInternalActions } from '../internal-actions';
 import {
+  getInitialData,
   iGetCommonData,
   iGetLoadedCommonData,
   iGetName,
   iGetNamespace,
 } from '../../selectors/immutable/selectors';
-import { iGetRelevantTemplate } from '../../../../selectors/immutable/template/combined';
+import {
+  iGetDefaultTemplate,
+  iGetRelevantTemplate,
+  getITemplateDefaultFlavor,
+  getITemplateDefaultWorkload,
+  iGetTemplateGuestToolsDisk,
+} from '../../../../selectors/immutable/template/combined';
 import {
   CUSTOM_FLAVOR,
-  TEMPLATE_DATAVOLUME_NAME_PARAMETER,
-  TEMPLATE_DATAVOLUME_NAMESPACE_PARAMETER,
+  TEMPLATE_BASE_IMAGE_NAME_PARAMETER,
+  TEMPLATE_BASE_IMAGE_NAMESPACE_PARAMETER,
 } from '../../../../constants/vm';
 import { ProvisionSource } from '../../../../constants/vm/provision-source';
 import { prefillVmTemplateUpdater } from './prefill-vm-template-state-update';
-import { iGetPrameterValue, iGetAnnotation } from '../../../../selectors/immutable/common';
+import { iGetAnnotation, iGetPrameterValue } from '../../../../selectors/immutable/common';
 import { CDI_UPLOAD_POD_ANNOTATION, CDI_UPLOAD_RUNNING } from '../../../cdi-upload-provider/consts';
 import { commonTemplatesUpdater } from './vm-common-templates-updater';
+import { iGetIsLoaded, iGetLoadError, toShallowJS } from '../../../../utils/immutable';
+import {
+  hasProvisionStorageChanged,
+  iGetProvisionSourceStorage,
+} from '../../selectors/immutable/storage';
+import { DataVolumeWrapper } from '../../../../k8s/wrapper/vm/data-volume-wrapper';
 
-const selectUserTemplateOnLoadedUpdater = (options: UpdateOptions) => {
+const selectTemplateOnLoadedUpdater = (options: UpdateOptions) => {
   const { id, dispatch, getState } = options;
   const state = getState();
 
-  if (
-    iGetCommonData(state, id, VMWizardProps.isUserTemplateInitialized) ||
-    !iGetLoadedCommonData(state, id, VMWizardProps.userTemplate)
-  ) {
+  if (iGetCommonData(state, id, VMWizardProps.isTemplateInitialized)) {
     return;
   }
 
-  dispatch(
-    vmWizardInternalActions[InternalActionType.UpdateCommonDataValue](
-      id,
-      [VMWizardProps.isUserTemplateInitialized],
-      true,
-    ),
-  );
+  const { commonTemplateName } = getInitialData(state, id);
+
+  const commonTemplateReady =
+    commonTemplateName &&
+    iGetIsLoaded(iGetCommonData(state, id, VMWizardProps.commonTemplates)) &&
+    iGetIsLoaded(iGetCommonData(state, id, VMWizardProps.openshiftCNVBaseImages)) &&
+    !iGetLoadError(iGetCommonData(state, id, VMWizardProps.openshiftCNVBaseImages));
 
   const iUserTemplate = iGetLoadedCommonData(state, id, VMWizardProps.userTemplate);
-  const isDisabled = asDisabled(iUserTemplate != null, VMWizardProps.userTemplate);
 
-  dispatch(
-    vmWizardInternalActions[InternalActionType.UpdateVmSettings](id, {
-      [VMSettingsField.PROVISION_SOURCE_TYPE]: { isDisabled },
-      [VMSettingsField.CONTAINER_IMAGE]: { isDisabled },
-      [VMSettingsField.IMAGE_URL]: { isDisabled },
-      [VMSettingsField.OPERATING_SYSTEM]: { isDisabled },
-      [VMSettingsField.WORKLOAD_PROFILE]: { isDisabled },
-      [VMSettingsField.CLONE_COMMON_BASE_DISK_IMAGE]: {
-        isHidden: asHidden(iUserTemplate != null, VMWizardProps.userTemplate),
-      },
-    }),
-  );
+  if (commonTemplateReady || iUserTemplate) {
+    dispatch(
+      vmWizardInternalActions[InternalActionType.UpdateCommonDataValue](
+        id,
+        [VMWizardProps.isTemplateInitialized],
+        true,
+      ),
+    );
 
-  prefillVmTemplateUpdater(options);
+    const isDisabled = asDisabled(iUserTemplate != null, VMWizardProps.userTemplate);
+
+    dispatch(
+      vmWizardInternalActions[InternalActionType.UpdateVmSettings](id, {
+        [VMSettingsField.PROVISION_SOURCE_TYPE]: { isDisabled },
+        [VMSettingsField.CONTAINER_IMAGE]: { isDisabled },
+        [VMSettingsField.IMAGE_URL]: { isDisabled },
+        [VMSettingsField.OPERATING_SYSTEM]: { isDisabled },
+        [VMSettingsField.WORKLOAD_PROFILE]: { isDisabled },
+        [VMSettingsField.CLONE_COMMON_BASE_DISK_IMAGE]: {
+          isHidden: asHidden(iUserTemplate != null, VMWizardProps.userTemplate),
+        },
+      }),
+    );
+
+    prefillVmTemplateUpdater(options);
+  }
 };
 
 const osUpdater = ({ id, prevState, dispatch, getState }: UpdateOptions) => {
@@ -78,13 +99,41 @@ const osUpdater = ({ id, prevState, dispatch, getState }: UpdateOptions) => {
   const os = iGetVmSettingValue(state, id, VMSettingsField.OPERATING_SYSTEM);
   const isWindows = os?.startsWith('win');
 
+  const iUserTemplate = iGetLoadedCommonData(state, id, VMWizardProps.userTemplate);
+  const mountTools = isWindows && (!iUserTemplate || !!iGetTemplateGuestToolsDisk(iUserTemplate));
+
   dispatch(
     vmWizardInternalActions[InternalActionType.UpdateVmSettingsField](
       id,
       VMSettingsField.MOUNT_WINDOWS_GUEST_TOOLS,
-      { isHidden: asHidden(!isWindows, VMSettingsField.OPERATING_SYSTEM), value: isWindows },
+      { isHidden: asHidden(!isWindows, VMSettingsField.OPERATING_SYSTEM), value: mountTools },
     ),
   );
+
+  const iCommonTemplates = iGetLoadedCommonData(state, id, VMWizardProps.commonTemplates);
+  const iDefaultTemplate = iCommonTemplates && iGetDefaultTemplate(iCommonTemplates, os);
+  const defaultFlavor = getITemplateDefaultFlavor(iDefaultTemplate);
+  const defaultWorkload = getITemplateDefaultWorkload(iDefaultTemplate);
+
+  if (defaultFlavor) {
+    dispatch(
+      vmWizardInternalActions[InternalActionType.UpdateVmSettingsField](
+        id,
+        VMSettingsField.FLAVOR,
+        { value: defaultFlavor.getValue() },
+      ),
+    );
+  }
+
+  if (defaultWorkload) {
+    dispatch(
+      vmWizardInternalActions[InternalActionType.UpdateVmSettingsField](
+        id,
+        VMSettingsField.WORKLOAD_PROFILE,
+        { value: defaultWorkload.getValue() },
+      ),
+    );
+  }
 };
 
 const baseImageUpdater = ({ id, prevState, dispatch, getState }: UpdateOptions) => {
@@ -111,8 +160,8 @@ const baseImageUpdater = ({ id, prevState, dispatch, getState }: UpdateOptions)
     const relevantOptions = iGetRelevantTemplateSelectors(state, id);
     const iCommonTemplates = iGetLoadedCommonData(state, id, VMWizardProps.commonTemplates);
     const iTemplate = iCommonTemplates && iGetRelevantTemplate(iCommonTemplates, relevantOptions);
-    const pvcName = iGetPrameterValue(iTemplate, TEMPLATE_DATAVOLUME_NAME_PARAMETER);
-    const pvcNamespace = iGetPrameterValue(iTemplate, TEMPLATE_DATAVOLUME_NAMESPACE_PARAMETER);
+    const pvcName = iGetPrameterValue(iTemplate, TEMPLATE_BASE_IMAGE_NAME_PARAMETER);
+    const pvcNamespace = iGetPrameterValue(iTemplate, TEMPLATE_BASE_IMAGE_NAMESPACE_PARAMETER);
 
     const iBaseImages = iGetLoadedCommonData(state, id, VMWizardProps.openshiftCNVBaseImages);
     iBaseImage =
@@ -177,6 +226,12 @@ const cloneCommonBaseDiskImageUpdater = ({ id, prevState, dispatch, getState }:
       [VMSettingsField.IMAGE_URL]: {
         isHidden: asHidden(cloneCommonBaseDiskImage, VMSettingsField.CLONE_COMMON_BASE_DISK_IMAGE),
       },
+      [VMSettingsField.CLONE_PVC_NS]: {
+        isHidden: asHidden(cloneCommonBaseDiskImage, VMSettingsField.CLONE_COMMON_BASE_DISK_IMAGE),
+      },
+      [VMSettingsField.CLONE_PVC_NAME]: {
+        isHidden: asHidden(cloneCommonBaseDiskImage, VMSettingsField.CLONE_COMMON_BASE_DISK_IMAGE),
+      },
     }),
   );
 };
@@ -216,8 +271,18 @@ const provisioningSourceUpdater = ({ id, prevState, dispatch, getState }: Update
     return;
   }
   const source = iGetProvisionSource(state, id);
-  const isContainer = source === ProvisionSource.CONTAINER;
+  const isContainer = [ProvisionSource.CONTAINER, ProvisionSource.CONTAINER_EPHEMERAL].includes(
+    source,
+  );
   const isUrl = source === ProvisionSource.URL;
+  const isPvc = source === ProvisionSource.DISK;
+  let hasPVCns = false;
+  if (isPvc) {
+    const provisionStorage = iGetProvisionSourceStorage(state, id);
+    const storage = toShallowJS<VMWizardStorage>(provisionStorage);
+    const dataVolumeWrapper = new DataVolumeWrapper(storage?.dataVolume);
+    hasPVCns = !!dataVolumeWrapper.getPersistentVolumeClaimNamespace();
+  }
 
   dispatch(
     vmWizardInternalActions[InternalActionType.UpdateVmSettings](id, {
@@ -227,6 +292,12 @@ const provisioningSourceUpdater = ({ id, prevState, dispatch, getState }: Update
       [VMSettingsField.IMAGE_URL]: {
         isHidden: asHidden(!isUrl, VMSettingsField.PROVISION_SOURCE_TYPE),
       },
+      [VMSettingsField.CLONE_PVC_NS]: {
+        isHidden: asHidden(!isPvc, VMSettingsField.PROVISION_SOURCE_TYPE),
+      },
+      [VMSettingsField.CLONE_PVC_NAME]: {
+        isHidden: asHidden(!(isPvc && hasPVCns), VMSettingsField.CLONE_PVC_NS),
+      },
     }),
   );
 };
@@ -272,9 +343,33 @@ const flavorUpdater = ({ id, prevState, dispatch, getState }: UpdateOptions) =>
   );
 };
 
+const cloneSourceUpdater = ({ id, prevState, dispatch, getState }: UpdateOptions) => {
+  const state = getState();
+  if (!hasProvisionStorageChanged(prevState, state, id)) {
+    return;
+  }
+  const provisionStorage = iGetProvisionSourceStorage(state, id);
+  const storage = toShallowJS<VMWizardStorage>(provisionStorage);
+  if (!storage?.dataVolume) {
+    return;
+  }
+  const dataVolumeWrapper = new DataVolumeWrapper(storage.dataVolume);
+
+  dispatch(
+    vmWizardInternalActions[InternalActionType.UpdateVmSettings](id, {
+      [VMSettingsField.CLONE_PVC_NAME]: {
+        isHidden: asHidden(
+          !dataVolumeWrapper.getPersistentVolumeClaimNamespace(),
+          VMSettingsField.CLONE_PVC_NS,
+        ),
+      },
+    }),
+  );
+};
+
 export const updateVmSettingsState = (options: UpdateOptions) =>
   [
-    selectUserTemplateOnLoadedUpdater,
+    selectTemplateOnLoadedUpdater,
     osUpdater,
     baseImageUpdater,
     cloneCommonBaseDiskImageUpdater,
@@ -283,6 +378,7 @@ export const updateVmSettingsState = (options: UpdateOptions) =>
     nativeK8sUpdater,
     flavorUpdater,
     commonTemplatesUpdater,
+    cloneSourceUpdater,
   ].forEach((updater) => {
     updater && updater(options);
   });
