@@ -2,17 +2,19 @@ import { Map as ImmutableMap } from 'immutable';
 import { TemplateKind } from '@console/internal/module/k8s';
 import { ITemplate } from '../../../types/template';
 import { getTemplateOperatingSystems } from '../../../selectors/vm-template/advanced';
-import { concatImmutableLists, immutableListToShallowJS } from '../../../utils/immutable';
+import { immutableListToShallowJS, toShallowJS } from '../../../utils/immutable';
 import { operatingSystemsNative } from '../../../constants/vm-templates/os';
 
-export const getOS = ({ osID, iUserTemplates, openshiftFlag, iCommonTemplates }: GetOSParams) => {
-  const operatingSystems = openshiftFlag
-    ? getTemplateOperatingSystems(
-        immutableListToShallowJS<TemplateKind>(
-          concatImmutableLists(iUserTemplates, iCommonTemplates),
-        ),
-      )
-    : operatingSystemsNative;
+export const getOS = ({ osID, iUserTemplate, openshiftFlag, iCommonTemplates }: GetOSParams) => {
+  let operatingSystems = [];
+
+  if (openshiftFlag && iUserTemplate) {
+    operatingSystems = getTemplateOperatingSystems([toShallowJS(iUserTemplate)]);
+  } else {
+    operatingSystems = openshiftFlag
+      ? getTemplateOperatingSystems(immutableListToShallowJS<TemplateKind>(iCommonTemplates))
+      : operatingSystemsNative;
+  }
 
   return {
     osID,
@@ -22,7 +24,7 @@ export const getOS = ({ osID, iUserTemplates, openshiftFlag, iCommonTemplates }:
 
 type GetOSParams = {
   osID: string;
-  iUserTemplates: ImmutableMap<string, ITemplate>;
+  iUserTemplate: ITemplate;
   iCommonTemplates: ImmutableMap<string, ITemplate>;
   openshiftFlag: boolean;
 };
