@@ -1,8 +1,12 @@
 import * as React from 'react';
-import { FormGroup } from '@patternfly/react-core';
+import { useTranslation } from 'react-i18next';
+import { FormGroup, Popover, PopoverPosition } from '@patternfly/react-core';
 import { HelpIcon } from '@patternfly/react-icons';
 import { LoadingInline } from '@console/internal/components/utils';
-import { PopoverStatus, ValidationErrorType } from '@console/shared';
+import { ValidationErrorType, ValidationObject } from '@console/shared';
+
+import { preventDefault } from './utils';
+
 import './form-row.scss';
 
 export const FormRow: React.FC<FormRowProps> = ({
@@ -18,37 +22,43 @@ export const FormRow: React.FC<FormRowProps> = ({
   children,
   className,
 }) => {
+  const { t } = useTranslation();
   if (isHidden) {
     return null;
   }
   const type = (validation && validation.type) || validationType;
-  const message = (validation && validation.message) || validationMessage;
+  const message = validation?.messageKey ? t(validation.messageKey) : validationMessage;
 
   return (
     <FormGroup
       label={title}
       isRequired={isRequired}
       fieldId={fieldId}
-      isValid={type !== ValidationErrorType.Error}
+      validated={type !== ValidationErrorType.Error ? 'default' : 'error'}
       helperTextInvalid={type === ValidationErrorType.Error ? message : undefined}
       helperText={
         type === ValidationErrorType.Info || type === ValidationErrorType.Warn ? message : undefined
       }
       className={className}
-    >
-      {help && (
-        <span className="kubevirt-form-row__icon-status-container">
-          <PopoverStatus
-            icon={<HelpIcon className="kubevirt-form-row__help-icon--hidden" />}
-            activeIcon={<HelpIcon />}
-            title={`${fieldId} help`}
-            iconOnly
-            hideHeader
+      labelIcon={
+        help && (
+          <Popover
+            position={PopoverPosition.right}
+            aria-label={`${fieldId} help`}
+            bodyContent={help}
           >
-            {help}
-          </PopoverStatus>
-        </span>
-      )}
+            <button
+              type="button"
+              onClick={preventDefault}
+              className="pf-c-form__group-label-help"
+              aria-label={`${fieldId} help`}
+            >
+              <HelpIcon noVerticalAlign />
+            </button>
+          </Popover>
+        )
+      }
+    >
       {isLoading && (
         <span className="kubevirt-form-row__loading-container">
           <LoadingInline />
@@ -69,10 +79,7 @@ type FormRowProps = {
   isLoading?: boolean;
   validationMessage?: string;
   validationType?: ValidationErrorType;
-  validation?: {
-    message?: string;
-    type?: ValidationErrorType;
-  };
+  validation?: ValidationObject;
   children?: React.ReactNode;
   className?: string;
 };
