@@ -1,12 +1,14 @@
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 import {
-  Alert,
-  AlertVariant,
   Form,
   FormSelect,
   FormSelectOption,
   TextInput,
-  Expandable,
+  ExpandableSection,
+  SelectOption,
+  Stack,
+  StackItem,
 } from '@patternfly/react-core';
 import {
   FirehoseResult,
@@ -19,8 +21,8 @@ import {
   PersistentVolumeClaimModel,
   StorageClassModel,
 } from '@console/internal/models';
-import { getName } from '@console/shared/src';
-import { getLoadedData, isLoaded, prefixedID } from '../../../utils';
+import { getName, getAnnotations } from '@console/shared/src';
+import { getLoadedData, isLoaded, prefixedID, resolveDataVolumeName } from '../../../utils';
 import { validateDisk } from '../../../utils/validations/vm';
 import { isValidationError } from '../../../utils/validations/common';
 import { FormRow } from '../../form/form-row';
@@ -31,21 +33,24 @@ import {
 import {
   getDefaultSCAccessModes,
   getDefaultSCVolumeMode,
+  getDefaultStorageClass,
+  isConfigMapContainsScModes,
 } from '../../../selectors/config-map/sc-defaults';
-import {
-  ADD,
-  DYNAMIC,
-  EDIT,
-  getDialogUIError,
-  getSequenceName,
-  SAVE,
-} from '../../../utils/strings';
+import { DYNAMIC, getDialogUIError, getSequenceName } from '../../../utils/strings';
 import { ModalFooter } from '../modal/modal-footer';
 import { useShowErrorToggler } from '../../../hooks/use-show-error-toggler';
 import { DiskWrapper } from '../../../k8s/wrapper/vm/disk-wrapper';
 import { DataVolumeWrapper } from '../../../k8s/wrapper/vm/data-volume-wrapper';
 import { VolumeWrapper } from '../../../k8s/wrapper/vm/volume-wrapper';
-import { AccessMode, DiskBus, DiskType, VolumeMode } from '../../../constants/vm/storage';
+import {
+  AccessMode,
+  DataVolumeSourceType,
+  DiskBus,
+  DiskType,
+  VolumeMode,
+  VolumeType,
+} from '../../../constants/vm/storage';
+import { DEFAULT_SC_ANNOTATION } from '../../../constants/sc';
 import { getPvcStorageSize } from '../../../selectors/pvc/selectors';
 import { K8sResourceSelectRow } from '../../form/k8s-resource-select-row';
 import { SizeUnitFormRow } from '../../form/size-unit-form-row';
@@ -54,11 +59,20 @@ import { PersistentVolumeClaimWrapper } from '../../../k8s/wrapper/vm/persistent
 import { BinaryUnit, stringValueUnitSplit } from '../../form/size-unit-utils';
 import { StorageUISource } from './storage-ui-source';
 import { TemplateValidations } from '../../../utils/validations/template/template-validations';
-import { ConfigMapKind } from '@console/internal/module/k8s';
+import {
+  ConfigMapKind,
+  StorageClassResourceKind,
+  PersistentVolumeClaimKind,
+} from '@console/internal/module/k8s';
 import { UIStorageEditConfig } from '../../../types/ui/storage';
 import { isFieldDisabled } from '../../../utils/ui/edit-config';
+import { PendingChangesAlert } from '../../Alerts/PendingChangesAlert';
+import { FormPFSelect } from '../../form/form-pf-select';
 
 import './disk-modal.scss';
+import { URLSourceHelp } from '../../form/helper/url-source-help';
+import { ContainerSourceHelp } from '../../form/helper/container-source-help';
+import { ConfigMapDefaultModesAlert } from '../../Alerts/ConfigMapDefaultModesAlert';
 
 export const DiskModal = withHandlePromise((props: DiskModalProps) => {
   const {
@@ -72,7 +86,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     namespaces,
     onNamespaceChanged,
     usedDiskNames,
-    isCreateTemplate,
+    isTemplate = false,
     onSubmit,
     inProgress: _inProgress,
     isEditing,
@@ -83,7 +97,9 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     templateValidations,
     storageClassConfigMap: _storageClassConfigMap,
     editConfig,
+    isVMRunning,
   } = props;
+  const { t } = useTranslation();
   const inProgress = _inProgress || !isLoaded(_storageClassConfigMap);
   const isDisabled = (fieldName: string, disabled?: boolean) =>
     inProgress || disabled || isFieldDisabled(editConfig, fieldName);
@@ -96,9 +112,6 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
   const dataVolume = props.dataVolume || new DataVolumeWrapper();
   const tValidations = templateValidations || new TemplateValidations();
 
-  const validAllowedBuses = tValidations.getAllowedBuses(disk.getType());
-  const recommendedBuses = tValidations.getRecommendedBuses(disk.getType());
-
   const combinedDisk = new CombinedDisk({
     diskWrapper: disk,
     volumeWrapper: volume,
@@ -108,7 +121,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
   });
   const combinedDiskSize = combinedDisk.getSize();
 
-  const type = disk.getType() || DiskType.DISK;
+  const [type, setType] = React.useState<DiskType>(disk.getType() || DiskType.DISK);
 
   const [source, setSource] = React.useState<StorageUISource>(
     combinedDisk.getInitialSource(isEditing),
@@ -117,7 +130,9 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
   const [url, setURL] = React.useState<string>(dataVolume.getURL());
 
   const [containerImage, setContainerImage] = React.useState<string>(
-    volume.getContainerImage() || '',
+    volume.getType() === VolumeType.CONTAINER_DISK
+      ? volume.getContainerImage()
+      : dataVolume.getContainer() || '',
   );
 
   const [pvcName, setPVCName] = React.useState<string>(combinedDisk.getPVCNameBySource(source));
@@ -125,13 +140,18 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
   const [name, setName] = React.useState<string>(
     disk.getName() || getSequenceName('disk', usedDiskNames),
   );
+
+  const validAllowedBuses = tValidations.getAllowedBuses(
+    isEditing ? DiskType.DISK : disk.getType(),
+  );
+  const recommendedBuses = tValidations.getRecommendedBuses(
+    isEditing ? DiskType.DISK : disk.getType(),
+  );
+  const allowedBuses = [...validAllowedBuses].filter((b) => type.isBusSupported(b));
+
   const [bus, setBus] = React.useState<DiskBus>(
     disk.getDiskBus() ||
-      (isEditing
-        ? null
-        : validAllowedBuses.has(DiskBus.VIRTIO)
-        ? DiskBus.VIRTIO
-        : [...validAllowedBuses][0]),
+      (isEditing ? null : validAllowedBuses.has(DiskBus.VIRTIO) ? DiskBus.VIRTIO : allowedBuses[0]),
   );
   const [storageClassName, setStorageClassName] = React.useState<string>(
     combinedDisk.getStorageClassName() || '',
@@ -155,16 +175,47 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
   );
 
   React.useEffect(() => {
-    if (!isEditing && isLoaded(_storageClassConfigMap)) {
-      if (source.requiresVolumeMode()) {
-        setVolumeMode(getDefaultSCVolumeMode(storageClassConfigMap));
+    if (source.requiresPVC()) {
+      const pvcNameDataVolume = dataVolume.getPersistentVolumeClaimName();
+      const pvcNamespaceDataVolume = dataVolume.getPersistentVolumeClaimNamespace();
+      const pvc = persistentVolumeClaims?.data.find(
+        ({ metadata }) =>
+          metadata?.name === pvcNameDataVolume && metadata?.namespace === pvcNamespaceDataVolume,
+      );
+      setVolumeMode((value) => VolumeMode.fromString(pvc?.spec?.volumeMode) || value);
+    }
+  }, [dataVolume, persistentVolumeClaims, source]);
+
+  const [defaultAccessMode, defaultVolumeMode, isScModesKnown] = React.useMemo(() => {
+    return [
+      getDefaultSCAccessModes(storageClassConfigMap, storageClassName)?.[0],
+      getDefaultSCVolumeMode(storageClassConfigMap, storageClassName),
+      isConfigMapContainsScModes(storageClassConfigMap, storageClassName),
+    ];
+  }, [storageClassConfigMap, storageClassName]);
+
+  React.useEffect(() => {
+    if (!isEditing) {
+      let defaultStorageClass = null;
+
+      if (!storageClassName) {
+        defaultStorageClass = getDefaultStorageClass(getLoadedData(storageClasses, []));
+
+        if (defaultStorageClass) {
+          setStorageClassName(getName(defaultStorageClass) || '');
+        }
       }
-      if (source.requiresAccessModes()) {
-        setAccessMode(getDefaultSCAccessModes(storageClassConfigMap)[0]);
+
+      if (defaultAccessMode) {
+        setVolumeMode(defaultVolumeMode);
+      }
+
+      if (defaultVolumeMode) {
+        setAccessMode(defaultAccessMode);
       }
     }
     // eslint-disable-next-line react-hooks/exhaustive-deps
-  }, [isLoaded(_storageClassConfigMap)]);
+  }, [defaultAccessMode, defaultVolumeMode, storageClassName, storageClasses]);
 
   const resultDisk = DiskWrapper.initializeFromSimpleData({
     name,
@@ -172,7 +223,12 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     type,
   });
 
-  const resultDataVolumeName = prefixedID(vmName, name);
+  // We can generate a random name every time, because this modal should not operate on disks with live datavolumes
+  const resultDataVolumeName = resolveDataVolumeName({
+    diskName: name,
+    vmLikeEntityName: vmName,
+    isTemplate,
+  });
 
   const resultVolume = VolumeWrapper.initializeFromSimpleData({
     name,
@@ -186,14 +242,19 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
 
   let resultDataVolume;
   if (source.requiresDatavolume()) {
-    resultDataVolume = DataVolumeWrapper.initializeFromSimpleData({
-      name: resultDataVolumeName,
-      storageClassName: storageClassName || null, // || null is to enable merging
-      type: source.getDataVolumeSourceType(),
-      size,
-      unit,
-      typeData: { name: pvcName, namespace, url },
-    })
+    resultDataVolume = new DataVolumeWrapper()
+      .init({
+        name: resultDataVolumeName,
+        unit,
+        size,
+        storageClassName: storageClassName || null, // || null is to enable merging
+      })
+      .setType(source.getDataVolumeSourceType(), {
+        name: pvcName,
+        namespace,
+        url:
+          source.getDataVolumeSourceType() === DataVolumeSourceType.REGISTRY ? containerImage : url,
+      })
       .setVolumeMode(volumeMode || null)
       .setAccessModes(accessMode ? [accessMode] : null);
   }
@@ -219,6 +280,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
       pvc: pvcValidation,
       diskInterface: busValidation,
       url: urlValidation,
+      type: typeValidation,
     },
     isValid,
     hasAllRequiredFilled,
@@ -238,10 +300,10 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     e.preventDefault();
 
     if (isValid) {
-      // eslint-disable-next-line promise/catch-or-return
       handlePromise(
         onSubmit(resultDisk, resultVolume, resultDataVolume, resultPersistentVolumeClaim),
-      ).then(close);
+        close,
+      );
     } else {
       setShowUIError(true);
     }
@@ -275,7 +337,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     }
   };
 
-  const onSourceChanged = (uiSource) => {
+  const onSourceChanged = (e, uiSource) => {
     setSize('');
     setUnit('Gi');
     setURL('');
@@ -302,19 +364,41 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
     setAdvancedDrawerIsOpen(!advancedDrawerIsOpen);
   };
 
+  const onTypeChanged = (diskType) => {
+    const newType = DiskType.fromString(diskType);
+    setType(newType);
+    if (newType === DiskType.CDROM && source === StorageUISource.BLANK) {
+      onSourceChanged(null, StorageUISource.URL.getValue());
+    }
+    if (newType === DiskType.CDROM && bus === DiskBus.VIRTIO) {
+      setBus(DiskBus.SATA);
+    }
+  };
+
+  const isStorageClassDataLoading = !isLoaded(storageClasses) || !isLoaded(_storageClassConfigMap);
+
   return (
     <div className="modal-content">
       <ModalTitle>
-        {isEditing ? EDIT : ADD} {type.toString()}
+        {isEditing ? t('kubevirt-plugin~Edit') : t('kubevirt-plugin~Add')}{' '}
+        {t('kubevirt-plugin~{{type}}', { type: type.toString() })}
       </ModalTitle>
       <ModalBody>
+        {isVMRunning && (
+          <PendingChangesAlert
+            warningMsg={t(
+              'kubevirt-plugin~The changes you are making require this virtual machine to be updated. Restart this VM to apply these changes.',
+            )}
+          />
+        )}
         <Form>
-          <FormRow title="Source" fieldId={asId('source')} isRequired>
-            <FormSelect
-              onChange={onSourceChanged}
-              value={asFormSelectValue(source)}
-              id={asId('source')}
+          <FormRow title={t('kubevirt-plugin~Source')} fieldId={asId('source')} isRequired>
+            <FormPFSelect
+              menuAppendTo={() => document.body}
               isDisabled={isDisabled('source', !source.canBeChangedToThisSource(type))}
+              selections={asFormSelectValue(t(source.toString()))}
+              onSelect={onSourceChanged}
+              toggleId={asId('select-source')}
             >
               {StorageUISource.getAll()
                 .filter(
@@ -322,46 +406,56 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
                     storageUISource.canBeChangedToThisSource(type) ||
                     !source.canBeChangedToThisSource(type),
                 )
+                .sort((a, b) => a.getOrder() - b.getOrder())
                 .map((uiType) => {
                   return (
-                    <FormSelectOption
+                    <SelectOption
                       key={uiType.getValue()}
                       value={uiType.getValue()}
-                      label={uiType.toString()}
-                    />
+                      description={t(uiType.getDescriptionKey())}
+                    >
+                      {t(uiType.toString())}
+                    </SelectOption>
                   );
                 })}
-            </FormSelect>
+            </FormPFSelect>
           </FormRow>
           {source.requiresURL() && (
-            <FormRow title="URL" fieldId={asId('url')} isRequired validation={urlValidation}>
+            <FormRow
+              title={t('kubevirt-plugin~URL')}
+              fieldId={asId('url')}
+              isRequired
+              validation={urlValidation}
+            >
               <TextInput
-                isValid={!isValidationError(urlValidation)}
+                validated={!isValidationError(urlValidation) ? 'default' : 'error'}
                 key="url"
                 isDisabled={isDisabled('url')}
                 isRequired
                 id={asId('url')}
                 value={url}
-                onChange={(v) => setURL(v)}
+                onChange={setURL}
               />
+              <URLSourceHelp />
             </FormRow>
           )}
           {source.requiresContainerImage() && (
             <FormRow
-              title="Container"
+              title={t('kubevirt-plugin~Container')}
               fieldId={asId('container')}
               isRequired
               validation={containerValidation}
             >
               <TextInput
-                isValid={!isValidationError(containerValidation)}
+                validated={!isValidationError(containerValidation) ? 'default' : 'error'}
                 key="container"
                 isDisabled={isDisabled('container')}
                 isRequired
                 id={asId('container')}
                 value={containerImage}
-                onChange={(v) => setContainerImage(v)}
+                onChange={setContainerImage}
               />
+              <ContainerSourceHelp />
             </FormRow>
           )}
           {source.requiresNamespace() && (
@@ -396,18 +490,15 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
             />
           )}
           <FormRow
-            title="Name"
+            title={t('kubevirt-plugin~Name')}
             fieldId={asId('name')}
             isRequired
             isLoading={!usedDiskNames}
             validation={nameValidation}
           >
             <TextInput
-              isValid={!isValidationError(nameValidation)}
-              isDisabled={isDisabled(
-                'name',
-                !usedDiskNames || !source.isNameEditingSupported(type),
-              )}
+              validated={!isValidationError(nameValidation) ? 'default' : 'error'}
+              isDisabled={isDisabled('name', !usedDiskNames)}
               isRequired
               id={asId('name')}
               value={name}
@@ -417,6 +508,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
 
           {source.requiresSize() && (
             <SizeUnitFormRow
+              title={t('kubevirt-plugin~Size')}
               key="size-row"
               id={asId('size-row')}
               size={size}
@@ -437,7 +529,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
             />
           )}
           {!source.requiresSize() && source.hasDynamicSize() && (
-            <FormRow title="Size" fieldId={asId('dynamic-size-row')}>
+            <FormRow title={t('kubevirt-plugin~Size')} fieldId={asId('dynamic-size-row')}>
               <TextInput
                 key="dynamic-size-row"
                 isDisabled
@@ -447,124 +539,179 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
             </FormRow>
           )}
           <FormRow
-            title="Interface"
+            title={t('kubevirt-plugin~Type')}
+            fieldId={asId('type')}
+            validation={typeValidation}
+            isRequired
+          >
+            <FormSelect
+              onChange={onTypeChanged}
+              value={asFormSelectValue(type.getValue())}
+              id={asId('type')}
+              isDisabled={isDisabled('type')}
+            >
+              <FormSelectPlaceholderOption
+                isDisabled
+                placeholder={t('kubevirt-plugin~--- Select Type ---')}
+              />
+              {DiskType.getAll()
+                .filter((dtype) => !dtype.isDeprecated() || dtype === type)
+                .map((dt) => (
+                  <FormSelectOption
+                    key={dt.getValue()}
+                    value={dt.getValue()}
+                    label={dt.toString()}
+                  />
+                ))}
+            </FormSelect>
+          </FormRow>
+          <FormRow
+            title={t('kubevirt-plugin~Interface')}
             fieldId={asId('interface')}
             isRequired
             validation={busValidation}
           >
-            <FormSelect
-              onChange={React.useCallback((diskBus) => setBus(DiskBus.fromString(diskBus)), [
-                setBus,
-              ])}
-              isValid={!isValidationError(busValidation)}
-              value={asFormSelectValue(bus)}
-              id={asId('interface')}
+            <FormPFSelect
+              menuAppendTo={() => document.body}
               isDisabled={isDisabled('interface')}
-            >
-              <FormSelectPlaceholderOption isDisabled placeholder="--- Select Interface ---" />
-              {!validAllowedBuses.has(bus) && (
-                <FormSelectOption
-                  isDisabled
-                  key={bus.getValue()}
-                  value={bus.getValue()}
-                  label={bus.toString()}
-                />
+              selections={asFormSelectValue(t(bus.toString()))}
+              onSelect={React.useCallback(
+                (e, diskBus) => setBus(DiskBus.fromString(diskBus.toString())),
+                [setBus],
               )}
-              {[...validAllowedBuses].map((b) => (
-                <FormSelectOption
+              toggleId={asId('select-interface')}
+            >
+              {allowedBuses.map((b) => (
+                <SelectOption
                   key={b.getValue()}
                   value={b.getValue()}
-                  label={`${b.toString()}${
-                    recommendedBuses.size !== validAllowedBuses.size && recommendedBuses.has(b)
-                      ? ' --- Recommended ---'
-                      : ''
-                  }`}
-                />
+                  description={t(b.getDescriptionKey())}
+                >
+                  {t(b.toString())}
+                  {recommendedBuses.size !== validAllowedBuses.size && recommendedBuses.has(b)
+                    ? t('kubevirt-plugin~ --- Recommended ---')
+                    : ''}
+                </SelectOption>
               ))}
-            </FormSelect>
+            </FormPFSelect>
           </FormRow>
           {source.requiresStorageClass() && (
             <K8sResourceSelectRow
+              title={t('kubevirt-plugin~Storage Class')}
               key="storage-class"
               id={asId('storage-class')}
-              isDisabled={isDisabled('storageClass')}
+              isDisabled={isDisabled('storageClass') || isStorageClassDataLoading}
               name={storageClassName}
               data={storageClasses}
               model={StorageClassModel}
               hasPlaceholder
               onChange={(sc) => onStorageClassNameChanged(sc || '')}
-            />
-          )}
-          {source.isPlainDataVolume(isCreateTemplate) && (
-            <Alert
-              variant={AlertVariant.warning}
-              isInline
-              title="PVC will be created on template creation and used by VMs created from this template."
+              getResourceLabel={(sc) =>
+                getAnnotations(sc, {})[DEFAULT_SC_ANNOTATION] === 'true'
+                  ? t('kubevirt-plugin~{{name}} (default)', { name: getName(sc) })
+                  : getName(sc)
+              }
             />
           )}
           {source.requiresVolumeModeOrAccessModes() && (
-            <Expandable
-              toggleText="Advanced"
+            <ExpandableSection
+              toggleText={t('kubevirt-plugin~Advanced')}
               isExpanded={advancedDrawerIsOpen}
               onToggle={onToggleAdvancedDrawer}
               className="disk-advanced-drawer"
             >
-              {source.requiresVolumeMode() && (
-                <FormRow title="Volume Mode" fieldId={asId('volume-mode')}>
-                  <FormSelect
-                    onChange={(vMode) => setVolumeMode(VolumeMode.fromString(vMode))}
-                    value={asFormSelectValue(volumeMode?.getValue())}
-                    id={asId('volume-mode')}
-                    isDisabled={isDisabled('volumeMode')}
-                  >
-                    <FormSelectPlaceholderOption
-                      isDisabled={inProgress}
-                      placeholder="--- Select Volume Mode ---"
-                    />
-                    {VolumeMode.getAll().map((v) => (
-                      <FormSelectOption
-                        key={v.getValue()}
-                        value={v.getValue()}
-                        label={`${v.toString()}`}
-                      />
-                    ))}
-                  </FormSelect>
-                </FormRow>
-              )}
-              {source.requiresAccessModes() && (
-                <FormRow
-                  title="Access Mode"
-                  fieldId={asId('access-mode')}
-                  className="disk-access-mode"
-                >
-                  <FormSelect
-                    onChange={(aMode) => setAccessMode(AccessMode.fromString(aMode))}
-                    value={asFormSelectValue(accessMode?.getValue())}
-                    id={asId('access-mode')}
-                    isDisabled={isDisabled('accessMode')}
-                  >
-                    <FormSelectPlaceholderOption
-                      isDisabled={inProgress}
-                      placeholder="--- Select Access Mode ---"
-                    />
-                    {AccessMode.getAll().map((a) => (
-                      <FormSelectOption
-                        key={a.getValue()}
-                        value={a.getValue()}
-                        label={a.toString()}
-                      />
-                    ))}
-                  </FormSelect>
-                </FormRow>
-              )}
-            </Expandable>
+              <Stack hasGutter>
+                <StackItem>
+                  {source.requiresVolumeMode() && (
+                    <FormRow title={t('kubevirt-plugin~Volume Mode')} fieldId={asId('volume-mode')}>
+                      <FormSelect
+                        onChange={(vMode) => setVolumeMode(VolumeMode.fromString(vMode))}
+                        value={asFormSelectValue(volumeMode?.getValue())}
+                        id={asId('volume-mode')}
+                        isDisabled={
+                          isDisabled('volumeMode') ||
+                          isStorageClassDataLoading ||
+                          source.requiresPVC()
+                        }
+                      >
+                        <FormSelectPlaceholderOption
+                          isDisabled={inProgress}
+                          placeholder={t('kubevirt-plugin~--- Select Volume Mode ---')}
+                        />
+                        {VolumeMode.getAll().map((v) => (
+                          <FormSelectOption
+                            key={v.getValue()}
+                            value={v.getValue()}
+                            label={v.toString().concat(
+                              v.getValue() !== defaultVolumeMode.getValue() && isScModesKnown
+                                ? t(
+                                    'kubevirt-plugin~ - Not recommended for {{storageClassName}} storage class',
+                                    {
+                                      storageClassName,
+                                    },
+                                  )
+                                : '',
+                            )}
+                          />
+                        ))}
+                      </FormSelect>
+                      {source.requiresPVC() && (
+                        <div className="pf-c-form__helper-text" aria-live="polite">
+                          {t('kubevirt-plugin~Volume Mode is set by Source PVC')}
+                        </div>
+                      )}
+                    </FormRow>
+                  )}
+                  {source.requiresAccessModes() && (
+                    <FormRow
+                      title={t('kubevirt-plugin~Access Mode')}
+                      fieldId={asId('access-mode')}
+                      className="disk-access-mode"
+                    >
+                      <FormSelect
+                        onChange={(aMode) => setAccessMode(AccessMode.fromString(aMode))}
+                        value={asFormSelectValue(accessMode?.getValue())}
+                        id={asId('access-mode')}
+                        isDisabled={isDisabled('accessMode') || isStorageClassDataLoading}
+                      >
+                        <FormSelectPlaceholderOption
+                          isDisabled={inProgress}
+                          placeholder={t('kubevirt-plugin~--- Select Access Mode ---')}
+                        />
+                        {AccessMode.getAll().map((a) => (
+                          <FormSelectOption
+                            key={a.getValue()}
+                            value={a.getValue()}
+                            label={a.toString().concat(
+                              a.getValue() !== defaultAccessMode.getValue() && isScModesKnown
+                                ? t(
+                                    'kubevirt-plugin~ - Not recommended for {{storageClassName}} storage class',
+                                    {
+                                      storageClassName,
+                                    },
+                                  )
+                                : '',
+                            )}
+                          />
+                        ))}
+                      </FormSelect>
+                    </FormRow>
+                  )}
+                </StackItem>
+                <StackItem>
+                  <ConfigMapDefaultModesAlert isScModesKnown={isScModesKnown} />
+                </StackItem>
+              </Stack>
+            </ExpandableSection>
           )}
         </Form>
       </ModalBody>
       <ModalFooter
         id="disk"
-        submitButtonText={isEditing ? SAVE : ADD}
-        errorMessage={errorMessage || (showUIError ? getDialogUIError(hasAllRequiredFilled) : null)}
+        submitButtonText={isEditing ? t('kubevirt-plugin~Save') : t('kubevirt-plugin~Add')}
+        errorMessage={
+          errorMessage || (showUIError ? getDialogUIError(hasAllRequiredFilled, t) : null)
+        }
         isDisabled={inProgress}
         inProgress={inProgress}
         isSimpleError={showUIError}
@@ -581,7 +728,7 @@ export const DiskModal = withHandlePromise((props: DiskModalProps) => {
 export type DiskModalProps = {
   disk?: DiskWrapper;
   showInitialValidation?: boolean;
-  isCreateTemplate?: boolean;
+  isTemplate?: boolean;
   isEditing?: boolean;
   volume?: VolumeWrapper;
   dataVolume?: DataVolumeWrapper;
@@ -594,8 +741,8 @@ export type DiskModalProps = {
     persistentVolumeClaim: PersistentVolumeClaimWrapper,
   ) => Promise<any>;
   namespaces?: FirehoseResult;
-  storageClasses?: FirehoseResult;
-  persistentVolumeClaims?: FirehoseResult;
+  storageClasses?: FirehoseResult<StorageClassResourceKind[]>;
+  persistentVolumeClaims?: FirehoseResult<PersistentVolumeClaimKind[]>;
   vmName: string;
   vmNamespace: string;
   namespace: string;
@@ -604,5 +751,6 @@ export type DiskModalProps = {
   usedDiskNames: Set<string>;
   usedPVCNames: Set<string>;
   editConfig?: UIStorageEditConfig;
+  isVMRunning?: boolean;
 } & ModalComponentProps &
   HandlePromiseProps;
