@@ -1,3 +1,3 @@
 export * from './modal-resource-launcher';
-export * from './vm-description-modal';
+export * from './description-modal';
 export * from './vm-flavor-modal';
