@@ -1,14 +1,17 @@
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
+import { TFunction } from 'i18next';
+import { Button, Popover } from '@patternfly/react-core';
+import { sortable } from '@patternfly/react-table';
+import { QuestionCircleIcon } from '@patternfly/react-icons';
 import { RowFunction, Table, MultiListPage } from '@console/internal/components/factory';
 import { PersistentVolumeClaimModel, TemplateModel } from '@console/internal/models';
-import { Firehose, FirehoseResult, EmptyBox } from '@console/internal/components/utils';
+import { Firehose, FirehoseResult } from '@console/internal/components/utils';
 import { useSafetyFirst } from '@console/internal/components/safety-first';
 import { K8sResourceKind, TemplateKind } from '@console/internal/module/k8s';
 import { dimensifyHeader, getNamespace } from '@console/shared';
-import { sortable } from '@patternfly/react-table';
-import { DataVolumeModel } from '../../models';
+import { DataVolumeModel, VirtualMachineModel, VirtualMachineInstanceModel } from '../../models';
 import { VMGenericLikeEntityKind } from '../../types/vmLike';
-import { VMLikeEntityTabProps } from '../vms/types';
 import { getResource, getLoadedData } from '../../utils';
 import { wrapWithProgress } from '../../utils/utils';
 import { diskModalEnhanced } from '../modals/disk-modal/disk-modal-enhanced';
@@ -17,14 +20,21 @@ import { V1alpha1DataVolume } from '../../types/vm/disk/V1alpha1DataVolume';
 import { StorageBundle } from './types';
 import { DiskRow } from './disk-row';
 import { diskTableColumnClasses } from './utils';
-import { isVMI } from '../../selectors/check-type';
-import { ADD_DISK } from '../../utils/strings';
+import { isVMI, isVM } from '../../selectors/check-type';
 import {
   getVMTemplateNamespacedName,
   getTemplateValidationsFromTemplate,
 } from '../../selectors/vm-template/selectors';
 import { diskSourceFilter } from './table-filters';
-import { asVM, isVMRunningOrExpectedRunning } from '../../selectors/vm';
+import { VMLikeEntityTabProps, VMTabProps } from '../vms/types';
+import { getVMStatus } from '../../statuses/vm/vm-status';
+import { FileSystemsList } from './guest-agent-file-systems';
+import { isVMRunningOrExpectedRunning } from '../../selectors/vm/selectors';
+import { asVM } from '../../selectors/vm';
+import { VMIKind } from '../../types';
+import { VMWrapper } from '../../k8s/wrapper/vm/vm-wrapper';
+import { VMIWrapper } from '../../k8s/wrapper/vm/vmi-wrapper';
+import { changedDisks } from '../../selectors/vm-like/next-run-changes';
 
 const getStoragesData = ({
   vmLikeEntity,
@@ -49,8 +59,8 @@ const getStoragesData = ({
     diskInterface: disk.getDiskInterface(),
     size: disk.getReadableSize(),
     storageClass: disk.getStorageClassName(),
-    type: disk.getType(),
     metadata: { name: disk.getName() },
+    type: disk.getType(),
   }));
 };
 
@@ -61,33 +71,36 @@ export type VMDisksTableProps = {
   loaded: boolean;
 };
 
-const NoDataEmptyMsg = () => <EmptyBox label="Disks" />;
-
-const getHeader = (columnClasses: string[]) => () =>
+const getHeader = (t: TFunction, columnClasses: string[]) => () =>
   dimensifyHeader(
     [
       {
-        title: 'Name',
+        title: t('kubevirt-plugin~Name'),
         sortField: 'name',
         transforms: [sortable],
       },
       {
-        title: 'Source',
+        title: t('kubevirt-plugin~Source'),
         sortField: 'source',
         transforms: [sortable],
       },
       {
-        title: 'Size',
+        title: t('kubevirt-plugin~Size'),
         sortField: 'size',
         transforms: [sortable],
       },
       {
-        title: 'Interface',
+        title: t('kubevirt-plugin~Drive'),
+        sortField: 'type',
+        transforms: [sortable],
+      },
+      {
+        title: t('kubevirt-plugin~Interface'),
         sortField: 'diskInterface',
         transforms: [sortable],
       },
       {
-        title: 'Storage Class',
+        title: t('kubevirt-plugin~Storage Class'),
         sortField: 'storageClass',
         transforms: [sortable],
       },
@@ -101,15 +114,40 @@ const getHeader = (columnClasses: string[]) => () =>
 export const VMDisksTable: React.FC<React.ComponentProps<typeof Table> | VMDisksTableProps> = (
   props,
 ) => {
+  const { t } = useTranslation();
   return (
-    <Table
-      {...props}
-      aria-label="VM Disks List"
-      NoDataEmptyMsg={NoDataEmptyMsg}
-      Header={getHeader(props?.customData?.columnClasses)}
-      Row={props.Row || DiskRow}
-      virtualize
-    />
+    <div>
+      {props?.customData?.showGuestAgentHelp && (
+        <>
+          <h3>
+            {t('kubevirt-plugin~Disks')}
+            <Popover
+              aria-label={t('kubevirt-plugin~Disks description')}
+              position="top"
+              bodyContent={
+                <>
+                  {t(
+                    'kubevirt-plugin~The following information is provided by the OpenShift Virtualization operator.',
+                  )}
+                </>
+              }
+            >
+              <Button variant="plain">
+                <QuestionCircleIcon />
+              </Button>
+            </Popover>
+          </h3>
+        </>
+      )}
+      <Table
+        {...props}
+        aria-label={t('kubevirt-plugin~VM Disks List')}
+        label={t('kubevirt-plugin~Disks')}
+        Header={getHeader(t, props?.customData?.columnClasses)}
+        Row={props.Row || DiskRow}
+        virtualize
+      />
+    </div>
   );
 };
 
@@ -118,13 +156,19 @@ type VMDisksProps = {
   pvcs?: FirehoseResult<K8sResourceKind[]>;
   datavolumes?: FirehoseResult<V1alpha1DataVolume[]>;
   vmTemplate?: FirehoseResult<TemplateKind>;
+  vmi?: VMIKind;
 };
 
-export const VMDisks: React.FC<VMDisksProps> = ({ vmLikeEntity, vmTemplate }) => {
+export const VMDisks: React.FC<VMDisksProps> = ({ vmLikeEntity, vmTemplate, vmi }) => {
+  const { t } = useTranslation();
   const namespace = getNamespace(vmLikeEntity);
   const [isLocked, setIsLocked] = useSafetyFirst(false);
   const withProgress = wrapWithProgress(setIsLocked);
   const templateValidations = getTemplateValidationsFromTemplate(getLoadedData(vmTemplate));
+  const isVMRunning = isVM(vmLikeEntity) && isVMRunningOrExpectedRunning(asVM(vmLikeEntity));
+  const pendingChangesDisks: Set<string> = vmi
+    ? new Set(changedDisks(new VMWrapper(asVM(vmLikeEntity)), new VMIWrapper(vmi)))
+    : null;
 
   const resources = [
     getResource(PersistentVolumeClaimModel, {
@@ -152,6 +196,7 @@ export const VMDisks: React.FC<VMDisksProps> = ({ vmLikeEntity, vmTemplate }) =>
         blocking: true,
         vmLikeEntity: !isVMI(vmLikeEntity) && vmLikeEntity,
         templateValidations,
+        isVMRunning,
       }).result,
     );
 
@@ -160,10 +205,10 @@ export const VMDisks: React.FC<VMDisksProps> = ({ vmLikeEntity, vmTemplate }) =>
       ListComponent={VMDisksTable}
       resources={resources}
       flatten={flatten}
-      createButtonText={ADD_DISK}
+      createButtonText={t('kubevirt-plugin~Add Disk')}
       canCreate={!isVMI(vmLikeEntity)}
       createProps={{
-        isDisabled: isLocked || isVMRunningOrExpectedRunning(asVM(vmLikeEntity)),
+        isDisabled: isLocked,
         onClick: createFn,
         id: 'add-disk',
       }}
@@ -174,6 +219,8 @@ export const VMDisks: React.FC<VMDisksProps> = ({ vmLikeEntity, vmTemplate }) =>
         isDisabled: isLocked,
         templateValidations,
         columnClasses: diskTableColumnClasses,
+        showGuestAgentHelp: true,
+        pendingChangesDisks,
       }}
       hideLabelFilter
     />
@@ -198,3 +245,56 @@ export const VMDisksFirehose: React.FC<VMLikeEntityTabProps> = ({ obj: vmLikeEnt
     </Firehose>
   );
 };
+
+export const VMDisksAndFileSystemsPage: React.FC<VMTabProps> = ({
+  obj: vmLikeEntity,
+  vm: vmProp,
+  vmis: vmisProp,
+  vmImports,
+  pods,
+  migrations,
+  pvcs,
+  dataVolumes,
+  customData: { kindObj },
+}) => {
+  const vmTemplate = getVMTemplateNamespacedName(vmLikeEntity);
+
+  const resources = [
+    getResource(TemplateModel, {
+      name: vmTemplate?.name,
+      namespace: vmTemplate?.namespace,
+      isList: false,
+      prop: 'vmTemplate',
+    }),
+  ];
+
+  const vm =
+    kindObj === VirtualMachineModel && isVM(vmLikeEntity)
+      ? vmLikeEntity
+      : isVM(vmProp)
+      ? vmProp
+      : null;
+  const vmi =
+    kindObj === VirtualMachineInstanceModel && isVMI(vmLikeEntity)
+      ? vmLikeEntity
+      : isVMI(vmisProp[0])
+      ? vmisProp[0]
+      : null;
+
+  const vmStatusBundle = getVMStatus({
+    vm,
+    vmi,
+    pods,
+    migrations,
+    pvcs,
+    dataVolumes,
+    vmImports,
+  });
+
+  return (
+    <Firehose resources={resources}>
+      <VMDisks vmLikeEntity={vmLikeEntity} vmi={vmi} />
+      <FileSystemsList vmi={vmi} vmStatusBundle={vmStatusBundle} />
+    </Firehose>
+  );
+};
