@@ -1,4 +1,5 @@
 import * as React from 'react';
+import { Trans, useTranslation } from 'react-i18next';
 import { AccessConsoles, VncConsole } from '@patternfly/react-console/dist/js';
 import { Alert, AlertActionCloseButton, Button, Stack, StackItem } from '@patternfly/react-core';
 import { Firehose, FirehoseResult, LoadingInline } from '@console/internal/components/utils';
@@ -38,6 +39,7 @@ import { ConsoleType } from '../../constants/vm/console-type';
 import { VolumeWrapper } from '../../k8s/wrapper/vm/volume-wrapper';
 import { CloudInitDataHelper } from '../../k8s/wrapper/vm/cloud-init-data-helper';
 import { CLOUD_INIT_MISSING_USERNAME } from '../../utils/strings';
+import { useRenderVNCConsole } from '../../hooks/use-render-vnc-console';
 
 const VMIsDown: React.FC = () => (
   <div className="co-m-pane__body">
@@ -74,10 +76,12 @@ const VMConsoles: React.FC<VMConsolesProps> = ({
   LoadingComponent,
   type,
   showOpenInNewWindow = true,
+  renderVNCConsole,
 }) => {
+  const { t } = useTranslation();
   const [showAlert, setShowAlert] = React.useState(true);
   const [showPassword, setShowPassword] = React.useState(false);
-  const showVNCOption = getIsGraphicsConsoleAttached(vm) !== false;
+  const showVNCOption = getIsGraphicsConsoleAttached(vm) !== false && renderVNCConsole;
   const showSerialOption = getIsSerialConsoleAttached(vm) !== false;
   const cloudInitVolume = getCloudInitVolume(vm);
   const data = new VolumeWrapper(cloudInitVolume).getCloudInitNoCloud();
@@ -100,8 +104,8 @@ const VMConsoles: React.FC<VMConsolesProps> = ({
   const vncServiceManual = (vnc && vnc.manual) || undefined;
   const rdpServiceManual = (rdp && rdp.manual) || undefined;
 
-  const vmName = getName(vm);
-  const namespace = getNamespace(vm);
+  const vmName = getName(vm) || getName(vmi);
+  const namespace = getNamespace(vm) || getNamespace(vmi);
   const typeNotSupported =
     (!showVNCOption && type === ConsoleType.VNC) ||
     (!showSerialOption && type === ConsoleType.SERIAL);
@@ -127,7 +131,6 @@ const VMConsoles: React.FC<VMConsolesProps> = ({
       guestAgent={isGuestAgentConnected(vmi)}
     />
   ) : null;
-
   return (
     <Stack hasGutter>
       {showOpenInNewWindow && consoleType && (
@@ -142,30 +145,33 @@ const VMConsoles: React.FC<VMConsolesProps> = ({
               )
             }
           >
-            Open Console in new Window
+            {t('kubevirt-plugin~Open Console in new Window')}
           </Button>
         </StackItem>
       )}
       {cloudInitPassword && (
         <StackItem>
-          <Alert variant="info" isInline title="Guest login credentials">
-            The following credentials for this operating system were created via{' '}
-            <strong>Cloud-init</strong>. If unsuccessful cloud-init could be improperly configured.
-            Please contact the image provider for more information.
+          <Alert variant="info" isInline title={t('kubevirt-plugin~Guest login credentials')}>
+            <Trans ns="kubevirt-plugin">
+              The following credentials for this operating system were created via{' '}
+              <strong>Cloud-init</strong>. If unsuccessful cloud-init could be improperly
+              configured. Please contact the image provider for more information.
+            </Trans>
             <p>
-              <strong>User name: </strong> {cloudInitUsername || CLOUD_INIT_MISSING_USERNAME}
+              <strong>{t('kubevirt-plugin~User name:')} </strong>{' '}
+              {cloudInitUsername || CLOUD_INIT_MISSING_USERNAME}
               {'  '}
-              <strong>Password: </strong>{' '}
+              <strong>{t('kubevirt-plugin~Password:')} </strong>{' '}
               {showPassword ? (
                 <>
                   {cloudInitPassword}{' '}
                   <Button isSmall isInline variant="link" onClick={() => setShowPassword(false)}>
-                    Hide password
+                    {t('kubevirt-plugin~Hide password')}
                   </Button>
                 </>
               ) : (
                 <Button isSmall isInline variant="link" onClick={() => setShowPassword(true)}>
-                  Show password
+                  {t('kubevirt-plugin~Show password')}
                 </Button>
               )}
             </p>
@@ -178,7 +184,19 @@ const VMConsoles: React.FC<VMConsolesProps> = ({
             isInline
             variant="danger"
             actionClose={<AlertActionCloseButton onClose={() => setShowAlert(false)} />}
-            title={`Selected type ${type.toPatternflyLabel()} is unsupported, falling back to a supported type`}
+            title={t(
+              'kubevirt-plugin~Selected type {{typeName}} is unsupported, falling back to a supported type',
+              { typeName: type.toPatternflyLabel() },
+            )}
+          />
+        </StackItem>
+      )}
+      {!renderVNCConsole && (
+        <StackItem>
+          <Alert
+            isInline
+            variant="danger"
+            title={t('kubevirt-plugin~Console is open on another tab/window')}
           />
         </StackItem>
       )}
@@ -197,7 +215,15 @@ const VMConsoles: React.FC<VMConsolesProps> = ({
 };
 
 export const VMConsolesWrapper: React.FC<VMConsolesWrapperProps> = (props) => {
-  const { vm: vmProp, vmi, pods, vmStatusBundle, type, showOpenInNewWindow } = props;
+  const {
+    vm: vmProp,
+    vmi,
+    pods,
+    vmStatusBundle,
+    type,
+    showOpenInNewWindow,
+    renderVNCConsole,
+  } = props;
   const vm = asVM(vmProp);
   const services = getLoadedData(props.services);
 
@@ -219,6 +245,7 @@ export const VMConsolesWrapper: React.FC<VMConsolesWrapperProps> = (props) => {
       LoadingComponent={LoadingInline}
       type={type}
       showOpenInNewWindow={showOpenInNewWindow}
+      renderVNCConsole={renderVNCConsole}
     />
   );
 };
@@ -240,7 +267,10 @@ export const VMConsoleFirehose: React.FC<VMTabProps> = ({
   const params = new URLSearchParams(window.location.search);
   const type = ConsoleType.fromString(params.get('type'));
   const namespace = getNamespace(vm);
-
+  const renderVNCConsole = useRenderVNCConsole({
+    vmName: getName(objProp),
+    shouldBeFullScreen: false,
+  });
   const resources = [
     // We probably can not simply match on labels but on Service's spec.selector.[kubevirt/vm] to achieve robust pairing VM-Service.
     // So read all services and filter on frontend.
@@ -267,6 +297,7 @@ export const VMConsoleFirehose: React.FC<VMTabProps> = ({
           pods={pods}
           type={type}
           showOpenInNewWindow={showOpenInNewWindow}
+          renderVNCConsole={renderVNCConsole}
         />
       </Firehose>
     </div>
@@ -281,6 +312,7 @@ type VMConsolesWrapperProps = {
   vmStatusBundle: VMStatusBundle;
   type?: ConsoleType;
   showOpenInNewWindow?: boolean;
+  renderVNCConsole?: boolean;
 };
 
 type VMConsolesProps = {
@@ -293,6 +325,7 @@ type VMConsolesProps = {
   vmStatusBundle: VMStatusBundle;
   type?: ConsoleType;
   showOpenInNewWindow?: boolean;
+  renderVNCConsole?: boolean;
 };
 
 type VMIsStartingProps = {
