@@ -1,19 +1,13 @@
-import {
-  apiVersionForModel,
-  k8sGet,
-  k8sKill,
-  k8sPatch,
-  resourceURL,
-} from '@console/internal/module/k8s';
-import { getName, getNamespace, getDeletetionTimestamp } from '@console/shared/src';
+import { apiVersionForModel, k8sKill, k8sPatch, resourceURL } from '@console/internal/module/k8s';
+import { getName, getNamespace } from '@console/shared/src';
 import { coFetch } from '@console/internal/co-fetch';
-import { getPxeBootPatch } from '../../patches/vm/vm-boot-patches';
-import { VirtualMachineImportModel, VirtualMachineModel } from '../../../models';
+import { getBootPatch } from '../../patches/vm/vm-boot-patches';
+import { VirtualMachineModel } from '../../../models';
 import { VMKind } from '../../../types/vm';
-import { VMWrapper } from '../../wrapper/vm/vm-wrapper';
 import { freeOwnedResources } from '../free-owned-resources';
 import { VMImportKind } from '../../../types/vm-import/ovirt/vm-import';
 import { K8sResourceWithModel } from '../../../types/k8s-resource-with-model';
+import { cancelVMImport } from '../vmimport';
 
 export enum VMActionType {
   Start = 'start',
@@ -39,18 +33,19 @@ const VMActionRequest = async (vm: VMKind, action: VMActionType) => {
   return text;
 };
 
-export const VMActionWithPXERequest = async (vm: VMKind, action: VMActionType) => {
-  // handle PXE boot (kubevirt.ui/firstBoot annotation)
-  const pxePatch = getPxeBootPatch(vm);
-  if (pxePatch.length > 0) {
-    await k8sPatch(VirtualMachineModel, vm, pxePatch);
+export const VMActionWithBootOrderRequest = async (vm: VMKind, action: VMActionType) => {
+  // handle PXE/CDRom boot (kubevirt.ui/firstBoot annotation)
+  const bootPatch = getBootPatch(vm);
+  if (bootPatch.length > 0) {
+    await k8sPatch(VirtualMachineModel, vm, bootPatch);
   }
   return VMActionRequest(vm, action);
 };
 
-export const startVM = async (vm: VMKind) => VMActionWithPXERequest(vm, VMActionType.Start);
+export const startVM = async (vm: VMKind) => VMActionWithBootOrderRequest(vm, VMActionType.Start);
 export const stopVM = async (vm: VMKind) => VMActionRequest(vm, VMActionType.Stop);
-export const restartVM = async (vm: VMKind) => VMActionWithPXERequest(vm, VMActionType.Restart);
+export const restartVM = async (vm: VMKind) =>
+  VMActionWithBootOrderRequest(vm, VMActionType.Restart);
 
 export const deleteVM = async (
   vm: VMKind,
@@ -79,20 +74,7 @@ export const deleteVM = async (
   }
 
   if (vmImport && deleteVMImport) {
-    await k8sKill(VirtualMachineImportModel, vmImport);
-    if (new VMWrapper(vm).getVMImportOwnerReference()) {
-      try {
-        const deletingVM = await k8sGet(VirtualMachineModel, getName(vm), getNamespace(vm));
-        if (deletingVM && !getDeletetionTimestamp(deletingVM)) {
-          // just lost reference - kill again
-          await k8sKill(VirtualMachineModel, vm);
-        }
-      } catch (ignored) {
-        // 404 expected
-      }
-    } else {
-      await k8sKill(VirtualMachineModel, vm);
-    }
+    await cancelVMImport(vmImport, vm);
   } else {
     await k8sKill(VirtualMachineModel, vm);
   }
