@@ -3,8 +3,15 @@ import * as _ from 'lodash';
 import { getLabels } from '@console/shared/src/selectors/common';
 import { compareOwnerReference } from '@console/shared/src/utils/owner-references';
 import { K8sResourceWrapper } from '../common/k8s-resource-wrapper';
-import { CPURaw, V1NetworkInterface, VMKind } from '../../../types/vm';
 import {
+  CPURaw,
+  V1DataVolumeTemplateSpec,
+  V1NetworkInterface,
+  VMISpec,
+  VMKind,
+} from '../../../types';
+import {
+  getCloudInitVolume,
   getDataVolumeTemplates,
   getDisks,
   getInterfaces,
@@ -17,7 +24,6 @@ import {
 } from '../../../selectors/vm/selectors';
 import { VMWizardNetwork, VMWizardStorage } from '../../../components/create-vm-wizard/types';
 import { VMILikeMethods } from './types';
-import { transformDevices } from '../../../selectors/vm';
 import { findKeySuffixValue } from '../../../selectors/utils';
 import {
   TEMPLATE_FLAVOR_LABEL,
@@ -31,6 +37,8 @@ import { V1Volume } from '../../../types/vm/disk/V1Volume';
 import { V1alpha1DataVolume } from '../../../types/vm/disk/V1alpha1DataVolume';
 import { VirtualMachineImportModel, VirtualMachineModel } from '../../../models';
 import { buildOwnerReferenceForModel } from '../../../utils';
+import { transformDevices } from '../../../selectors/vm/devices';
+import { toDataVolumeTemplateSpec } from '../../../selectors/dv/selectors';
 
 export class VMWrapper extends K8sResourceWrapper<VMKind, VMWrapper> implements VMILikeMethods {
   constructor(vm?: VMKind | VMWrapper | any, copy = false) {
@@ -42,9 +50,10 @@ export class VMWrapper extends K8sResourceWrapper<VMKind, VMWrapper> implements
   getOperatingSystem = () => findKeySuffixValue(this.getLabels(), TEMPLATE_OS_LABEL);
   getWorkloadProfile = () => findKeySuffixValue(this.getLabels(), TEMPLATE_WORKLOAD_LABEL);
   getFlavor = () => findKeySuffixValue(this.getLabels(), TEMPLATE_FLAVOR_LABEL);
-
-  getMemory = () => this.data?.spec?.template?.spec?.domain?.resources?.requests?.memory;
-  getCPU = (): CPURaw => this.data?.spec?.template?.spec?.domain?.cpu;
+  getVirtualMachineInstanceSpec = (): VMISpec => this.data?.spec?.template?.spec;
+  getEvictionStrategy = (): string => this.getVirtualMachineInstanceSpec()?.evictionStrategy;
+  getMemory = () => this.getVirtualMachineInstanceSpec()?.domain?.resources?.requests?.memory;
+  getCPU = (): CPURaw => this.getVirtualMachineInstanceSpec()?.domain?.cpu;
 
   getTemplateLabels = (defaultValue = {}) =>
     getLabels(_.get(this.data, 'spec.template'), defaultValue);
@@ -60,20 +69,27 @@ export class VMWrapper extends K8sResourceWrapper<VMKind, VMWrapper> implements
 
   getVolumes = (defaultValue = []) => getVolumes(this.data, defaultValue);
 
+  getVolumesOfDisks = (disks: V1Disk[]): V1Volume[] => {
+    const diskNames = disks.map((disk) => disk?.name);
+    return this.getVolumes().filter((vol) => diskNames.includes(vol.name));
+  };
+
   getLabeledDevices = () => transformDevices(this.getDisks(), this.getNetworkInterfaces());
 
   getNodeSelector = () => getNodeSelector(this.data);
 
   getTolerations = () => getTolerations(this.data);
 
-  getConfigMaps = () => this.getVolumes().filter((vol) => Object.keys(vol).includes('configMap'));
+  getVolumesByType = (volType: VolumeType): V1Volume[] =>
+    this.getVolumes().filter((vol) => new VolumeWrapper(vol).getType() === volType);
 
-  getSecrets = () => this.getVolumes().filter((vol) => Object.keys(vol).includes('secret'));
+  getConfigMaps = (): V1Volume[] => this.getVolumesByType(VolumeType.CONFIG_MAP);
 
-  getServiceAccounts = () =>
-    this.getVolumes().filter((vol) => Object.keys(vol).includes('serviceAccount'));
+  getSecrets = (): V1Volume[] => this.getVolumesByType(VolumeType.SECRET);
 
-  getDiskSerial = (diskName) => {
+  getServiceAccounts = (): V1Volume[] => this.getVolumesByType(VolumeType.SERVICE_ACCOUNT);
+
+  getDiskSerial = (diskName: string) => {
     const disk = this.getDisks().find((d) => d.name === diskName);
     return disk && Object.keys(disk).includes('serial') && disk.serial;
   };
@@ -92,6 +108,8 @@ export class VMWrapper extends K8sResourceWrapper<VMKind, VMWrapper> implements
     );
   };
 
+  getCloudInitVolume = () => getCloudInitVolume(this.data);
+
   addTemplateLabel = (key: string, value: string) => {
     if (key) {
       this.ensurePath('spec.template.metadata.labels');
@@ -100,6 +118,11 @@ export class VMWrapper extends K8sResourceWrapper<VMKind, VMWrapper> implements
     return this;
   };
 
+  getBootDisk = (): V1Disk => {
+    const disks = this.getDisks();
+    return disks.find((d) => d.bootOrder === 1) || disks[0];
+  };
+
   addTemplateAnnotation = (key: string, value: string) => {
     if (key) {
       this.ensurePath('spec.template.metadata.annotations');
@@ -187,7 +210,7 @@ export class VMWrapper extends K8sResourceWrapper<VMKind, VMWrapper> implements
 
     if (volumeWrapper.getType() === VolumeType.DATA_VOLUME) {
       this.data.spec.dataVolumeTemplates = this.getDataVolumeTemplates().filter(
-        (dataVolume) => dataVolume.name !== volumeWrapper.getDataVolumeName(),
+        (dataVolume) => dataVolume.metadata.name !== volumeWrapper.getDataVolumeName(),
       );
     }
 
@@ -195,14 +218,55 @@ export class VMWrapper extends K8sResourceWrapper<VMKind, VMWrapper> implements
     return this;
   };
 
+  removeDiskByPVC = (nameParam: string, namespaceParam: string) => {
+    this.ensurePath('spec.template.spec.domain.devices', {});
+    const metaDataNames: string[] = [];
+
+    this.data.spec.dataVolumeTemplates = this.data?.spec?.dataVolumeTemplates?.filter(
+      (dataVolume) => {
+        const { name, namespace } = dataVolume?.spec?.source?.pvc;
+        if (name === nameParam && namespace === namespaceParam) {
+          metaDataNames.push(dataVolume?.metadata?.name);
+          return false;
+        }
+        return true;
+      },
+    );
+
+    this.data.spec.template.spec.volumes = this.data?.spec?.template?.spec?.volumes.filter(
+      (volume) => {
+        return !metaDataNames.find((metaDataName) => volume.name === metaDataName);
+      },
+    );
+
+    this.data.spec.template.spec.domain.devices.disks = this.data?.spec?.template?.spec?.domain?.devices?.disks?.filter(
+      (disk) => !disk.name || !metaDataNames.find((metaDataName) => disk.name === metaDataName),
+    );
+
+    this.ensureStorageConsistency();
+
+    return this;
+  };
+
+  updateVolume = (volume: V1Volume) => {
+    this.data.spec.template.spec.volumes = this.getVolumes().map((vol) => {
+      if (volume.name === vol.name) {
+        return volume;
+      }
+      return vol;
+    });
+    return this;
+  };
+
   setWizardStorages = (storages: VMWizardStorage[]) => {
     this.ensurePath('spec.template.spec.domain.devices');
     this.data.spec.template.spec.domain.devices.disks = _.compact(
-      storages.map((storage) => storage.disk),
+      storages.map((storage) => (storage.disk?.name ? storage.disk : null)),
     );
     this.data.spec.template.spec.volumes = _.compact(storages.map((storage) => storage.volume));
-    this.data.spec.dataVolumeTemplates = _.compact(storages.map((storage) => storage.dataVolume));
-
+    this.data.spec.dataVolumeTemplates = _.compact(
+      storages.map((storage) => toDataVolumeTemplateSpec(storage.dataVolume)),
+    );
     this.ensureStorageConsistency();
     return this;
   };
@@ -219,7 +283,8 @@ export class VMWrapper extends K8sResourceWrapper<VMKind, VMWrapper> implements
     return this;
   };
 
-  ensureDataVolumeTemplates = () => this.ensurePath('spec.dataVolumeTemplates', []);
+  ensureDataVolumeTemplates = (): V1DataVolumeTemplateSpec[] =>
+    this.ensurePath('spec.dataVolumeTemplates', []);
 
   private ensureStorages = () => {
     this.ensurePath('spec.template.spec.domain.devices.disks', []);
