@@ -1,46 +1,48 @@
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 import Helmet from 'react-helmet';
 import { navFactory, FirehoseResource } from '@console/internal/components/utils';
 import { PodsPage } from '@console/internal/components/pod';
 import { ResourceEventStream } from '@console/internal/components/events';
 import { DetailsPage } from '@console/internal/components/factory';
 import { referenceForModel } from '@console/internal/module/k8s';
-import { MachineModel, NodeModel } from '@console/internal/models';
+import { MachineModel, NodeModel, CertificateSigningRequestModel } from '@console/internal/models';
 import { connectToPlural } from '@console/internal/kinds';
 import { ResourceDetailsPageProps } from '@console/internal/components/resource-list';
-import { useFlag } from '@console/shared/src/hooks/flag';
-import { NodeMaintenanceModel, BareMetalHostModel } from '../../models';
+import { BareMetalHostModel } from '../../models';
 import { menuActionsCreator } from './menu-actions';
 import BareMetalNodeDetails from './BareMetalNodeDetails';
-import { NODE_MAINTENANCE_FLAG } from '../../features';
 import BareMetalNodeDashboard from './dashboard/BareMetalNodeDashboard';
+import { useMaintenanceCapability } from '../../hooks/useMaintenanceCapability';
 
 const { editYaml, events, pods } = navFactory;
 
-const pages = [
-  {
-    href: '',
-    name: 'Overview',
-    component: BareMetalNodeDashboard,
-  },
-  {
-    href: 'details',
-    name: 'Details',
-    component: BareMetalNodeDetails,
-  },
-  editYaml(),
-  pods(({ obj }) => (
-    <PodsPage showTitle={false} fieldSelector={`spec.nodeName=${obj.metadata.name}`} />
-  )),
-  events(ResourceEventStream),
-];
-
 type BareMetalNodeDetailsPageProps = ResourceDetailsPageProps & {
   plural: string;
 };
 
 const BareMetalNodeDetailsPage = connectToPlural((props: BareMetalNodeDetailsPageProps) => {
-  const hasNodeMaintenanceCapability = useFlag(NODE_MAINTENANCE_FLAG);
+  const { t } = useTranslation();
+  const [hasNodeMaintenanceCapability, maintenanceModel] = useMaintenanceCapability();
+
+  const pages = [
+    {
+      href: '',
+      name: t('metal3-plugin~Overview'),
+      component: BareMetalNodeDashboard,
+    },
+    {
+      href: 'details',
+      name: t('metal3-plugin~Details'),
+      component: BareMetalNodeDetails,
+    },
+    editYaml(),
+    pods(({ obj }) => (
+      <PodsPage showTitle={false} fieldSelector={`spec.nodeName=${obj.metadata.name}`} />
+    )),
+    events(ResourceEventStream),
+  ];
+
   const resources: FirehoseResource[] = [
     {
       kind: referenceForModel(MachineModel),
@@ -54,11 +56,17 @@ const BareMetalNodeDetailsPage = connectToPlural((props: BareMetalNodeDetailsPag
       isList: true,
       prop: 'hosts',
     },
+    {
+      kind: CertificateSigningRequestModel.kind,
+      namespaced: false,
+      isList: true,
+      prop: 'csrs',
+    },
   ];
 
   if (hasNodeMaintenanceCapability) {
     resources.push({
-      kind: referenceForModel(NodeMaintenanceModel),
+      kind: referenceForModel(maintenanceModel),
       namespaced: false,
       isList: true,
       prop: 'nodeMaintenances',
@@ -71,7 +79,7 @@ const BareMetalNodeDetailsPage = connectToPlural((props: BareMetalNodeDetailsPag
   return (
     <>
       <Helmet>
-        <title>{`${name} · Details`}</title>
+        <title>{t('metal3-plugin~{{name}} · Details', { name })}</title>
       </Helmet>
       <DetailsPage
         {...props}
@@ -80,13 +88,16 @@ const BareMetalNodeDetailsPage = connectToPlural((props: BareMetalNodeDetailsPag
         pages={pages}
         resources={resources}
         kind={modelRef}
-        customData={{ hasNodeMaintenanceCapability }}
+        customData={{ hasNodeMaintenanceCapability, maintenanceModel, t }}
         breadcrumbsFor={() => [
           {
             name: `${kindObj.labelPlural}`,
             path: `/k8s/cluster/${plural}`,
           },
-          { name: `${kindObj.label} Details`, path: `${match.url}` },
+          {
+            name: t('metal3-plugin~{{name}} Details', { name: kindObj.label }),
+            path: `${match.url}`,
+          },
         ]}
       />
     </>
