@@ -1,4 +1,5 @@
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 import { Status, ProgressStatus } from '@console/shared';
 import {
   NODE_STATUS_UNDER_MAINTENANCE,
@@ -7,15 +8,21 @@ import {
 } from '../../constants';
 import { BareMetalHostStatusProps } from '../types';
 import MaintenancePopover from '../maintenance/MaintenancePopover';
+import { NODE_STATUS_SERVER_CSR } from '../../status/baremetal-node-status';
+import CSRStatus from './CSRStatus';
 
 const BareMetalNodeStatus: React.FC<BareMetalHostStatusProps> = ({
   status,
-  title,
+  titleKey,
   nodeMaintenance,
+  csr,
   className,
 }) => {
-  const statusTitle = title || status;
+  const { t } = useTranslation();
+  const statusTitle = t(titleKey) || status;
   switch (true) {
+    case status === NODE_STATUS_SERVER_CSR:
+      return <CSRStatus title={statusTitle} csr={csr} serverCSR />;
     case [NODE_STATUS_STARTING_MAINTENANCE, NODE_STATUS_UNDER_MAINTENANCE].includes(status):
       return (
         <MaintenancePopover
