@@ -2,8 +2,9 @@ import * as React from 'react';
 import * as _ from 'lodash';
 import * as classNames from 'classnames';
 import { match } from 'react-router-dom';
+import { useTranslation } from 'react-i18next';
 import { CreateYAML } from '@console/internal/components/create-yaml';
-import { ListPageProps } from '@console/internal/components/monitoring';
+import { ListPageProps } from '@console/internal/components/monitoring/types';
 import { sortable } from '@patternfly/react-table';
 import { Button } from '@patternfly/react-core';
 import { withFallback } from '@console/shared/src/components/error/error-boundary';
@@ -24,6 +25,8 @@ import {
   SectionHeading,
   asAccessReview,
   KebabOption,
+  ResourceSummary,
+  DetailsItem,
 } from '@console/internal/components/utils';
 import {
   DetailsPage,
@@ -35,7 +38,7 @@ import {
   RowFunction,
 } from '@console/internal/components/factory';
 import { ConfigMapModel } from '@console/internal/models';
-import { PopoverStatus } from '@console/shared';
+import { PopoverStatus, StatusIconAndText } from '@console/shared';
 import {
   SubscriptionModel,
   CatalogSourceModel,
@@ -43,19 +46,17 @@ import {
   OperatorGroupModel,
   OperatorHubModel,
 } from '../models';
-import {
-  CatalogSourceKind,
-  SubscriptionKind,
-  PackageManifestKind,
-  OperatorGroupKind,
-} from '../types';
+import { CatalogSourceKind, PackageManifestKind, OperatorGroupKind } from '../types';
 import { requireOperatorGroup } from './operator-group';
-import { PackageManifestList } from './package-manifest';
 import { deleteCatalogSourceModal } from './modals/delete-catalog-source-modal';
 import { disableDefaultSourceModal } from './modals/disable-default-source-modal';
 import { OperatorHubKind } from './operator-hub';
+import { editRegitryPollInterval } from './modals/edit-registry-poll-interval-modal';
+import { PackageManifestsPage } from './package-manifest';
+import useOperatorHubConfig from '../utils/useOperatorHubConfig';
+import i18n from '@console/internal/i18n';
+import { DEFAULT_SOURCE_NAMESPACE } from '../const';
 
-const DEFAULT_SOURCE_NAMESPACE = 'openshift-marketplace';
 const catalogSourceModelReference = referenceForModel(CatalogSourceModel);
 
 const deleteModal = (kind: K8sKind, catalogSource: CatalogSourceKind): KebabOption => ({
@@ -68,7 +69,8 @@ const disableSourceModal = (
   operatorHub: OperatorHubKind,
   sourceName: string,
 ): KebabOption => ({
-  label: 'Disable',
+  // t('olm~Disable')
+  labelKey: 'olm~Disable',
   callback: () => disableDefaultSourceModal({ kind, operatorHub, sourceName }),
   accessReview: asAccessReview(kind, operatorHub, 'patch'),
 });
@@ -78,7 +80,8 @@ const enableSource = (
   operatorHub: OperatorHubKind,
   sourceName: string,
 ): KebabOption => ({
-  label: 'Enable',
+  // t('olm~Enable')
+  labelKey: 'olm~Enable',
   callback: () => {
     const currentSources = _.get(operatorHub, 'spec.sources', []);
     const patch = [
@@ -98,89 +101,175 @@ const DefaultSourceKebab: React.FC<DefaultSourceKebabProps> = ({
   operatorHub,
   sourceName,
   sourceDisabled,
+  source,
 }) => {
   const options = sourceDisabled
     ? [enableSource(kind, operatorHub, sourceName)]
-    : [disableSourceModal(kind, operatorHub, sourceName)];
+    : [
+        disableSourceModal(kind, operatorHub, sourceName),
+        ...(source ? [Kebab.factory.Edit(CatalogSourceModel, source)] : []),
+      ];
   return <Kebab options={options} />;
 };
 
-export const CatalogSourceDetails: React.SFC<CatalogSourceDetailsProps> = ({
-  obj,
-  packageManifests,
-  subscriptions,
-  operatorGroups,
-}) => {
-  const toData = <T extends K8sResourceKind>(data: T[]) => ({ loaded: true, data });
+const getOperatorCount = (
+  catalogSource: CatalogSourceKind,
+  packageManifests: PackageManifestKind[],
+): number =>
+  packageManifests.filter(
+    (p) =>
+      p.status?.catalogSource === catalogSource.metadata.name &&
+      p.status?.catalogSourceNamespace === catalogSource.metadata.namespace,
+  ).length;
 
-  return !_.isEmpty(obj) ? (
-    <div className="co-catalog-details co-m-pane">
-      <div className="co-m-pane__body">
-        <div className="col-xs-4">
-          <dl className="co-m-pane__details">
-            <dt>Name</dt>
-            <dd>{obj.spec.displayName}</dd>
-          </dl>
+const getEndpoint = (catalogSource: CatalogSourceKind): React.ReactNode => {
+  if (catalogSource.spec.configmap) {
+    return (
+      <ResourceLink
+        kind={referenceForModel(ConfigMapModel)}
+        name={catalogSource.spec.configmap}
+        namespace={catalogSource.metadata.namespace}
+      />
+    );
+  }
+  return catalogSource.spec.image || catalogSource.spec.address;
+};
+
+export const CatalogSourceDetails: React.FC<CatalogSourceDetailsProps> = ({
+  obj: catalogSource,
+  packageManifests,
+}) => {
+  const { t } = useTranslation();
+
+  const operatorCount = getOperatorCount(catalogSource, packageManifests);
+
+  const catsrcNamespace =
+    catalogSource.metadata.namespace === DEFAULT_SOURCE_NAMESPACE
+      ? 'Cluster wide'
+      : catalogSource.metadata.namespace;
+
+  return !_.isEmpty(catalogSource) ? (
+    <div className="co-m-pane__body">
+      <SectionHeading
+        text={t('olm~CatalogSource details', {
+          resource: CatalogSourceModel.label,
+        })}
+      />
+      <div className="row">
+        <div className="col-sm-6 col-xs-12">
+          <ResourceSummary resource={catalogSource} />
         </div>
-        <div className="col-xs-4">
-          <dl className="co-m-pane__details">
-            <dt>Publisher</dt>
-            <dd>{obj.spec.publisher}</dd>
-          </dl>
+        <div className="col-sm-6 col-xs-12">
+          <div className="co-m-pane__body">
+            <DetailsItem
+              editAsGroup
+              label={t('public~Status')}
+              obj={catalogSource}
+              path="status.connectionState.lastObservedState"
+            />
+            <DetailsItem
+              label={t('public~Display name')}
+              obj={catalogSource}
+              path="spec.displayName"
+            />
+            <DetailsItem label={t('olm~Publisher')} obj={catalogSource} path="spec.publisher" />
+            <DetailsItem
+              label={t('olm~Availability')}
+              obj={catalogSource}
+              description={t(
+                'olm~Denotes whether this CatalogSource provides operators to a specific namespace, or the entire cluster.',
+              )}
+            >
+              {catsrcNamespace}
+            </DetailsItem>
+            <DetailsItem
+              label="Endpoint"
+              obj={catalogSource}
+              description={t(
+                "olm~The ConfigMap, image, or address for this CatalogSource's registry.",
+              )}
+            >
+              {getEndpoint(catalogSource)}
+            </DetailsItem>
+            <DetailsItem
+              label={t('olm~Registry poll interval')}
+              obj={catalogSource}
+              path="spec.updateStrategy.registryPoll.interval"
+              canEdit={!_.isEmpty(catalogSource.spec.updateStrategy)}
+              onEdit={() => editRegitryPollInterval({ catalogSource })}
+            />
+            <DetailsItem
+              label={t('olm~Number of Operators')}
+              obj={catalogSource}
+              description={t('olm~The number of packages this CatalogSource provides.')}
+            >
+              {operatorCount}
+            </DetailsItem>
+          </div>
         </div>
       </div>
-      <div className="co-m-pane__body">
-        <SectionHeading text="Packages" />
-        <PackageManifestList
-          loaded
-          data={packageManifests}
-          operatorGroup={toData(operatorGroups)}
-          subscription={toData(subscriptions)}
-        />
-      </div>
     </div>
   ) : (
     <div />
   );
 };
 
-export const CatalogSourceDetailsPage: React.SFC<CatalogSourceDetailsPageProps> = (props) => (
-  <DetailsPage
-    {...props}
-    namespace={props.match.params.ns}
-    kind={referenceForModel(CatalogSourceModel)}
-    name={props.match.params.name}
-    pages={[navFactory.details(CatalogSourceDetails), navFactory.editYaml()]}
-    menuActions={Kebab.factory.common}
-    resources={[
-      {
-        kind: referenceForModel(PackageManifestModel),
-        isList: true,
-        namespace: props.match.params.ns,
-        selector: { matchLabels: { catalog: props.match.params.name } },
-        prop: 'packageManifests',
-      },
-      {
-        kind: referenceForModel(SubscriptionModel),
-        isList: true,
-        namespace: props.match.params.ns,
-        prop: 'subscriptions',
-      },
-      {
-        kind: referenceForModel(OperatorGroupModel),
-        isList: true,
-        namespace: props.match.params.ns,
-        prop: 'operatorGroups',
-      },
-    ]}
-  />
-);
+export const CatalogSourceOperatorsPage: React.FC<CatalogSourceOperatorsPageProps> = (props) => {
+  return <PackageManifestsPage catalogSource={props.obj} showTitle={false} {...props} />;
+};
 
-export const CreateSubscriptionYAML: React.SFC<CreateSubscriptionYAMLProps> = (props) => {
+export const CatalogSourceDetailsPage: React.FC<CatalogSourceDetailsPageProps> = (props) => {
+  const [operatorHub, operatorHubLoaded, operatorHubLoadError] = useOperatorHubConfig();
+
+  const isDefaultSource = React.useMemo(
+    () =>
+      DEFAULT_SOURCE_NAMESPACE === props.match.params.ns &&
+      operatorHub?.status?.sources?.some((source) => source.name === props.match.params.name),
+    [operatorHub, props.match.params.name, props.match.params.ns],
+  );
+
+  const menuActions = isDefaultSource
+    ? [
+        Kebab.factory.Edit,
+        () => disableSourceModal(OperatorHubModel, operatorHub, props.match.params.name),
+      ]
+    : Kebab.factory.common;
+
+  return (
+    <DetailsPage
+      {...props}
+      namespace={props.match.params.ns}
+      kind={referenceForModel(CatalogSourceModel)}
+      name={props.match.params.name}
+      pages={[
+        navFactory.details(CatalogSourceDetails),
+        navFactory.editYaml(),
+        {
+          href: 'operators',
+          // t('olm~Operators')
+          nameKey: 'olm~Operators',
+          component: CatalogSourceOperatorsPage,
+        },
+      ]}
+      menuActions={operatorHubLoaded && !operatorHubLoadError ? menuActions : []}
+      resources={[
+        {
+          kind: referenceForModel(PackageManifestModel),
+          isList: true,
+          namespace: props.match.params.ns,
+          prop: 'packageManifests',
+        },
+      ]}
+    />
+  );
+};
+
+export const CreateSubscriptionYAML: React.FC<CreateSubscriptionYAMLProps> = (props) => {
   type CreateProps = {
     packageManifest: { loaded: boolean; data?: PackageManifestKind };
     operatorGroup: { loaded: boolean; data?: OperatorGroupKind[] };
   };
+  const { t } = useTranslation();
   const Create = requireOperatorGroup(
     withFallback<CreateProps>(
       (createProps) => {
@@ -211,8 +300,8 @@ export const CreateSubscriptionYAML: React.SFC<CreateSubscriptionYAMLProps> = (p
       },
       () => (
         <MsgBox
-          title="Package Not Found"
-          detail="Cannot create a Subscription to a non-existent package."
+          title={t('olm~Package not found')}
+          detail={t('olm~Cannot create a Subscription to a non-existent package.')}
         />
       ),
     ),
@@ -243,77 +332,16 @@ export const CreateSubscriptionYAML: React.SFC<CreateSubscriptionYAMLProps> = (p
 };
 
 const tableColumnClasses = [
-  classNames('col-lg-3', 'col-md-3', 'col-sm-4', 'col-xs-6'),
-  classNames('col-lg-2', 'col-md-3', 'col-sm-4', 'col-xs-6'),
-  classNames('col-lg-2', 'col-md-3', 'col-sm-4', 'hidden-xs'),
-  classNames('col-lg-3', 'col-md-3', 'hidden-sm', 'hidden-xs'),
-  classNames('col-lg-2', 'hidden-md', 'hidden-sm', 'hidden-xs'),
+  '',
+  classNames('pf-m-hidden', 'pf-m-visible-on-sm'),
+  '',
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-xl'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-xl'),
+  classNames('pf-m-hidden', 'pf-m-visible-on-lg'),
   Kebab.columnClass,
 ];
 
-const CatalogSourceHeader = () => {
-  return [
-    {
-      title: 'Name',
-      sortField: 'name',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[0] },
-    },
-    {
-      title: 'Publisher',
-      sortField: 'publisher',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[1] },
-    },
-    {
-      title: 'Availability',
-      sortField: 'availabilitySort',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[2] },
-    },
-    {
-      title: 'Endpoint',
-      sortField: 'endpoint',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[3] },
-    },
-    {
-      title: '# of Operators',
-      sortField: 'operatorCount',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[4] },
-    },
-    {
-      title: '',
-      props: { className: tableColumnClasses[5] },
-    },
-  ];
-};
-
-const getEndpoint = (catalogSource: CatalogSourceKind): React.ReactNode => {
-  if (catalogSource.spec.configmap) {
-    return (
-      <ResourceLink
-        kind={referenceForModel(ConfigMapModel)}
-        name={catalogSource.spec.configmap}
-        namespace={catalogSource.metadata.namespace}
-      />
-    );
-  }
-  return catalogSource.spec.image || catalogSource.spec.address;
-};
-
-const getOperatorCount = (
-  catalogSource: CatalogSourceKind,
-  packageManifests: PackageManifestKind[],
-): number =>
-  _.filter(packageManifests, {
-    status: {
-      catalogSource: catalogSource.metadata.name,
-      catalogSourceNamespace: catalogSource.metadata.namespace,
-    },
-  } as any).length; // Type inferred to prevent Lodash TypeScript error.
-
 const CatalogSourceTableRow: RowFunction<CatalogSourceTableRowObj> = ({
   obj: {
     availability = '-',
@@ -324,6 +352,8 @@ const CatalogSourceTableRow: RowFunction<CatalogSourceTableRowObj> = ({
     operatorCount = 0,
     operatorHub,
     publisher = '-',
+    registryPollInterval = '-',
+    status = '',
     source,
   },
   index,
@@ -349,21 +379,31 @@ const CatalogSourceTableRow: RowFunction<CatalogSourceTableRowObj> = ({
         name
       )}
     </TableData>
-    <TableData className={tableColumnClasses[1]}>{publisher}</TableData>
-    <TableData className={tableColumnClasses[2]}>{availability}</TableData>
-    <TableData className={tableColumnClasses[3]}>{endpoint}</TableData>
-    <TableData className={tableColumnClasses[4]}>{operatorCount || '-'}</TableData>
-    <TableData className={tableColumnClasses[5]}>
+    <TableData className={tableColumnClasses[1]} data-test={`${source?.metadata.name}-status`}>
+      {status}
+    </TableData>
+    <TableData className={tableColumnClasses[2]}>{publisher}</TableData>
+    <TableData className={tableColumnClasses[3]}>{availability}</TableData>
+    <TableData className={tableColumnClasses[4]}>{endpoint}</TableData>
+    <TableData className={tableColumnClasses[5]}>{registryPollInterval}</TableData>
+    <TableData className={tableColumnClasses[6]}>{operatorCount || '-'}</TableData>
+    <TableData className={tableColumnClasses[7]}>
       {isDefault ? (
         <DefaultSourceKebab
           kind={OperatorHubModel}
           operatorHub={operatorHub}
           sourceName={name}
           sourceDisabled={disabled}
+          source={source}
         />
       ) : (
         <ResourceKebab
-          actions={[Kebab.factory.Edit, deleteModal]}
+          actions={[
+            Kebab.factory.ModifyLabels,
+            Kebab.factory.ModifyAnnotations,
+            Kebab.factory.Edit,
+            deleteModal,
+          ]}
           kind={catalogSourceModelReference}
           resource={source}
         />
@@ -372,14 +412,67 @@ const CatalogSourceTableRow: RowFunction<CatalogSourceTableRowObj> = ({
   </TableRow>
 );
 
-const CatalogSourceList: React.FC<TableProps> = (props) => (
-  <Table
-    {...props}
-    aria-label="Catalog Sources"
-    Header={CatalogSourceHeader}
-    Row={CatalogSourceTableRow}
-  />
-);
+const CatalogSourceList: React.FC<TableProps> = (props) => {
+  const { t } = useTranslation();
+  const CatalogSourceHeader = () => {
+    return [
+      {
+        title: t('public~Name'),
+        sortField: 'name',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[0] },
+      },
+      {
+        title: t('public~Status'),
+        sortField: 'status',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[1] },
+      },
+      {
+        title: t('olm~Publisher'),
+        sortField: 'publisher',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[2] },
+      },
+      {
+        title: t('olm~Availability'),
+        sortField: 'availabilitySort',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[3] },
+      },
+      {
+        title: t('olm~Endpoint'),
+        sortField: 'endpoint',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[4] },
+      },
+      {
+        title: t('olm~Registry poll interval'),
+        sortField: 'registryPollInterval',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[5] },
+      },
+      {
+        title: t('olm~# of Operators'),
+        sortField: 'operatorCount',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[6] },
+      },
+      {
+        title: '',
+        props: { className: tableColumnClasses[7] },
+      },
+    ];
+  };
+  return (
+    <Table
+      {...props}
+      aria-label={`${CatalogSourceModel.labelPlural}`}
+      Header={CatalogSourceHeader}
+      Row={CatalogSourceTableRow}
+    />
+  );
+};
 
 const DisabledPopover: React.FC<DisabledPopoverProps> = ({ operatorHub, sourceName }) => {
   const [visible, setVisible] = React.useState<boolean>(null);
@@ -393,19 +486,30 @@ const DisabledPopover: React.FC<DisabledPopoverProps> = ({ operatorHub, sourceNa
         .then(close),
     [close, operatorHub, sourceName],
   );
+  const { t } = useTranslation();
   return (
-    <PopoverStatus title="Disabled" isVisible={visible} shouldClose={close}>
+    <PopoverStatus
+      title={t('olm~Disabled')}
+      isVisible={visible}
+      shouldClose={close}
+      statusBody={<StatusIconAndText title={t('olm~Disabled')} />}
+    >
       <p>
-        Operators provided by this source will not appear in OperatorHub and any operators installed
-        from this source will not receive updates unitl this source is re-enabled.
+        {t(
+          'olm~Operators provided by this source will not appear in OperatorHub and any operators installed from this source will not receive updates until this source is re-enabled.',
+        )}
       </p>
       <Button isInline variant="link" onClick={onClickEnable}>
-        Enable source
+        {t('olm~Enable source')}
       </Button>
     </PopoverStatus>
   );
 };
 
+const getRegistryPollInterval = (catalogSource: CatalogSourceKind): string => {
+  return catalogSource.spec?.updateStrategy?.registryPoll?.interval;
+};
+
 const flatten = ({
   catalogSources,
   operatorHub,
@@ -420,7 +524,7 @@ const flatten = ({
       const catalogSourceExists = !_.isEmpty(catalogSource);
       return {
         availability: catalogSourceExists ? (
-          'Cluster wide'
+          i18n.t('olm~Cluster wide')
         ) : (
           <DisabledPopover operatorHub={operatorHub} sourceName={defaultSource.name} />
         ),
@@ -436,6 +540,8 @@ const flatten = ({
           endpoint: getEndpoint(catalogSource),
           operatorCount: getOperatorCount(catalogSource, packageManifests.data),
           publisher: catalogSource.spec.publisher,
+          registryPollInterval: getRegistryPollInterval(catalogSource),
+          status: catalogSource.status?.connectionState?.lastObservedState,
         }),
       };
     },
@@ -444,7 +550,7 @@ const flatten = ({
   const customSources: CatalogSourceTableRowObj[] = _.map(catalogSources.data, (source) => ({
     availability:
       source.metadata.namespace === DEFAULT_SOURCE_NAMESPACE
-        ? 'Cluster wide'
+        ? i18n.t('olm~Cluster wide')
         : source.metadata.namespace,
     endpoint: getEndpoint(source),
     name: source.metadata.name,
@@ -452,6 +558,8 @@ const flatten = ({
     operatorCount: getOperatorCount(source, packageManifests.data),
     operatorHub,
     publisher: source.spec.publisher,
+    registryPollInterval: getRegistryPollInterval(source),
+    status: source.status?.connectionState?.lastObservedState,
     source,
   }));
 
@@ -462,31 +570,34 @@ const flatten = ({
   );
 };
 
-export const CatalogSourceListPage: React.FC<CatalogSourceListPageProps> = (props) => (
-  <MultiListPage
-    {...props}
-    canCreate
-    createAccessReview={{ model: CatalogSourceModel }}
-    createButtonText="Create Catalog Source"
-    createProps={{ to: `/k8s/cluster/${referenceForModel(CatalogSourceModel)}/~new` }}
-    flatten={(data) => flatten({ operatorHub: props.obj, ...data })}
-    ListComponent={CatalogSourceList}
-    textFilter="catalog-source-name"
-    hideLabelFilter
-    resources={[
-      {
-        isList: true,
-        kind: referenceForModel(PackageManifestModel),
-        prop: 'packageManifests',
-      },
-      {
-        isList: true,
-        kind: catalogSourceModelReference,
-        prop: 'catalogSources',
-      },
-    ]}
-  />
-);
+export const CatalogSourceListPage: React.FC<CatalogSourceListPageProps> = (props) => {
+  const { t } = useTranslation();
+  return (
+    <MultiListPage
+      {...props}
+      canCreate
+      createAccessReview={{ model: CatalogSourceModel }}
+      createButtonText={t('olm~Create CatalogSource')}
+      createProps={{ to: `/k8s/cluster/${referenceForModel(CatalogSourceModel)}/~new` }}
+      flatten={(data) => flatten({ operatorHub: props.obj, ...data })}
+      ListComponent={CatalogSourceList}
+      textFilter="catalog-source-name"
+      hideLabelFilter
+      resources={[
+        {
+          isList: true,
+          kind: referenceForModel(PackageManifestModel),
+          prop: 'packageManifests',
+        },
+        {
+          isList: true,
+          kind: catalogSourceModelReference,
+          prop: 'catalogSources',
+        },
+      ]}
+    />
+  );
+};
 
 type CatalogSourceTableRowObj = {
   availability: React.ReactNode;
@@ -495,9 +606,11 @@ type CatalogSourceTableRowObj = {
   isDefault?: boolean;
   name: string;
   namespace: string;
-  publisher?: string;
   operatorCount?: number;
   operatorHub: OperatorHubKind;
+  publisher?: string;
+  registryPollInterval?: string;
+  status?: string;
   source?: CatalogSourceKind;
 };
 
@@ -506,6 +619,7 @@ type DefaultSourceKebabProps = {
   operatorHub: OperatorHubKind;
   sourceName: string;
   sourceDisabled: boolean;
+  source?: CatalogSourceKind;
 };
 
 type DisabledPopoverProps = {
@@ -521,9 +635,7 @@ type FlattenArgType = {
 
 export type CatalogSourceDetailsProps = {
   obj: CatalogSourceKind;
-  subscriptions: SubscriptionKind[];
   packageManifests: PackageManifestKind[];
-  operatorGroups: OperatorGroupKind[];
 };
 
 export type CatalogSourceDetailsPageProps = {
@@ -539,6 +651,10 @@ export type CreateSubscriptionYAMLProps = {
   location: Location;
 };
 
+export type CatalogSourceOperatorsPageProps = {
+  obj: CatalogSourceKind;
+} & ListPageProps;
+
 CatalogSourceDetails.displayName = 'CatalogSourceDetails';
 CatalogSourceDetailsPage.displayName = 'CatalogSourceDetailPage';
 CreateSubscriptionYAML.displayName = 'CreateSubscriptionYAML';
