@@ -1,6 +1,7 @@
 import * as React from 'react';
 import Helmet from 'react-helmet';
 import { match } from 'react-router-dom';
+import { useTranslation } from 'react-i18next';
 import { ActionGroup, Button, Form, FormGroup, TextInput } from '@patternfly/react-core';
 import {
   ButtonBar,
@@ -18,19 +19,6 @@ enum AvailabilityValue {
   SINGLE_NAMESPACE = '1',
 }
 
-const availabilityKinds = [
-  {
-    value: AvailabilityValue.ALL_NAMESPACES,
-    title: 'Cluster-wide catalog source',
-    desc: 'Catalog will be available in all namespaces',
-  },
-  {
-    value: AvailabilityValue.SINGLE_NAMESPACE,
-    title: 'Namespace catalog source',
-    desc: 'Catalog will only be available in a single namespace',
-  },
-];
-
 export const CreateCatalogSource: React.FC<CreateCatalogSourceProps> = withHandlePromise(
   ({ handlePromise, inProgress, errorMessage }) => {
     const [availability, setAvailability] = React.useState(AvailabilityValue.ALL_NAMESPACES);
@@ -60,7 +48,8 @@ export const CreateCatalogSource: React.FC<CreateCatalogSourceProps> = withHandl
               sourceType: 'grpc',
             },
           }),
-        ).then(() => history.goBack());
+          () => history.goBack(),
+        );
       },
       [availability, displayName, handlePromise, image, name, namespace, publisher],
     );
@@ -73,17 +62,34 @@ export const CreateCatalogSource: React.FC<CreateCatalogSourceProps> = withHandl
       setAvailability(value as AvailabilityValue);
     };
 
+    const { t } = useTranslation();
+    const availabilityKinds = [
+      {
+        value: AvailabilityValue.ALL_NAMESPACES,
+        title: t('olm~Cluster-wide CatalogSource'),
+        desc: t('olm~Catalog will be available in all namespaces'),
+      },
+      {
+        value: AvailabilityValue.SINGLE_NAMESPACE,
+        title: t('olm~Namespaced CatalogSource'),
+        desc: t('olm~Catalog will only be available in a single namespace'),
+      },
+    ];
+
+    const title = t('olm~Create CatalogSource');
     return (
       <div className="co-m-pane__body">
         <Helmet>
-          <title>Create Catalog Source</title>
+          <title>{title}</title>
         </Helmet>
-        <h1 className="co-m-pane__heading">Create Catalog Source</h1>
+        <h1 className="co-m-pane__heading" data-test="create-catalogsource-title">
+          {title}
+        </h1>
         <p className="co-m-pane__explanation">
-          Create a catalog source in order to make operators available in OperatorHub.
+          {t('olm~Create a CatalogSource in order to make operators available in OperatorHub.')}
         </p>
         <Form onSubmit={onSave}>
-          <FormGroup fieldId="catalog-source-name" isRequired label="Catalog source name">
+          <FormGroup fieldId="catalog-source-name" isRequired label={t('olm~CatalogSource name')}>
             <TextInput
               id="catalog-source-name"
               isRequired
@@ -92,19 +98,20 @@ export const CreateCatalogSource: React.FC<CreateCatalogSourceProps> = withHandl
               placeholder="e.g. custom-catalog-source"
               type="text"
               value={name}
+              data-test="catalog-source-name"
             />
           </FormGroup>
-          <FormGroup fieldId="catalog-source-display-name" label="Display name">
+          <FormGroup fieldId="catalog-source-display-name" label={t('olm~Display name')}>
             <TextInput
               id="catalog-source-display-name"
               name="caltalog-source-display-name"
               onChange={setDisplayName}
-              placeholder="e.g. Custom Catalog Source"
+              placeholder="e.g. Custom catalog source"
               type="text"
               value={displayName}
             />
           </FormGroup>
-          <FormGroup fieldId="catalog-source-publisher" label="Publisher name">
+          <FormGroup fieldId="catalog-source-publisher" label={t('olm~Publisher name')}>
             <TextInput
               id="catalog-source-publisher"
               isRequired
@@ -116,10 +123,10 @@ export const CreateCatalogSource: React.FC<CreateCatalogSourceProps> = withHandl
             />
           </FormGroup>
           <FormGroup
-            label="Image (URL of container image)"
+            label={t('olm~Image (URL of container image)')}
             isRequired
             fieldId="catalog-source-image"
-            helperText="URL of container image hosted on a registry"
+            helperText={t('olm~URL of container image hosted on a registry')}
           >
             <TextInput
               aria-describedby="catalog-source-image-helper"
@@ -130,9 +137,10 @@ export const CreateCatalogSource: React.FC<CreateCatalogSourceProps> = withHandl
               onChange={setImage}
               placeholder="e.g. quay.io/johndoe/catalog-registry:latest"
               value={image}
+              data-test="catalog-source-image"
             />
           </FormGroup>
-          <FormGroup fieldId="catalog-source-availability" label="Availability">
+          <FormGroup fieldId="catalog-source-availability" label={t('olm~Availability')}>
             <RadioGroup
               currentValue={availability}
               items={availabilityKinds}
@@ -140,7 +148,7 @@ export const CreateCatalogSource: React.FC<CreateCatalogSourceProps> = withHandl
             />
           </FormGroup>
           {availability === AvailabilityValue.SINGLE_NAMESPACE && (
-            <FormGroup fieldId="catalog-source-namespace" label="Namespace" isRequired>
+            <FormGroup fieldId="catalog-source-namespace" label={t('olm~Namespace')} isRequired>
               <NsDropdown
                 selectedKey={namespace}
                 onChange={onNamespaceChange}
@@ -150,11 +158,11 @@ export const CreateCatalogSource: React.FC<CreateCatalogSourceProps> = withHandl
           )}
           <ButtonBar errorMessage={errorMessage} inProgress={inProgress}>
             <ActionGroup className="pf-c-form__group--no-top-margin">
-              <Button type="submit" variant="primary" id="save-changes">
-                Create
+              <Button type="submit" variant="primary" id="save-changes" data-test="save-changes">
+                {t('olm~Create')}
               </Button>
               <Button type="button" variant="secondary" id="cancel" onClick={history.goBack}>
-                Cancel
+                {t('olm~Cancel')}
               </Button>
             </ActionGroup>
           </ButtonBar>
