@@ -1,11 +1,12 @@
 import * as React from 'react';
-import { compare, parse, SemVer } from 'semver';
+import { compare, gte, parse, SemVer } from 'semver';
 import {
   ClusterServiceVersionKind,
   ClusterServiceVersionModel,
   ClusterServiceVersionPhase,
 } from '@console/operator-lifecycle-manager';
 import { k8sList } from '@console/internal/module/k8s';
+import { PIPELINE_GA_VERSION } from '../const';
 
 export const getPipelineOperatorVersion = async (namespace: string): Promise<SemVer | null> => {
   const allCSVs: ClusterServiceVersionKind[] = await k8sList(ClusterServiceVersionModel, {
@@ -13,7 +14,8 @@ export const getPipelineOperatorVersion = async (namespace: string): Promise<Sem
   });
   const matchingCSVs = allCSVs.filter(
     (csv) =>
-      csv.metadata?.name?.startsWith('openshift-pipelines-operator') &&
+      (csv.metadata?.name?.startsWith('openshift-pipelines-operator') ||
+        csv.metadata?.name?.startsWith('redhat-openshift-pipelines')) &&
       csv.status?.phase === ClusterServiceVersionPhase.CSVPhaseSucceeded,
   );
   const versions = matchingCSVs.map((csv) => parse(csv.spec.version)).filter(Boolean);
@@ -37,3 +39,8 @@ export const usePipelineOperatorVersion = (namespace: string): SemVer | null =>
   }, [namespace]);
   return version;
 };
+
+export const isGAVersionInstalled = (operator: SemVer): boolean => {
+  if (!operator) return false;
+  return gte(operator.version, PIPELINE_GA_VERSION);
+};
