@@ -8,6 +8,8 @@ import { Map as ImmutableMap } from 'immutable';
 import * as fuzzy from 'fuzzysearch';
 import { Tooltip } from '@patternfly/react-core';
 import { sortable } from '@patternfly/react-table';
+import { useTranslation } from 'react-i18next';
+import i18next from 'i18next';
 
 import { ALL_NAMESPACES_KEY, FLAGS, APIError } from '@console/shared';
 import { useAccessReview } from '@console/internal/components/utils';
@@ -30,7 +32,7 @@ import { CheckBox, CheckBoxControls } from './row-filter';
 import { DefaultPage } from './default-resource';
 import { Table, TextFilter } from './factory';
 import { fuzzyCaseInsensitive } from './factory/table-filters';
-import { resourceListPages } from './resource-pages';
+import { getResourceListPages } from './resource-pages';
 import { ExploreType } from './sidebars/explore-type-sidebar';
 import {
   AsyncComponent,
@@ -46,6 +48,7 @@ import {
   ScrollToTopOnMount,
   setQueryArgument,
 } from './utils';
+import { isResourceListPage, useExtensions, ResourceListPage } from '@console/plugin-sdk';
 
 const mapStateToProps = (state: RootState): APIResourceLinkStateProps => {
   return {
@@ -70,6 +73,7 @@ const APIResourceLink_: React.FC<APIResourceLinkStateProps & APIResourceLinkOwnP
   activeNamespace,
   model,
 }) => {
+  const { t } = useTranslation();
   const to = getAPIResourceLink(activeNamespace, model);
   return (
     <span className="co-resource-item">
@@ -77,7 +81,7 @@ const APIResourceLink_: React.FC<APIResourceLinkStateProps & APIResourceLinkOwnP
         <ResourceIcon kind={referenceForModel(model)} />
       </span>
       <Link to={to} className="co-resource-item__resource-name">
-        {model.kind}
+        {model.labelKey ? t(model.labelKey) : model.kind}
       </Link>
     </span>
   );
@@ -86,7 +90,10 @@ const APIResourceLink = connect<APIResourceLinkStateProps, {}, APIResourceLinkOw
   mapStateToProps,
 )(APIResourceLink_);
 
-const EmptyAPIResourcesMsg: React.FC<{}> = () => <EmptyBox label="API Resources" />;
+const EmptyAPIResourcesMsg: React.FC<{}> = () => {
+  const { t } = useTranslation();
+  return <EmptyBox label={t('public~API resources')} />;
+};
 
 const Group: React.FC<{ value: string }> = ({ value }) => {
   if (!value) {
@@ -112,37 +119,6 @@ const tableClasses = [
   'col-lg-3 col-md-5 hidden-sm hidden-xs',
 ];
 
-const APIResourceHeader = () => [
-  {
-    title: 'Kind',
-    sortField: 'kind',
-    transforms: [sortable],
-    props: { className: tableClasses[0] },
-  },
-  {
-    title: 'Group',
-    sortField: 'apiGroup',
-    transforms: [sortable],
-    props: { className: tableClasses[1] },
-  },
-  {
-    title: 'Version',
-    sortField: 'apiVersion',
-    transforms: [sortable],
-    props: { className: tableClasses[2] },
-  },
-  {
-    title: 'Namespaced',
-    sortField: 'namespaced',
-    transforms: [sortable],
-    props: { className: tableClasses[3] },
-  },
-  {
-    title: 'Description',
-    props: { className: tableClasses[4] },
-  },
-];
-
 const APIResourceRows = ({ componentProps: { data } }) =>
   _.map(data, (model: K8sKind) => [
     {
@@ -162,7 +138,7 @@ const APIResourceRows = ({ componentProps: { data } }) =>
       props: { className: tableClasses[2] },
     },
     {
-      title: model.namespaced ? 'true' : 'false',
+      title: model.namespaced ? i18next.t('public~true') : i18next.t('public~false'),
       props: { className: tableClasses[3] },
     },
     {
@@ -190,7 +166,7 @@ const APIResourcesList = compose(
   const versionFilter = search.get(VERSION_PARAM) || ALL;
   const textFilter = search.get(TEXT_FILTER_PARAM) || '';
   const scopeFilter = search.get(SCOPE_PARAM) || ALL;
-
+  const { t } = useTranslation();
   // group options
   const groups: Set<string> = models.reduce((result: Set<string>, { apiGroup }) => {
     return apiGroup ? result.add(apiGroup) : result;
@@ -201,7 +177,7 @@ const APIResourcesList = compose(
       result[group] = <Group value={group} />;
       return result;
     },
-    { [ALL]: 'All Groups', '': 'No Group' },
+    { [ALL]: t('public~All groups'), '': t('public~No group') },
   );
 
   const groupSpacer = new Set<string>();
@@ -223,7 +199,7 @@ const APIResourcesList = compose(
       result[version] = version;
       return result;
     },
-    { [ALL]: 'All Versions' },
+    { [ALL]: t('public~All versions') },
   );
 
   const versionSpacer = new Set<string>();
@@ -232,9 +208,9 @@ const APIResourcesList = compose(
   }
 
   const scopeOptions = {
-    [ALL]: 'All Scopes',
-    cluster: 'Cluster',
-    namespace: 'Namespace',
+    [ALL]: t('public~All scopes'),
+    cluster: t('public~Cluster'),
+    namespace: t('public~Namespace'),
   };
   const scopeSpacer = new Set<string>(['cluster']);
 
@@ -288,6 +264,37 @@ const APIResourcesList = compose(
     }
   };
 
+  const APIResourceHeader = () => [
+    {
+      title: t('public~Kind'),
+      sortField: 'kind',
+      transforms: [sortable],
+      props: { className: tableClasses[0] },
+    },
+    {
+      title: t('public~Group'),
+      sortField: 'apiGroup',
+      transforms: [sortable],
+      props: { className: tableClasses[1] },
+    },
+    {
+      title: t('public~Version'),
+      sortField: 'apiVersion',
+      transforms: [sortable],
+      props: { className: tableClasses[2] },
+    },
+    {
+      title: t('public~Namespaced'),
+      sortField: 'namespaced',
+      transforms: [sortable],
+      props: { className: tableClasses[3] },
+    },
+    {
+      title: t('public~Description'),
+      props: { className: tableClasses[4] },
+    },
+  ];
+
   return (
     <>
       <div className="co-m-pane__filter-bar">
@@ -319,7 +326,7 @@ const APIResourcesList = compose(
           />
         </div>
         <div className="co-m-pane__filter-bar-group co-m-pane__filter-bar-group--filter">
-          <TextFilter value={textFilter} label="by kind" onChange={setTextFilter} />
+          <TextFilter value={textFilter} label={t('public~by kind')} onChange={setTextFilter} />
         </div>
       </div>
       <div className="co-m-pane__body">
@@ -327,7 +334,7 @@ const APIResourcesList = compose(
           EmptyMsg={EmptyAPIResourcesMsg}
           Header={APIResourceHeader}
           Rows={APIResourceRows}
-          aria-label="API Resources"
+          aria-label={t('public~API resources')}
           data={sortedResources}
           loaded={!!models.size}
           virtualize={false}
@@ -338,40 +345,46 @@ const APIResourcesList = compose(
 });
 APIResourcesList.displayName = 'APIResourcesList';
 
-export const APIExplorerPage: React.FC<{}> = () => (
-  <>
-    <Helmet>
-      <title>Explore API Resources</title>
-    </Helmet>
-    <div className="co-m-nav-title">
-      <h1 className="co-m-pane__heading">Explore API Resources</h1>
-    </div>
-    <APIResourcesList />
-  </>
-);
+export const APIExplorerPage: React.FC<{}> = () => {
+  const { t } = useTranslation();
+  return (
+    <>
+      <Helmet>
+        <title>{t('public~Explore API Resources')}</title>
+      </Helmet>
+      <div className="co-m-nav-title">
+        <h1 className="co-m-pane__heading">{t('public~Explore API Resources')}</h1>
+      </div>
+      <APIResourcesList />
+    </>
+  );
+};
 APIExplorerPage.displayName = 'APIExplorerPage';
 
 const APIResourceDetails: React.FC<APIResourceTabProps> = ({ customData: { kindObj } }) => {
   const { kind, apiGroup, apiVersion, namespaced, verbs, shortNames } = kindObj;
   const description = getResourceDescription(kindObj);
+  const { t } = useTranslation();
   return (
     <div className="co-m-pane__body">
       <dl className="co-m-pane__details">
-        <dt>Kind</dt>
+        <dt>{t('public~Kind')}</dt>
         <dd>{kind}</dd>
-        <dt>API Group</dt>
+        <dt>{t('public~API group')}</dt>
         <dd className="co-select-to-copy">{apiGroup || '-'}</dd>
-        <dt>API Version</dt>
+        <dt>{t('public~API version')}</dt>
         <dd>{apiVersion}</dd>
-        <dt>Namespaced</dt>
-        <dd>{namespaced ? 'true' : 'false'}</dd>
-        <dt>Verbs</dt>
+        <dt>{t('public~Namespaced')}</dt>
+        <dd>{namespaced ? t('public~true') : t('public~false')}</dd>
+        <dt>{t('public~Verbs')}</dt>
         <dd>{verbs.join(', ')}</dd>
         {shortNames && (
           <>
             <dt>
-              <Tooltip content="Short names can be used to match this resource on the CLI.">
-                <span>Short Names</span>
+              <Tooltip
+                content={t('public~Short names can be used to match this resource on the CLI.')}
+              >
+                <span>{t('public~Short names')}</span>
               </Tooltip>
             </dt>
             <dd>{shortNames.join(', ')}</dd>
@@ -379,7 +392,7 @@ const APIResourceDetails: React.FC<APIResourceTabProps> = ({ customData: { kindO
         )}
         {description && (
           <>
-            <dt>Description</dt>
+            <dt>{t('public~Description')}</dt>
             <dd className="co-break-word co-pre-wrap">
               <LinkifyExternal>{description}</LinkifyExternal>
             </dd>
@@ -402,8 +415,10 @@ const APIResourceSchema: React.FC<APIResourceTabProps> = ({ customData: { kindOb
 const APIResourceInstances: React.FC<APIResourceTabProps> = ({
   customData: { kindObj, namespace },
 }) => {
-  const componentLoader = resourceListPages.get(referenceForModel(kindObj), () =>
-    Promise.resolve(DefaultPage),
+  const resourceListPageExtensions = useExtensions<ResourceListPage>(isResourceListPage);
+  const componentLoader = getResourceListPages(resourceListPageExtensions).get(
+    referenceForModel(kindObj),
+    () => Promise.resolve(DefaultPage),
   );
   const ns = kindObj.namespaced ? namespace : undefined;
 
@@ -430,34 +445,10 @@ const Subject: React.FC<{ value: string }> = ({ value }) => {
   );
 };
 
-const AccessTableHeader = () => [
-  {
-    title: 'Subject',
-    sortField: 'name',
-    transforms: [sortable],
-  },
-  {
-    title: 'Type',
-    sortField: 'type',
-    transforms: [sortable],
-  },
-];
-
-const AccessTableRows = ({ componentProps: { data } }) =>
-  _.map(data, (subject) => [
-    {
-      title: (
-        <span className="co-break-word co-select-to-copy">
-          <Subject value={subject.name} />
-        </span>
-      ),
-    },
-    {
-      title: subject.type,
-    },
-  ]);
-
-const EmptyAccessReviewMsg: React.FC<{}> = () => <EmptyBox label="Subjects" />;
+const EmptyAccessReviewMsg: React.FC<{}> = () => {
+  const { t } = useTranslation();
+  return <EmptyBox label={t('public~Subjects')} />;
+};
 
 const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({
   customData: { kindObj, namespace },
@@ -472,6 +463,7 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({
   const [showServiceAccounts, setShowServiceAccounts] = React.useState(false);
   const [accessResponse, setAccessResponse] = React.useState<ResourceAccessReviewResponse>();
   const [error, setError] = React.useState<APIError>();
+  const { t } = useTranslation();
 
   // perform the access review
   React.useEffect(() => {
@@ -497,7 +489,7 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({
     return (
       <LoadError
         message={error.message}
-        label="Access Review"
+        label={t('public~Access review')}
         className="loading-box loading-box__errored"
       />
     );
@@ -531,6 +523,45 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({
   const selectedCount = data.length;
   const filteredData = data.filter(({ name }: { name: string }) => fuzzy(filter, name));
   const sortedData = _.orderBy(filteredData, ['type', 'name'], ['asc', 'asc']);
+  const AccessTableHeader = () => [
+    {
+      title: t('public~Subject'),
+      sortField: 'name',
+      transforms: [sortable],
+    },
+    {
+      title: t('public~Type'),
+      sortField: 'type',
+      transforms: [sortable],
+    },
+  ];
+
+  const getSubjectTypeLabel = (type: string) => {
+    switch (type) {
+      case 'User':
+        return t('public~User');
+      case 'Group':
+        return t('public~Group');
+      case 'ServiceAccount':
+        return t('public~ServiceAccount');
+      default:
+        return type;
+    }
+  };
+
+  const AccessTableRows = () =>
+    _.map(data, (subject) => [
+      {
+        title: (
+          <span className="co-break-word co-select-to-copy">
+            <Subject value={subject.name} />
+          </span>
+        ),
+      },
+      {
+        title: getSubjectTypeLabel(subject.type),
+      },
+    ]);
 
   // event handlers
   const toggleShowUsers = (e: React.MouseEvent<HTMLAnchorElement>) => {
@@ -560,11 +591,15 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({
             items={verbOptions}
             onChange={(v: K8sVerb) => setVerb(v)}
             selectedKey={verb}
-            titlePrefix="Verb"
+            titlePrefix={t('public~Verb')}
           />
         </div>
         <div className="co-m-pane__filter-bar-group co-m-pane__filter-bar-group--filter">
-          <TextFilter defaultValue={filter} label="by subject" onChange={(val) => setFilter(val)} />
+          <TextFilter
+            defaultValue={filter}
+            label={t('public~by subject')}
+            onChange={(val) => setFilter(val)}
+          />
         </div>
       </div>
       <div className="co-m-pane__body">
@@ -575,35 +610,48 @@ const APIResourceAccessReview: React.FC<APIResourceTabProps> = ({
           onSelectAll={onSelectAll}
         >
           <CheckBox
-            title="User"
+            title={t('public~User')}
             active={showUsers}
             number={users.length}
             toggle={toggleShowUsers}
           />
           <CheckBox
-            title="Group"
+            title={t('public~Group')}
             active={showGroups}
             number={groups.length}
             toggle={toggleShowGroups}
           />
           <CheckBox
-            title="ServiceAccount"
+            title={t('public~ServiceAccount')}
             active={showServiceAccounts}
             number={serviceAccounts.length}
             toggle={toggleShowServiceAccounts}
           />
         </CheckBoxControls>
         <p className="co-m-pane__explanation">
-          The following subjects can {verb} {plural}
-          {namespaced && namespace && <> in namespace {namespace}</>}
-          {namespaced && !namespace && <> in all namespaces</>}
-          {!namespaced && <> at the cluster scope</>}.
+          {namespaced &&
+            namespace &&
+            t(
+              'public~The following subjects can {{verb}} {{plural}} in namespace {{ namespace }}',
+              { verb, plural, namespace },
+            )}
+          {namespaced &&
+            !namespace &&
+            t('public~The following subjects can {{verb}} {{plural}} in all namespaces', {
+              verb,
+              plural,
+            })}
+          {!namespaced &&
+            t('public~The following subjects can {{verb}} {{plural}} at the cluster scope', {
+              verb,
+              plural,
+            })}
         </p>
         <Table
           EmptyMsg={EmptyAccessReviewMsg}
           Header={AccessTableHeader}
           Rows={AccessTableRows}
-          aria-label="API Resources"
+          aria-label={t('public~API resources')}
           data={sortedData}
           loaded
           virtualize={false}
@@ -625,6 +673,7 @@ const APIResourcePage_ = ({
   flags: FlagsObject;
 }) => {
   const namespace = kindObj?.namespaced ? match.params.ns : undefined;
+  const { t } = useTranslation();
 
   const canCreateResourceAccessReview = useAccessReview({
     group: namespace
@@ -642,18 +691,20 @@ const APIResourcePage_ = ({
       <LoadingBox />
     ) : (
       <div className="co-m-pane__body">
-        <h1 className="co-m-pane__heading co-m-pane__heading--center">404: Not Found</h1>
+        <h1 className="co-m-pane__heading co-m-pane__heading--center">
+          {t('public~404: Not found')}
+        </h1>
       </div>
     );
   }
 
   const breadcrumbs = [
     {
-      name: 'Explore',
+      name: t('public~Explore'),
       path: '/api-explorer',
     },
     {
-      name: 'Resource Details',
+      name: t('public~Resource details'),
       path: match.url,
     },
   ];
@@ -661,12 +712,12 @@ const APIResourcePage_ = ({
   const pages = [
     {
       href: '',
-      name: 'Details',
+      name: t('public~Details'),
       component: APIResourceDetails,
     },
     {
       href: 'schema',
-      name: 'Schema',
+      name: t('public~Schema'),
       component: APIResourceSchema,
     },
   ];
@@ -674,7 +725,7 @@ const APIResourcePage_ = ({
   if (_.isEmpty(kindObj.verbs) || kindObj.verbs.includes('list')) {
     pages.push({
       href: 'instances',
-      name: 'Instances',
+      name: t('public~Instances'),
       component: APIResourceInstances,
     });
   }
@@ -682,7 +733,7 @@ const APIResourcePage_ = ({
   if (flags[FLAGS.OPENSHIFT] && canCreateResourceAccessReview) {
     pages.push({
       href: 'access',
-      name: 'Access Review',
+      name: t('public~Access review'),
       component: APIResourceAccessReview,
     });
   }
