@@ -8,6 +8,8 @@ import { Route, Router, Switch } from 'react-router-dom';
 // AbortController is not supported in some older browser versions
 import 'abort-controller/polyfill';
 import store from '../redux';
+import { withTranslation } from 'react-i18next';
+
 import { detectFeatures } from '../actions/features';
 import AppContents from './app-contents';
 import { getBrandingDetails, Masthead } from './masthead';
@@ -18,10 +20,12 @@ import { history, AsyncComponent, LoadingBox } from './utils';
 import * as UIActions from '../actions/ui';
 import { fetchSwagger, getCachedResources } from '../module/k8s';
 import { receivedResources, watchAPIServices } from '../actions/k8s';
+import { initConsolePlugins } from '../plugins';
 // cloud shell imports must come later than features
 import CloudShell from '@console/app/src/components/cloud-shell/CloudShell';
 import CloudShellTab from '@console/app/src/components/cloud-shell/CloudShellTab';
 import DetectPerspective from '@console/app/src/components/detect-perspective/DetectPerspective';
+import DetectNamespace from '@console/app/src/components/detect-namespace/DetectNamespace';
 import { withExtensions, isContextProvider } from '@console/plugin-sdk';
 import { GuidedTour } from '@console/app/src/components/tour';
 
@@ -30,11 +34,12 @@ const consoleLoader = () =>
     '@console/kubevirt-plugin/src/components/connected-vm-console/vm-console-page' /* webpackChunkName: "kubevirt" */
   ).then((m) => m.VMConsolePage);
 import QuickStartDrawer from '@console/app/src/components/quick-starts/QuickStartDrawer';
+import '../i18n';
 import '../vendor.scss';
 import '../style.scss';
 
 //PF4 Imports
-import { Page } from '@patternfly/react-core';
+import { Page, SkipToContent } from '@patternfly/react-core';
 
 const breakpointMD = 768;
 const NOTIFICATION_DRAWER_BREAKPOINT = 1800;
@@ -160,6 +165,13 @@ class App_ extends React.PureComponent {
                 onPerspectiveSelected={this._onNavSelect}
               />
             }
+            skipToContent={
+              <SkipToContent
+                href={`${this.props.location.pathname}${this.props.location.search}#content`}
+              >
+                Skip to Content
+              </SkipToContent>
+            }
           >
             <ConnectedNotificationDrawer
               isDesktop={isDrawerInline}
@@ -168,33 +180,39 @@ class App_ extends React.PureComponent {
               <AppContents />
             </ConnectedNotificationDrawer>
           </Page>
-          <div id="modal-container" />
           <CloudShell />
           <GuidedTour />
           <ConsoleNotifier location="BannerBottom" />
         </QuickStartDrawer>
+        <div id="modal-container" role="dialog" aria-modal="true" />
       </>
     );
 
     return (
       <DetectPerspective>
-        {contextProviderExtensions.reduce(
-          (children, e) => (
-            <EnhancedProvider key={e.uid} {...e.properties}>
-              {children}
-            </EnhancedProvider>
-          ),
-          content,
-        )}
+        <DetectNamespace>
+          {contextProviderExtensions.reduce(
+            (children, e) => (
+              <EnhancedProvider key={e.uid} {...e.properties}>
+                {children}
+              </EnhancedProvider>
+            ),
+            content,
+          )}
+        </DetectNamespace>
       </DetectPerspective>
     );
   }
 }
 
+initConsolePlugins(store);
+
 const App = withExtensions({ contextProviderExtensions: isContextProvider })(App_);
 
 render(<LoadingBox />, document.getElementById('app'));
 
+const AppWithTranslation = withTranslation()(App);
+
 graphQLReady.onReady(() => {
   const startDiscovery = () => store.dispatch(watchAPIServices());
 
@@ -214,20 +232,25 @@ graphQLReady.onReady(() => {
   // Global timer to ensure all <Timestamp> components update in sync
   setInterval(() => store.dispatch(UIActions.updateTimestamps(Date.now())), 10000);
 
-  // Fetch swagger on load if it's stale.
+  // Fetch swagger definitions immediately upon application start
   fetchSwagger();
+  // then poll swagger definitions every 5 minutes to ensure they stay up to date
+  setInterval(fetchSwagger, 5 * 60 * 1000);
 
   // Used by GUI tests to check for unhandled exceptions
   window.windowError = null;
   window.onerror = (message, source, lineno, colno, error) => {
+    const { stack } = error;
+    const formattedStack = stack?.replace(/\\n/g, '\n');
+    window.windowError = `unhandled error: ${message} ${formattedStack || ''}`;
     // eslint-disable-next-line no-console
-    console.error('Uncaught error', error);
-    window.windowError = error;
+    console.error(window.windowError);
   };
   window.onunhandledrejection = (promiseRejectionEvent) => {
+    const { reason } = promiseRejectionEvent;
+    window.windowError = `unhandled promise rejection: ${reason}`;
     // eslint-disable-next-line no-console
-    console.error('Unhandled promise rejection', promiseRejectionEvent);
-    window.windowError = promiseRejectionEvent;
+    console.error(window.windowError);
   };
 
   if ('serviceWorker' in navigator) {
@@ -259,20 +282,22 @@ graphQLReady.onReady(() => {
   }
 
   render(
-    <Provider store={store}>
-      <Router history={history} basename={window.SERVER_FLAGS.basePath}>
-        <Switch>
-          <Route
-            path="/k8s/ns/:ns/virtualmachineinstances/:name/standaloneconsole"
-            render={(componentProps) => (
-              <AsyncComponent loader={consoleLoader} {...componentProps} />
-            )}
-          />
-          <Route path="/terminal" component={CloudShellTab} />
-          <Route path="/" component={App} />
-        </Switch>
-      </Router>
-    </Provider>,
+    <React.Suspense fallback={<LoadingBox />}>
+      <Provider store={store}>
+        <Router history={history} basename={window.SERVER_FLAGS.basePath}>
+          <Switch>
+            <Route
+              path="/k8s/ns/:ns/virtualmachineinstances/:name/standaloneconsole"
+              render={(componentProps) => (
+                <AsyncComponent loader={consoleLoader} {...componentProps} />
+              )}
+            />
+            <Route path="/terminal" component={CloudShellTab} />
+            <Route path="/" component={AppWithTranslation} />
+          </Switch>
+        </Router>
+      </Provider>
+    </React.Suspense>,
     document.getElementById('app'),
   );
 });
