@@ -11,13 +11,13 @@ import {
   ChartStack,
   ChartThemeColor,
   ChartThemeVariant,
-  ChartTooltip,
   ChartVoronoiContainer,
   getCustomTheme,
 } from '@patternfly/react-charts';
 import {
   Alert,
   Button,
+  Checkbox,
   EmptyState,
   EmptyStateBody,
   EmptyStateIcon,
@@ -26,8 +26,9 @@ import {
   Title,
 } from '@patternfly/react-core';
 import { ChartLineIcon } from '@patternfly/react-icons';
+import { useTranslation } from 'react-i18next';
 import { connect } from 'react-redux';
-import { APIError } from '@console/shared';
+import { VictoryPortal } from 'victory-core';
 import { withFallback } from '@console/shared/src/components/error/error-boundary';
 
 import * as UIActions from '../../actions/ui';
@@ -48,23 +49,16 @@ import {
   formatPrometheusDuration,
   parsePrometheusDuration,
   twentyFourHourTime,
-  twentyFourHourTimeWithSeconds,
 } from '../utils/datetime';
-
-// Prometheus internal labels start with "__"
-const isInternalLabel = (key: string): boolean => _.startsWith(key, '__');
-
-// External labels added by Prometheus (included in Thanos Querier responses)
-const isExternalLabel = (key: string): boolean => key === 'prometheus';
+import { PrometheusAPIError } from './types';
+import { ONE_MINUTE } from '@console/shared/src/constants/time';
 
 const spans = ['5m', '15m', '30m', '1h', '2h', '6h', '12h', '1d', '2d', '1w', '2w'];
 const dropdownItems = _.zipObject(spans, spans);
-const chartTheme = getCustomTheme(
-  ChartThemeColor.multi,
-  ChartThemeVariant.light,
-  queryBrowserTheme,
-);
-export const colors = chartTheme.line.colorScale;
+// Note: Victory incorrectly typed ThemeBaseProps.padding as number instead of PaddingProps
+// @ts-ignore
+const theme = getCustomTheme(ChartThemeColor.multi, ChartThemeVariant.light, queryBrowserTheme);
+export const colors = theme.line.colorScale;
 
 // Use exponential notation for small or very large numbers to avoid labels with too many characters
 const formatPositiveValue = (v: number): string =>
@@ -80,8 +74,10 @@ export const Error: React.FC<ErrorProps> = ({ error, title = 'An error occurred'
 const GraphEmptyState: React.FC<GraphEmptyStateProps> = ({ children, title }) => (
   <div className="query-browser__wrapper graph-empty-state">
     <EmptyState variant={EmptyStateVariant.full}>
-      <EmptyStateIcon size="sm" icon={ChartLineIcon} />
-      <Title size="sm">{title}</Title>
+      <EmptyStateIcon icon={ChartLineIcon} />
+      <Title headingLevel="h2" size="md">
+        {title}
+      </Title>
       <EmptyStateBody>{children}</EmptyStateBody>
     </EmptyState>
   </div>
@@ -92,6 +88,8 @@ const SpanControls: React.FC<SpanControlsProps> = React.memo(
     const [isValid, setIsValid] = React.useState(true);
     const [text, setText] = React.useState(formatPrometheusDuration(span));
 
+    const { t } = useTranslation();
+
     React.useEffect(() => {
       setText(formatPrometheusDuration(span));
     }, [span]);
@@ -114,7 +112,7 @@ const SpanControls: React.FC<SpanControlsProps> = React.memo(
         <TextInput
           aria-label="graph timespan"
           className="query-browser__span-text"
-          isValid={isValid}
+          validated={isValid ? 'default' : 'error'}
           onChange={(v) => setSpan(v, true)}
           type="text"
           value={text}
@@ -125,7 +123,7 @@ const SpanControls: React.FC<SpanControlsProps> = React.memo(
           items={dropdownItems}
           menuClassName="query-browser__span-dropdown-menu"
           noSelection={true}
-          onChange={(v) => setSpan(v)}
+          onChange={(v: string) => setSpan(v)}
         />
         <Button
           className="query-browser__inline-control"
@@ -133,105 +131,94 @@ const SpanControls: React.FC<SpanControlsProps> = React.memo(
           type="button"
           variant="tertiary"
         >
-          Reset Zoom
+          {t('public~Reset zoom')}
         </Button>
       </>
     );
   },
 );
 
-const tooltipStateToProps = ({ UI }: RootState, { seriesIndex }) => {
-  let remaining = seriesIndex;
-  let props = {};
-  UI.getIn(['queryBrowser', 'queries'])
-    .filter((q) => q.get('isEnabled') && q.get('query'))
-    .forEach((q) => {
-      const series = q.get('series') || [];
-      if (series.length > remaining) {
-        props = { labels: series[remaining], query: q.get('query') };
-        return false;
-      }
-      remaining -= series.length;
-    });
-  return props;
-};
+const TOOLTIP_MAX_ENTRIES = 20;
+const TOOLTIP_MAX_WIDTH = 300;
+const TOOLTIP_MAX_HEIGHT = 400;
 
-const TooltipInner_: React.FC<TooltipInnerProps> = ({
-  datumX,
-  datumY,
-  labels,
-  query,
-  seriesIndex,
-  x,
-  y,
-}) => {
-  if (!query && !labels) {
+// For performance, use this instead of PatternFly's ChartTooltip or Victory VictoryTooltip
+const Tooltip_: React.FC<TooltipProps> = ({ activePoints, center, height, style, width, x }) => {
+  const time = activePoints?.[0]?.x;
+
+  if (!_.isDate(time) || !_.isFinite(x)) {
     return null;
   }
 
-  const width = 240;
+  // Don't show the tooltip if the cursor is too far from the active points (can happen when the
+  // graph's timespan includes a range with no data)
+  if (Math.abs(x - center.x) > width / 15) {
+    return null;
+  }
 
-  // This is actually the max tooltip height
-  const height = 500;
+  // Pick tooltip width and location (left or right of the cursor) to maximize its available space
+  const tooltipMaxWidth = Math.min(width / 2 + 60, TOOLTIP_MAX_WIDTH);
+  const isOnLeft = x > (width - 40) / 2;
+
+  const allSeries = activePoints
+    .map((point, i) => ({
+      color: style[i]?.fill,
+      name: style[i]?.name,
+      total: point._y1 ?? point.y,
+      value: point.y,
+    }))
+    // For stacked graphs, this filters out data series that have no data for this timestamp
+    .filter(({ value }) => value !== null)
+    .sort((a, b) => b.total - a.total)
+    .slice(0, TOOLTIP_MAX_ENTRIES);
 
   return (
-    <foreignObject
-      className="query-browser__tooltip-svg-wrap"
-      height={height}
-      width={width}
-      x={x - width / 2}
-      y={y}
-    >
-      <div className="query-browser__tooltip-wrap">
-        <div className="query-browser__tooltip-arrow" />
-        <div className="query-browser__tooltip">
-          <div className="query-browser__tooltip-group">
-            <div
-              className="query-browser__series-btn"
-              style={{ backgroundColor: colors[seriesIndex % colors.length] }}
-            />
-            {datumX && (
-              <div className="query-browser__tooltip-time">
-                {twentyFourHourTimeWithSeconds(datumX)}
+    <>
+      <VictoryPortal>
+        <foreignObject
+          className="query-browser__tooltip-svg-wrap"
+          height={TOOLTIP_MAX_HEIGHT}
+          width={tooltipMaxWidth}
+          x={isOnLeft ? x - tooltipMaxWidth : x}
+          y={center.y - TOOLTIP_MAX_HEIGHT / 2}
+        >
+          <div
+            className={classNames('query-browser__tooltip-wrap', {
+              'query-browser__tooltip-wrap--left': isOnLeft,
+            })}
+          >
+            <div className="query-browser__tooltip-arrow" />
+            <div className="query-browser__tooltip">
+              <div className="query-browser__tooltip-group">
+                <div className="query-browser__tooltip-time">{twentyFourHourTime(time, true)}</div>
               </div>
-            )}
-          </div>
-          <div className="query-browser__tooltip-group">
-            <div className="co-nowrap co-truncate">{query}</div>
-            <div className="query-browser__tooltip-value">{formatValue(datumY)}</div>
-          </div>
-          {_.map(labels, (v, k) => (
-            <div className="co-nowrap co-truncate" key={k}>
-              <span className="query-browser__tooltip-label-key">
-                {k === '__name__' ? 'name' : k}
-              </span>{' '}
-              {v}
+              {allSeries.map((s, i) => (
+                <div className="query-browser__tooltip-group" key={i}>
+                  <div className="query-browser__series-btn" style={{ backgroundColor: s.color }} />
+                  <div className="co-nowrap co-truncate">{s.name}</div>
+                  <div className="query-browser__tooltip-value">{formatValue(s.value)}</div>
+                </div>
+              ))}
             </div>
-          ))}
-        </div>
-      </div>
-    </foreignObject>
+          </div>
+        </foreignObject>
+      </VictoryPortal>
+      <line className="query-browser__tooltip-line" x1={x} x2={x} y1="0" y2={height} />
+    </>
   );
 };
-const TooltipInner = connect(tooltipStateToProps)(TooltipInner_);
-
-const Tooltip_: React.FC<TooltipProps> = ({ datum, x, y }) =>
-  datum && _.isFinite(datum.y) && _.isFinite(x) && _.isFinite(y) ? (
-    <TooltipInner datumX={datum.x} datumY={datum.y} seriesIndex={datum._stack - 1} x={x} y={y} />
-  ) : null;
 const Tooltip = withFallback(Tooltip_);
 
-// The `center` prop is required by ChartTooltip, but is actually overridden by our custom tooltip
-const graphLabelComponent = <ChartTooltip center={{ x: 0, y: 0 }} flyoutComponent={<Tooltip />} />;
-
-// Set activateData to false to work around VictoryVoronoiContainer crash (see
-// https://github.com/FormidableLabs/victory/issues/1314)
 const graphContainer = (
+  // Set activateData to false to work around VictoryVoronoiContainer crash (see
+  // https://github.com/FormidableLabs/victory/issues/1314)
   <ChartVoronoiContainer
     activateData={false}
-    className="query-browser__graph-container"
-    labelComponent={graphLabelComponent}
-    labels={() => ''}
+    labelComponent={<Tooltip />}
+    labels={() => ' '}
+    mouseFollowTooltips={true}
+    voronoiDimension="x"
+    voronoiPadding={0}
   />
 );
 
@@ -247,16 +234,52 @@ const LegendContainer = ({ children }: { children?: React.ReactNode }) => {
   );
 };
 
+const Null = () => null;
+const nullComponent = <Null />;
+
+const formatLabels = (labels: PrometheusLabels) => {
+  const name = labels?.__name__ ?? '';
+  const otherLabels = _.omit(labels, '__name__');
+  return `${name}{${_.map(otherLabels, (v, k) => `${k}=${v}`).join(',')}}`;
+};
+
+type GraphSeries = GraphDataPoint[] | null;
+
+const getXDomain = (endTime, span): AxisDomain => [endTime - span, endTime];
+
 const Graph: React.FC<GraphProps> = React.memo(
-  ({ allSeries, disabledSeries, formatLegendLabel, isStack, span, width, xDomain }) => {
-    // Remove any disabled series
-    const data = _.flatMap(allSeries, (series, i) => {
-      return _.map(series, ([metric, values]) => {
-        return _.some(disabledSeries[i], (s) => _.isEqual(s, metric)) ? [{}] : values;
+  ({ allSeries, disabledSeries, formatLegendLabel, isStack, span, width, fixedXDomain }) => {
+    const data: GraphSeries[] = [];
+    const tooltipSeriesNames: string[] = [];
+    const legendData: { name: string }[] = [];
+    const { t } = useTranslation();
+
+    const [xDomain, setXDomain] = React.useState(fixedXDomain || getXDomain(Date.now(), span));
+
+    // Only update X-axis if the time range (fixedXDomain or span) or graph data (allSeries) change
+    React.useEffect(() => {
+      setXDomain(fixedXDomain || getXDomain(Date.now(), span));
+    }, [allSeries, span, fixedXDomain]);
+
+    const domain = { x: xDomain, y: undefined };
+
+    _.each(allSeries, (series, i) => {
+      _.each(series, ([metric, values]) => {
+        // Ignore any disabled series
+        data.push(_.some(disabledSeries[i], (s) => _.isEqual(s, metric)) ? null : values);
+        if (formatLegendLabel) {
+          const name = formatLegendLabel(metric, i);
+          legendData.push({ name });
+          tooltipSeriesNames.push(name);
+        } else {
+          tooltipSeriesNames.push(formatLabels(metric));
+        }
       });
     });
 
-    const domain = { x: xDomain || [Date.now() - span, Date.now()], y: undefined };
+    if (data.every(_.isEmpty)) {
+      return <GraphEmpty />;
+    }
 
     let yTickFormat = formatValue;
 
@@ -270,10 +293,10 @@ const Graph: React.FC<GraphProps> = React.memo(
       }
     } else {
       // Set a reasonable Y-axis range based on the min and max values in the data
-      const findMin = (series: GraphDataPoint[]) => _.minBy(series, 'y');
-      const findMax = (series: GraphDataPoint[]) => _.maxBy(series, 'y');
-      let minY = _.get(findMin(_.map(data, findMin)), 'y', 0);
-      let maxY = _.get(findMax(_.map(data, findMax)), 'y', 0);
+      const findMin = (series: GraphSeries) => _.minBy(series, 'y');
+      const findMax = (series: GraphSeries) => _.maxBy(series, 'y');
+      let minY: number = findMin(data.map(findMin))?.y ?? 0;
+      let maxY: number = findMax(data.map(findMax))?.y ?? 0;
       if (minY === 0 && maxY === 0) {
         minY = -1;
         maxY = 1;
@@ -289,9 +312,7 @@ const Graph: React.FC<GraphProps> = React.memo(
         yTickFormat = (v: number) => (v === 0 ? '0' : v.toExponential(1));
       }
     }
-
-    const xTickFormat = span < 5 * 60 * 1000 ? twentyFourHourTimeWithSeconds : twentyFourHourTime;
-
+    const xTickFormat = (d) => twentyFourHourTime(d, span < 5 * ONE_MINUTE);
     let xAxisStyle;
     if (width < 225) {
       xAxisStyle = {
@@ -304,41 +325,56 @@ const Graph: React.FC<GraphProps> = React.memo(
       };
     }
 
-    const legendData = formatLegendLabel
-      ? _.flatMap(allSeries, (series, i) =>
-          _.map(series, (s) => ({ name: formatLegendLabel(s[0], i) })),
-        )
-      : undefined;
+    const GroupComponent = isStack ? ChartStack : ChartGroup;
+    const ChartComponent = isStack ? ChartArea : ChartLine;
 
     return (
       <Chart
         containerComponent={graphContainer}
+        ariaTitle={t('public~query browser chart')}
         domain={domain}
         domainPadding={{ y: 1 }}
         height={200}
         scale={{ x: 'time', y: 'linear' }}
-        theme={chartTheme}
+        theme={theme}
         width={width}
       >
         <ChartAxis style={xAxisStyle} tickCount={5} tickFormat={xTickFormat} />
-        <ChartAxis crossAxis={false} dependentAxis tickCount={6} tickFormat={yTickFormat} />
-        {isStack ? (
-          <ChartStack>
-            {_.map(data, (values, i) => (
-              <ChartArea key={i} data={values} />
-            ))}
-          </ChartStack>
-        ) : (
-          <ChartGroup>
-            {_.map(data, (values, i) => (
-              <ChartLine key={i} data={values} />
-            ))}
-          </ChartGroup>
-        )}
-        {legendData && (
+        <ChartAxis
+          crossAxis={false}
+          dependentAxis
+          tickComponent={nullComponent}
+          tickCount={6}
+          tickFormat={yTickFormat}
+        />
+        <GroupComponent>
+          {data.map((values, i) => {
+            if (values === null) {
+              return null;
+            }
+            const color = colors[i % colors.length];
+            const style = {
+              data: { [isStack ? 'fill' : 'stroke']: color },
+              labels: { fill: color, name: tooltipSeriesNames[i] },
+            };
+            return (
+              // We need to use the `name` prop to prevent an error in VictorySharedEvents when
+              // dynamically removing and then adding back data series
+              <ChartComponent
+                data={values}
+                groupComponent={<g />}
+                key={i}
+                name={`series-${i}`}
+                style={style}
+              />
+            );
+          })}
+        </GroupComponent>
+        {!_.isEmpty(legendData) && (
           <ChartLegend
             data={legendData}
             groupComponent={<LegendContainer />}
+            gutter={30}
             itemsPerRow={4}
             orientation="vertical"
             style={{
@@ -391,7 +427,7 @@ const minSamples = 10;
 const maxSamples = 300;
 
 // Fall back to a line chart for performance if there are too many series
-const maxStacks = 20;
+const maxStacks = 50;
 
 // We don't want to refresh all the graph data for just a small adjustment in the number of samples,
 // so don't update unless the number of samples would change by at least this proportion
@@ -409,17 +445,24 @@ const minPollInterval = 10 * 1000;
 const ZoomableGraph: React.FC<ZoomableGraphProps> = ({
   allSeries,
   disabledSeries,
+  fixedXDomain,
   formatLegendLabel,
   isStack,
   onZoom,
   span,
   width,
-  xDomain,
 }) => {
   const [isZooming, setIsZooming] = React.useState(false);
   const [x1, setX1] = React.useState(0);
   const [x2, setX2] = React.useState(0);
 
+  const onKeyDown = (e: React.KeyboardEvent) => {
+    if (e.key === 'Escape') {
+      e.preventDefault();
+      setIsZooming(false);
+    }
+  };
+
   const onMouseDown = (e: React.MouseEvent) => {
     setIsZooming(true);
     const x = e.clientX - e.currentTarget.getBoundingClientRect().left;
@@ -443,7 +486,7 @@ const ZoomableGraph: React.FC<ZoomableGraphProps> = ({
     }
 
     const zoomWidth = e.currentTarget.getBoundingClientRect().width;
-    const oldFrom = _.get(xDomain, '[0]', Date.now() - span);
+    const oldFrom = _.get(fixedXDomain, '[0]', Date.now() - span);
     let from = oldFrom + (span * xMin) / zoomWidth;
     let to = oldFrom + (span * xMax) / zoomWidth;
     let newSpan = to - from;
@@ -457,7 +500,10 @@ const ZoomableGraph: React.FC<ZoomableGraphProps> = ({
     onZoom(from, to);
   };
 
-  const handlers = isZooming ? { onMouseMove, onMouseUp } : { onMouseDown };
+  // tabIndex is required to enable the onKeyDown handler
+  const handlers = isZooming
+    ? { onKeyDown, onMouseMove, onMouseUp, tabIndex: -1 }
+    : { onMouseDown };
 
   return (
     <div className="query-browser__zoom" {...handlers}>
@@ -470,11 +516,11 @@ const ZoomableGraph: React.FC<ZoomableGraphProps> = ({
       <Graph
         allSeries={allSeries}
         disabledSeries={disabledSeries}
+        fixedXDomain={fixedXDomain}
         formatLegendLabel={formatLegendLabel}
         isStack={isStack}
         span={span}
         width={width}
-        xDomain={xDomain}
       />
     </div>
   );
@@ -486,9 +532,12 @@ const Loading = () => (
   </div>
 );
 
+const getMaxSamplesForSpan = (span) => _.clamp(Math.round(span / minStep), minSamples, maxSamples);
+
 const QueryBrowser_: React.FC<QueryBrowserProps> = ({
   defaultSamples,
   defaultTimespan = parsePrometheusDuration('30m'),
+  deleteAllSeries,
   disabledSeries = [],
   filterLabels,
   formatLegendLabel,
@@ -498,8 +547,9 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
   isStack = false,
   namespace,
   patchQuery,
-  pollInterval,
   queries,
+  showStackedControl = false,
+  tickInterval,
   timespan,
 }) => {
   // For the default time span, use the first of the suggested span options that is at least as long
@@ -510,11 +560,10 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
   const [span, setSpan] = React.useState(timespan || parsePrometheusDuration(defaultSpanText));
 
   // Limit the number of samples so that the step size doesn't fall below minStep
-  const maxSamplesForSpan =
-    defaultSamples || _.clamp(Math.round(span / minStep), minSamples, maxSamples);
+  const maxSamplesForSpan = defaultSamples || getMaxSamplesForSpan(span);
 
   const [xDomain, setXDomain] = React.useState<AxisDomain>();
-  const [error, setError] = React.useState<QueryBrowserError>();
+  const [error, setError] = React.useState<PrometheusAPIError>();
   const [isDatasetTooBig, setIsDatasetTooBig] = React.useState(false);
   const [graphData, setGraphData] = React.useState(null);
   const [samples, setSamples] = React.useState(maxSamplesForSpan);
@@ -522,113 +571,129 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
 
   const [containerRef, width] = useRefWidth();
 
-  const endTime = _.get(xDomain, '[1]');
+  const endTime = xDomain?.[1];
 
   const safeFetch = useSafeFetch();
 
-  const stack = isStack && _.sumBy(graphData, 'length') <= maxStacks;
+  const [isStacked, setIsStacked] = React.useState(isStack);
+
+  const canStack = _.sumBy(graphData, 'length') <= maxStacks;
 
   // If provided, `timespan` overrides any existing span setting
   React.useEffect(() => {
     if (timespan) {
       setSpan(timespan);
+      setSamples(defaultSamples || getMaxSamplesForSpan(timespan));
     }
-  }, [timespan]);
+  }, [defaultSamples, timespan]);
 
-  // Define this once for all queries so that they have exactly the same time range and X values
-  const now = Date.now();
+  // Clear any existing series data when the namespace is changed
+  React.useEffect(() => {
+    deleteAllSeries();
+  }, [deleteAllSeries, namespace]);
 
-  const safeFetchQuery = (query: string) => {
-    if (_.isEmpty(query)) {
-      return Promise.resolve();
+  const tick = () => {
+    if (hideGraphs) {
+      return undefined;
     }
-    const url = getPrometheusURL({
-      endpoint: PrometheusEndpoint.QUERY_RANGE,
-      endTime: endTime || now,
-      namespace,
-      query,
-      samples,
-      timeout: '5s',
-      timespan: span,
-    });
-    return safeFetch(url);
-  };
 
-  const tick = () =>
-    hideGraphs
-      ? undefined
-      : Promise.all(_.map(queries, safeFetchQuery))
-          .then((responses: PrometheusResponse[]) => {
-            const newResults = _.map(responses, 'data.result');
-            const numDataPoints = _.sumBy(newResults, (r) => _.sumBy(r, 'values.length'));
+    // Define this once for all queries so that they have exactly the same time range and X values
+    const now = Date.now();
 
-            if (numDataPoints > maxDataPointsHard && samples === minSamples) {
-              setIsDatasetTooBig(true);
-              return;
-            }
-            setIsDatasetTooBig(false);
+    const allPromises = _.map(queries, (query) =>
+      _.isEmpty(query)
+        ? Promise.resolve()
+        : safeFetch(
+            getPrometheusURL({
+              endpoint: PrometheusEndpoint.QUERY_RANGE,
+              endTime: endTime || now,
+              namespace,
+              query,
+              samples,
+              timeout: '30s',
+              timespan: span,
+            }),
+          ),
+    );
 
-            const newSamples = _.clamp(
-              Math.floor((samples * maxDataPointsSoft) / numDataPoints),
-              minSamples,
-              maxSamplesForSpan,
-            );
+    return Promise.all(allPromises)
+      .then((responses: PrometheusResponse[]) => {
+        const newResults = _.map(responses, 'data.result');
+        const numDataPoints = _.sumBy(newResults, (r) => _.sumBy(r, 'values.length'));
 
-            // Change `samples` if either
-            //   - It will change by a proportion greater than `samplesLeeway`
-            //   - It will change to the upper or lower limit of its allowed range
-            if (
-              Math.abs(newSamples - samples) / samples > samplesLeeway ||
-              (newSamples !== samples &&
-                (newSamples === maxSamplesForSpan || newSamples === minSamples))
-            ) {
-              setSamples(newSamples);
-            } else {
-              const newGraphData = _.map(newResults, (result: PrometheusResult[]) => {
-                return _.map(result, ({ metric, values }) => {
-                  // If filterLabels is specified, ignore all series that don't match
-                  return filterLabels &&
-                    _.some(
-                      metric,
-                      (v, k) => filterLabels[k] !== v && !isInternalLabel(k) && !isExternalLabel(k),
-                    )
-                    ? []
-                    : [metric, formatSeriesValues(values, samples, span)];
-                });
-              });
-              setGraphData(newGraphData);
+        if (numDataPoints > maxDataPointsHard && samples === minSamples) {
+          setIsDatasetTooBig(true);
+          return;
+        }
+        setIsDatasetTooBig(false);
 
-              _.each(newResults, (r, i) =>
-                patchQuery(i, {
-                  series: r ? _.map(r, 'metric') : undefined,
-                }),
-              );
-              setUpdating(false);
-            }
-            setError(undefined);
-          })
-          .catch((err) => {
-            if (err.name !== 'AbortError') {
-              setError(err);
-              setUpdating(false);
-            }
+        const newSamples = _.clamp(
+          Math.floor((samples * maxDataPointsSoft) / numDataPoints),
+          minSamples,
+          maxSamplesForSpan,
+        );
+
+        // Change `samples` if either
+        //   - It will change by a proportion greater than `samplesLeeway`
+        //   - It will change to the upper or lower limit of its allowed range
+        if (
+          Math.abs(newSamples - samples) / samples > samplesLeeway ||
+          (newSamples !== samples &&
+            (newSamples === maxSamplesForSpan || newSamples === minSamples))
+        ) {
+          setSamples(newSamples);
+        } else {
+          const newGraphData = _.map(newResults, (result: PrometheusResult[]) => {
+            return _.map(result, ({ metric, values }) => {
+              // If filterLabels is specified, ignore all series that don't match
+              return _.some(filterLabels, (v, k) => _.has(metric, k) && metric[k] !== v)
+                ? []
+                : [metric, formatSeriesValues(values, samples, span)];
+            });
           });
+          setGraphData(newGraphData);
+
+          _.each(newResults, (r, i) =>
+            patchQuery(i, {
+              series: r ? _.map(r, 'metric') : undefined,
+            }),
+          );
+          setUpdating(false);
+        }
+        setError(undefined);
+      })
+      .catch((err) => {
+        if (err.name !== 'AbortError') {
+          setError(err);
+          setUpdating(false);
+        }
+      });
+  };
 
   // Don't poll if an end time was set (because the latest data is not displayed) or if the graph is
   // hidden. Otherwise use a polling interval relative to the graph's timespan.
-  const tickInterval =
-    pollInterval === undefined ? Math.max(span / 120, minPollInterval) : pollInterval;
-  const delay = endTime || hideGraphs ? null : tickInterval;
+  let delay;
+  if (endTime || hideGraphs || tickInterval === null) {
+    delay = null;
+  } else if (tickInterval > 0) {
+    delay = tickInterval;
+  } else {
+    delay = Math.max(span / 120, minPollInterval);
+  }
 
   const queriesKey = _.reject(queries, _.isEmpty).join();
   usePoll(tick, delay, endTime, filterLabels, namespace, queriesKey, samples, span);
 
   React.useLayoutEffect(() => setUpdating(true), [endTime, namespace, queriesKey, samples, span]);
 
-  const onSpanChange = React.useCallback((newSpan: number) => {
-    setXDomain(undefined);
-    setSpan(newSpan);
-  }, []);
+  const onSpanChange = React.useCallback(
+    (newSpan: number) => {
+      setXDomain(undefined);
+      setSpan(newSpan);
+      setSamples(defaultSamples || getMaxSamplesForSpan(newSpan));
+    },
+    [defaultSamples],
+  );
 
   const isRangeVector = _.get(error, 'json.error', '').match(
     /invalid expression type "range vector"/,
@@ -669,12 +734,16 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
   const onZoom = (from: number, to: number) => {
     setXDomain([from, to]);
     setSpan(to - from);
+    setSamples(defaultSamples || getMaxSamplesForSpan(to - from));
   };
 
+  const isGraphDataEmpty = !graphData || graphData.every((d) => d.length === 0);
+
   return (
     <div
       className={classNames('query-browser__wrapper', {
-        'graph-empty-state': _.isEmpty(graphData),
+        'graph-empty-state': isGraphDataEmpty,
+        'graph-empty-state__loaded': isGraphDataEmpty && !updating,
       })}
     >
       {hideControls ? (
@@ -685,16 +754,22 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
             <SpanControls defaultSpanText={defaultSpanText} onChange={onSpanChange} span={span} />
             {updating && <Loading />}
           </div>
-          {GraphLink && (
-            <div className="query-browser__controls--right">
-              <GraphLink />
-            </div>
-          )}
+          <div className="query-browser__controls--right">
+            {GraphLink && <GraphLink />}
+            {canStack && showStackedControl && (
+              <Checkbox
+                id="stacked"
+                isChecked={isStacked}
+                label="Stacked"
+                onChange={(v) => setIsStacked(v)}
+              />
+            )}
+          </div>
         </div>
       )}
       {error && <Error error={error} />}
-      {_.isEmpty(graphData) && !updating && <GraphEmpty />}
-      {!_.isEmpty(graphData) && (
+      {isGraphDataEmpty && !updating && <GraphEmpty />}
+      {!isGraphDataEmpty && (
         <>
           {samples < maxSamplesForSpan && !updating && (
             <Alert
@@ -704,7 +779,11 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
               variant="info"
             />
           )}
-          <div className="graph-wrapper graph-wrapper--query-browser">
+          <div
+            className={classNames('graph-wrapper graph-wrapper--query-browser', {
+              'graph-wrapper--query-browser--with-legend': !!formatLegendLabel,
+            })}
+          >
             <div ref={containerRef} style={{ width: '100%' }}>
               {width > 0 && (
                 <>
@@ -712,22 +791,22 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
                     <Graph
                       allSeries={graphData}
                       disabledSeries={disabledSeries}
+                      fixedXDomain={xDomain}
                       formatLegendLabel={formatLegendLabel}
-                      isStack={stack}
+                      isStack={canStack && isStacked}
                       span={span}
                       width={width}
-                      xDomain={xDomain}
                     />
                   ) : (
                     <ZoomableGraph
                       allSeries={graphData}
                       disabledSeries={disabledSeries}
+                      fixedXDomain={xDomain}
                       formatLegendLabel={formatLegendLabel}
-                      isStack={stack}
+                      isStack={canStack && isStacked}
                       onZoom={onZoom}
                       span={span}
                       width={width}
-                      xDomain={xDomain}
                     />
                   )}
                 </>
@@ -740,9 +819,16 @@ const QueryBrowser_: React.FC<QueryBrowserProps> = ({
   );
 };
 export const QueryBrowser = withFallback(
-  connect(({ UI }: RootState) => ({ hideGraphs: !!UI.getIn(['monitoring', 'hideGraphs']) }), {
-    patchQuery: UIActions.queryBrowserPatchQuery,
-  })(QueryBrowser_),
+  connect(
+    ({ UI }: RootState, { pollInterval }: { pollInterval?: number }) => ({
+      hideGraphs: !!UI.getIn(['monitoring', 'hideGraphs']),
+      tickInterval: pollInterval ?? UI.getIn(['queryBrowser', 'pollInterval']),
+    }),
+    {
+      deleteAllSeries: UIActions.queryBrowserDeleteAllSeries,
+      patchQuery: UIActions.queryBrowserPatchQuery,
+    },
+  )(QueryBrowser_),
 );
 
 type AxisDomain = [number, number];
@@ -752,7 +838,7 @@ type GraphDataPoint = {
   y: number;
 };
 
-type Series = [PrometheusLabels, GraphDataPoint[][]];
+type Series = [PrometheusLabels, GraphDataPoint[]];
 
 export type QueryObj = {
   disabledSeries?: PrometheusLabels[];
@@ -763,18 +849,12 @@ export type QueryObj = {
   text?: string;
 };
 
-export type FormatLegendLabel = (labels: PrometheusLabels, i: number) => string;
+export type FormatLegendLabel = (labels: PrometheusLabels, i?: number) => string;
 
 export type PatchQuery = (index: number, patch: QueryObj) => any;
 
-type QueryBrowserError = {
-  json?: {
-    error?: string;
-  };
-} & APIError;
-
 type ErrorProps = {
-  error: QueryBrowserError;
+  error: PrometheusAPIError;
   title?: string;
 };
 
@@ -786,11 +866,11 @@ type GraphEmptyStateProps = {
 type GraphProps = {
   allSeries: Series[][];
   disabledSeries?: PrometheusLabels[][];
+  fixedXDomain?: AxisDomain;
   formatLegendLabel?: FormatLegendLabel;
   isStack?: boolean;
   span: number;
   width: number;
-  xDomain?: AxisDomain;
 };
 
 type ZoomableGraphProps = GraphProps & { onZoom: (from: number, to: number) => void };
@@ -798,6 +878,7 @@ type ZoomableGraphProps = GraphProps & { onZoom: (from: number, to: number) => v
 export type QueryBrowserProps = {
   defaultSamples?: number;
   defaultTimespan?: number;
+  deleteAllSeries: () => never;
   disabledSeries?: PrometheusLabels[][];
   filterLabels?: PrometheusLabels;
   formatLegendLabel?: FormatLegendLabel;
@@ -809,6 +890,8 @@ export type QueryBrowserProps = {
   patchQuery: PatchQuery;
   pollInterval?: number;
   queries: string[];
+  showStackedControl?: boolean;
+  tickInterval: number;
   timespan?: number;
 };
 
@@ -818,20 +901,11 @@ type SpanControlsProps = {
   span: number;
 };
 
-type TooltipDatum = { _stack: number; x: Date; y: number };
-
-type TooltipInnerProps = {
-  datumX: Date;
-  datumY: number;
-  labels?: PrometheusLabels;
-  query?: string;
-  seriesIndex: number;
-  x: number;
-  y: number;
-};
-
 type TooltipProps = {
-  datum?: TooltipDatum;
+  activePoints?: { x: number; y: number; _y1?: number }[];
+  center?: { x: number; y: number };
+  height?: number;
+  style?: { fill: string; name: string };
+  width?: number;
   x?: number;
-  y?: number;
 };
