@@ -1,5 +1,6 @@
 import * as _ from 'lodash-es';
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 import { Link } from 'react-router-dom';
 import { sortable } from '@patternfly/react-table';
 import * as classNames from 'classnames';
@@ -29,35 +30,6 @@ const tableColumnClasses = [
   Kebab.columnClass,
 ];
 
-const NetworkPolicyTableHeader = () => {
-  return [
-    {
-      title: 'Name',
-      sortField: 'metadata.name',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[0] },
-    },
-    {
-      title: 'Namespace',
-      sortField: 'metadata.namespace',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[1] },
-      id: 'namespace',
-    },
-    {
-      title: 'Pod Selector',
-      sortField: 'spec.podSelector',
-      transforms: [sortable],
-      props: { className: tableColumnClasses[2] },
-    },
-    {
-      title: '',
-      props: { className: tableColumnClasses[3] },
-    },
-  ];
-};
-NetworkPolicyTableHeader.displayName = 'NetworkPolicyTableHeader';
-
 const kind = 'NetworkPolicy';
 
 const NetworkPolicyTableRow = ({ obj: np, index, key, style }) => {
@@ -97,29 +69,63 @@ const NetworkPolicyTableRow = ({ obj: np, index, key, style }) => {
   );
 };
 
-const NetworkPoliciesList = (props) => (
-  <Table
-    {...props}
-    aria-label="Network Policies"
-    Header={NetworkPolicyTableHeader}
-    Row={NetworkPolicyTableRow}
-    virtualize
-  />
-);
+const NetworkPoliciesList = (props) => {
+  const { t } = useTranslation();
+  const NetworkPolicyTableHeader = () => {
+    return [
+      {
+        title: t('network-policy~Name'),
+        sortField: 'metadata.name',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[0] },
+      },
+      {
+        title: t('network-policy~Namespace'),
+        sortField: 'metadata.namespace',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[1] },
+        id: 'namespace',
+      },
+      {
+        title: t('network-policy~Pod selector'),
+        sortField: 'spec.podSelector',
+        transforms: [sortable],
+        props: { className: tableColumnClasses[2] },
+      },
+      {
+        title: '',
+        props: { className: tableColumnClasses[3] },
+      },
+    ];
+  };
+  return (
+    <Table
+      {...props}
+      aria-label={t('network-policy~Network policies')}
+      Header={NetworkPolicyTableHeader}
+      Row={NetworkPolicyTableRow}
+      virtualize
+    />
+  );
+};
 
 export const NetworkPoliciesPage = (props) => (
   <ListPage {...props} ListComponent={NetworkPoliciesList} kind={kind} canCreate={true} />
 );
 
-const IngressHeader = () => (
-  <div className="row co-m-table-grid__head">
-    <div className="col-xs-4">Target Pods</div>
-    <div className="col-xs-5">From</div>
-    <div className="col-xs-3">To Ports</div>
-  </div>
-);
+const IngressHeader = () => {
+  const { t } = useTranslation();
+  return (
+    <div className="row co-m-table-grid__head">
+      <div className="col-xs-4">{t('network-policy~Target pods')}</div>
+      <div className="col-xs-5">{t('network-policy~From')}</div>
+      <div className="col-xs-3">{t('network-policy~To ports')}</div>
+    </div>
+  );
+};
 
 const IngressRow = ({ ingress, namespace, podSelector }) => {
+  const { t } = useTranslation();
   const podSelectors = [];
   const nsSelectors = [];
   let i = 0;
@@ -144,7 +150,7 @@ const IngressRow = ({ ingress, namespace, podSelector }) => {
     <div className="row co-resource-list__item">
       <div className="col-xs-4">
         <div>
-          <span className="text-muted">Pod Selector:</span>
+          <span className="text-muted">{t('network-policy~Pod selector')}:</span>
         </div>
         <div style={style}>
           <Selector selector={podSelector} namespace={namespace} />
@@ -154,13 +160,13 @@ const IngressRow = ({ ingress, namespace, podSelector }) => {
         <div>
           {!podSelectors.length ? null : (
             <div>
-              <span className="text-muted">Pod Selector:</span>
+              <span className="text-muted">{t('network-policy~Pod selector')}:</span>
               {podSelectors}
             </div>
           )}
           {!nsSelectors.length ? null : (
             <div style={{ paddingTop: podSelectors.length ? 10 : 0 }}>
-              <span className="text-muted">NS Selector:</span>
+              <span className="text-muted">{t('network-policy~NS selector')}:</span>
               {nsSelectors}
             </div>
           )}
@@ -178,26 +184,33 @@ const IngressRow = ({ ingress, namespace, podSelector }) => {
 };
 
 const Details_ = ({ obj: np, flags }) => {
+  const { t } = useTranslation();
   return (
     <>
       <div className="co-m-pane__body">
-        <SectionHeading text="Namespace Details" />
-        <ResourceSummary resource={np} podSelector={'spec.podSelector'} showPodSelector />
+        <SectionHeading text={t('network-policy~Network policy details')} />
+        <div className="row">
+          <div className="col-md-6">
+            <ResourceSummary resource={np} podSelector={'spec.podSelector'} showPodSelector />
+          </div>
+        </div>
       </div>
       <div className="co-m-pane__body">
-        <SectionHeading text="Ingress Rules" />
+        <SectionHeading text={t('network-policy~Ingress rules')} />
         <p className="co-m-pane__explanation">
-          Pods accept all traffic by default. They can be isolated via Network Policies which
-          specify a whitelist of ingress rules. When a Pod is selected by a Network Policy, it will
-          reject all traffic not explicitly allowed via a Network Policy. See more details in{' '}
+          {t(
+            'network-policy~Pods accept all traffic by default. They can be isolated via Network Policies which specify a whitelist of ingress rules. When a Pod is selected by a Network Policy, it will reject all traffic not explicitly allowed via a Network Policy. See more details in:',
+          )}
           <ExternalLink
             href={getNetworkPolicyDocLink(flags[FLAGS.OPENSHIFT])}
-            text="Network Policies Documentation"
+            text={t('network-policy~Network Policies documentation')}
           />
           .
         </p>
         {_.isEmpty(_.get(np, 'spec.ingress[0]', [])) ? (
-          `All traffic is allowed to Pods in ${np.metadata.namespace}.`
+          t('network-policy~All traffic is allowed to Pods in {{namespace}}', {
+            namespace: np.metadata.namespace,
+          })
         ) : (
           <div className="co-m-table-grid co-m-table-grid--bordered">
             <IngressHeader />
