@@ -1,4 +1,5 @@
 import * as React from 'react';
+import { useTranslation } from 'react-i18next';
 import * as _ from 'lodash-es';
 import { Button } from '@patternfly/react-core';
 import { PencilAltIcon } from '@patternfly/react-icons';
@@ -12,6 +13,12 @@ import { Selector } from './selector';
 import { Timestamp } from './timestamp';
 import { useAccessReview } from './rbac';
 import { K8sResourceKind, modelFor, referenceFor, Toleration } from '../../module/k8s';
+import { labelsModal } from '../modals';
+
+const editLabelsModal = (e, props) => {
+  e.preventDefault();
+  labelsModal(props);
+};
 
 export const pluralize = (
   i: number,
@@ -33,7 +40,7 @@ const getTolerationsPath = (obj: K8sResourceKind): string => {
   return obj.kind === 'Pod' ? 'spec.tolerations' : 'spec.template.spec.tolerations';
 };
 
-export const ResourceSummary: React.SFC<ResourceSummaryProps> = ({
+export const ResourceSummary: React.FC<ResourceSummaryProps> = ({
   children,
   resource,
   customPathName,
@@ -41,9 +48,11 @@ export const ResourceSummary: React.SFC<ResourceSummaryProps> = ({
   showNodeSelector = false,
   showAnnotations = true,
   showTolerations = false,
+  showLabelEditor = true,
   podSelector = 'spec.selector',
   nodeSelector = 'spec.template.spec.nodeSelector',
 }) => {
+  const { t } = useTranslation();
   const { metadata, type } = resource;
   const reference = referenceFor(resource);
   const model = modelFor(reference);
@@ -59,9 +68,13 @@ export const ResourceSummary: React.SFC<ResourceSummaryProps> = ({
 
   return (
     <dl data-test-id="resource-summary" className="co-m-pane__details">
-      <DetailsItem label="Name" obj={resource} path={customPathName || 'metadata.name'} />
+      <DetailsItem
+        label={t('details-page~Name')}
+        obj={resource}
+        path={customPathName || 'metadata.name'}
+      />
       {metadata.namespace && (
-        <DetailsItem label="Namespace" obj={resource} path="metadata.namespace">
+        <DetailsItem label={t('details-page~Namespace')} obj={resource} path="metadata.namespace">
           <ResourceLink
             kind="Namespace"
             name={metadata.namespace}
@@ -70,13 +83,21 @@ export const ResourceSummary: React.SFC<ResourceSummaryProps> = ({
           />
         </DetailsItem>
       )}
-      {type ? <dt>Type</dt> : null}
+      {type ? <dt>{t('details-page~Type')}</dt> : null}
       {type ? <dd>{type}</dd> : null}
-      <DetailsItem label="Labels" obj={resource} path="metadata.labels">
+      <DetailsItem
+        label={t('details-page~Labels')}
+        obj={resource}
+        path="metadata.labels"
+        valueClassName="details-item__value--labels"
+        onEdit={(e) => editLabelsModal(e, { resource, kind: model })}
+        canEdit={showLabelEditor && canUpdate}
+        editAsGroup
+      >
         <LabelList kind={reference} labels={metadata.labels} />
       </DetailsItem>
       {showPodSelector && (
-        <DetailsItem label="Pod Selector" obj={resource} path={podSelector}>
+        <DetailsItem label={t('details-page~Pod selector')} obj={resource} path={podSelector}>
           <Selector
             selector={_.get(resource, podSelector)}
             namespace={_.get(resource, 'metadata.namespace')}
@@ -84,12 +105,12 @@ export const ResourceSummary: React.SFC<ResourceSummaryProps> = ({
         </DetailsItem>
       )}
       {showNodeSelector && (
-        <DetailsItem label="Node Selector" obj={resource} path={nodeSelector}>
-          <Selector kind="Node" selector={_.get(resource, nodeSelector)} />
+        <DetailsItem label={t('details-page~Node selector')} obj={resource} path={nodeSelector}>
+          <Selector kind={t('details-page~Node')} selector={_.get(resource, nodeSelector)} />
         </DetailsItem>
       )}
       {showTolerations && (
-        <DetailsItem label="Tolerations" obj={resource} path={tolerationsPath}>
+        <DetailsItem label={t('details-page~Tolerations')} obj={resource} path={tolerationsPath}>
           {canUpdate ? (
             <Button
               type="button"
@@ -97,49 +118,70 @@ export const ResourceSummary: React.SFC<ResourceSummaryProps> = ({
               onClick={Kebab.factory.ModifyTolerations(model, resource).callback}
               variant="link"
             >
-              {pluralize(_.size(tolerations), 'Toleration')}
+              {t('details-page~{{count}} toleration', { count: _.size(tolerations) })}
               <PencilAltIcon className="co-icon-space-l pf-c-button-icon--plain" />
             </Button>
           ) : (
-            pluralize(_.size(tolerations), 'Toleration')
+            t('details-page~{{count}} toleration', { count: _.size(tolerations) })
           )}
         </DetailsItem>
       )}
       {showAnnotations && (
-        <DetailsItem label="Annotations" obj={resource} path="metadata.annotations">
+        <DetailsItem
+          label={t('details-page~Annotations')}
+          obj={resource}
+          path="metadata.annotations"
+        >
           {canUpdate ? (
             <Button
-              data-test-id="edit-annotations"
+              data-test="edit-annotations"
               type="button"
               isInline
               onClick={Kebab.factory.ModifyAnnotations(model, resource).callback}
               variant="link"
             >
-              {pluralize(_.size(metadata.annotations), 'Annotation')}
+              {t('details-page~{{count}} annotation', { count: _.size(metadata.annotations) })}
               <PencilAltIcon className="co-icon-space-l pf-c-button-icon--plain" />
             </Button>
           ) : (
-            pluralize(_.size(metadata.annotations), 'Annotation')
+            t('details-page~{{count}} annotation', { count: _.size(metadata.annotations) })
           )}
         </DetailsItem>
       )}
       {children}
-      <DetailsItem label="Created At" obj={resource} path="metadata.creationTimestamp">
+      <DetailsItem
+        label={t('details-page~Created at')}
+        obj={resource}
+        path="metadata.creationTimestamp"
+      >
         <Timestamp timestamp={metadata.creationTimestamp} />
       </DetailsItem>
-      <DetailsItem label="Owner" obj={resource} path="metadata.ownerReferences">
+      <DetailsItem label={t('details-page~Owner')} obj={resource} path="metadata.ownerReferences">
         <OwnerReferences resource={resource} />
       </DetailsItem>
     </dl>
   );
 };
 
-export const ResourcePodCount: React.SFC<ResourcePodCountProps> = ({ resource }) => (
-  <dl>
-    <DetailsItem label="Current Count" obj={resource} path="status.replicas" defaultValue="0" />
-    <DetailsItem label="Desired Count" obj={resource} path="spec.replicas" defaultValue="0" />
-  </dl>
-);
+export const ResourcePodCount: React.SFC<ResourcePodCountProps> = ({ resource }) => {
+  const { t } = useTranslation();
+  return (
+    <dl>
+      <DetailsItem
+        label={t('details-page~Current count')}
+        obj={resource}
+        path="status.replicas"
+        defaultValue="0"
+      />
+      <DetailsItem
+        label={t('details-page~Desired count')}
+        obj={resource}
+        path="spec.replicas"
+        defaultValue="0"
+      />
+    </dl>
+  );
+};
 
 export type ResourceSummaryProps = {
   resource: K8sResourceKind;
@@ -147,6 +189,7 @@ export type ResourceSummaryProps = {
   showNodeSelector?: boolean;
   showAnnotations?: boolean;
   showTolerations?: boolean;
+  showLabelEditor?: boolean;
   podSelector?: string;
   nodeSelector?: string;
   children?: React.ReactNode;
