@@ -3,7 +3,10 @@ import * as React from 'react';
 import * as classNames from 'classnames';
 import * as PropTypes from 'prop-types';
 import { connect } from 'react-redux';
+import { useTranslation, withTranslation } from 'react-i18next';
 import { CaretDownIcon, MinusCircleIcon, PlusCircleIcon, StarIcon } from '@patternfly/react-icons';
+import { useUserSettingsCompatibility } from '@console/shared';
+
 import { impersonateStateToProps } from '../../reducers/ui';
 import { checkAccess } from './rbac';
 import { history } from './router';
@@ -11,7 +14,7 @@ import { KebabItems } from './kebab';
 import { ResourceName } from './resource-icon';
 import { useSafetyFirst } from '../safety-first';
 
-export class DropdownMixin extends React.PureComponent {
+class DropdownMixin extends React.PureComponent {
   constructor(props) {
     super(props);
     this.listener = this._onWindowClick.bind(this);
@@ -51,6 +54,7 @@ export class DropdownMixin extends React.PureComponent {
   onClick_(selectedKey, e) {
     e.preventDefault();
     e.stopPropagation();
+    e.nativeEvent?.stopImmediatePropagation?.();
 
     const { items, actionItems, onChange, noSelection, title } = this.props;
 
@@ -101,25 +105,28 @@ export class DropdownMixin extends React.PureComponent {
   }
 }
 
-class DropDownRow extends React.PureComponent {
+class DropDownRowWithTranslation extends React.PureComponent {
   render() {
     const {
       itemKey,
       content,
       onclick,
-      onBookmark,
-      onUnBookmark,
       className,
       selected,
       hover,
+      autocompleteFilter,
+      isBookmarked,
+      onBookmark,
+      favoriteKey,
       canFavorite,
       onFavorite,
-      favoriteKey,
-      autocompleteFilter,
+      t,
     } = this.props;
-    let prefix;
 
-    if (!autocompleteFilter && !onBookmark && !onUnBookmark) {
+    let prefix;
+    const contentString = _.isString(content) ? content : '';
+
+    if (!autocompleteFilter && !onBookmark) {
       //use pf4 markup if not using the autocomplete dropdown
       return (
         <li key={itemKey}>
@@ -135,37 +142,44 @@ class DropDownRow extends React.PureComponent {
         </li>
       );
     }
-    if (onUnBookmark) {
-      prefix = (
-        <a
-          href="#"
-          className={classNames('bookmarker', { hover, focus: selected })}
-          onClick={(e) => onUnBookmark(e, itemKey)}
-        >
-          <MinusCircleIcon />
-        </a>
-      );
-    }
     if (onBookmark) {
       prefix = (
         <a
           href="#"
           className={classNames('bookmarker', { hover, focus: selected })}
-          onClick={(e) => onBookmark(e, itemKey, content)}
+          onClick={(e) => {
+            e.preventDefault();
+            e.stopPropagation();
+            onBookmark(itemKey, !isBookmarked);
+          }}
+          aria-label={
+            isBookmarked
+              ? t('dropdown~Remove bookmark {{content}}', { content: contentString })
+              : t('dropdown~Add bookmark {{content}}', { content: contentString })
+          }
         >
-          <PlusCircleIcon />
+          {isBookmarked ? <MinusCircleIcon /> : <PlusCircleIcon />}
         </a>
       );
     }
 
     let suffix;
-    if (onUnBookmark && canFavorite) {
+    if (isBookmarked && canFavorite) {
       const isFavorite = favoriteKey === itemKey;
       suffix = (
         <a
           href="#"
           className={classNames('bookmarker', { hover, focus: selected })}
-          onClick={(e) => onFavorite(e, isFavorite ? undefined : itemKey)}
+          onClick={(e) => {
+            e.preventDefault();
+            e.stopPropagation();
+            onFavorite(isFavorite ? null : itemKey);
+          }}
+          aria-label={
+            isFavorite
+              ? t('dropdown~Remove favorite {{content}}', { content: contentString })
+              : t('dropdown~Add favorite {{content}}', { content: contentString })
+          }
         >
           <StarIcon className={classNames({ favorite: isFavorite })} />
         </a>
@@ -179,6 +193,7 @@ class DropDownRow extends React.PureComponent {
           href="#"
           ref={this.link}
           id={`${itemKey}-link`}
+          data-test="dropdown-menu-item-link"
           className={classNames('pf-c-dropdown__menu-item', {
             'next-to-bookmark': !!prefix,
             hover,
@@ -194,37 +209,14 @@ class DropDownRow extends React.PureComponent {
   }
 }
 
-/** @augments {React.Component<any>} */
-export class Dropdown extends DropdownMixin {
+const DropDownRow = withTranslation()(DropDownRowWithTranslation);
+
+class Dropdown_ extends DropdownMixin {
   constructor(props) {
     super(props);
-    this.onUnBookmark = (...args) => this.onUnBookmark_(...args);
-    this.onBookmark = (...args) => this.onBookmark_(...args);
-    this.onFavorite = (...args) => this.onFavorite_(...args);
     this.onClick = (...args) => this.onClick_(...args);
 
-    let bookmarks = props.defaultBookmarks || {};
-    let favoriteKey;
-    if (props.storageKey) {
-      try {
-        const parsedBookmarks = JSON.parse(localStorage.getItem(this.bookmarkStorageKey));
-        if (_.isPlainObject(parsedBookmarks)) {
-          bookmarks = parsedBookmarks;
-        }
-        const parsedFavorite = localStorage.getItem(props.storageKey);
-        if (props.canFavorite && _.isString(parsedFavorite)) {
-          favoriteKey = parsedFavorite;
-        }
-      } catch (e) {
-        // eslint-disable-next-line no-console
-        console.warn(`could not load bookmarks for ${props.storageKey}: ${e}`);
-      }
-    }
-    this.state.favoriteKey = favoriteKey;
-    this.state.bookmarks = bookmarks;
-
-    this.state.items = Object.assign({}, bookmarks, props.items);
-
+    this.state.items = props.items;
     this.state.title = props.noSelection
       ? props.title
       : _.get(props.items, props.selectedKey, props.title);
@@ -232,7 +224,13 @@ export class Dropdown extends DropdownMixin {
     this.onKeyDown = (e) => this.onKeyDown_(e);
     this.changeTextFilter = (e) => this.applyTextFilter_(e.target.value, this.props.items);
     const { shortCut } = this.props;
+
     this.globalKeyDown = (e) => {
+      if (e.key === 'Escape' && this.state.active) {
+        this.hide(e);
+        return;
+      }
+
       const { nodeName } = e.target;
 
       if (nodeName === 'INPUT' || nodeName === 'TEXTAREA') {
@@ -253,10 +251,6 @@ export class Dropdown extends DropdownMixin {
     };
   }
 
-  get bookmarkStorageKey() {
-    return `${this.props.storageKey}-bookmarks`;
-  }
-
   componentDidMount() {
     if (this.props.shortCut) {
       window.addEventListener('keydown', this.globalKeyDown);
@@ -290,7 +284,6 @@ export class Dropdown extends DropdownMixin {
 
   applyTextFilter_(autocompleteText, items) {
     const { autocompleteFilter } = this.props;
-    items = Object.assign({}, this.state.bookmarks, items);
     if (autocompleteFilter && !_.isEmpty(autocompleteText)) {
       items = _.pickBy(items, (item, key) => autocompleteFilter(autocompleteText, item, key));
     }
@@ -299,16 +292,13 @@ export class Dropdown extends DropdownMixin {
 
   onKeyDown_(e) {
     const { key } = e;
-    if (key === 'Escape') {
-      this.hide(e);
-      return;
-    }
 
     if (key !== 'ArrowDown' && key !== 'ArrowUp' && key !== 'Enter') {
       return;
     }
 
-    const { items, keyboardHoverKey } = this.state;
+    const { keyboardHoverKey } = this.state;
+    const { items } = this.props;
 
     if (key === 'Enter') {
       if (this.state.active && items[keyboardHoverKey]) {
@@ -340,38 +330,6 @@ export class Dropdown extends DropdownMixin {
     e.stopPropagation();
   }
 
-  onFavorite_(e, favoriteKey) {
-    e.preventDefault();
-    e.stopPropagation();
-    this.setState({ favoriteKey });
-    if (favoriteKey) {
-      localStorage.setItem(this.props.storageKey, favoriteKey);
-    } else {
-      // do not set `undefined` as a value in localstorage
-      localStorage.removeItem(this.props.storageKey, favoriteKey);
-    }
-  }
-
-  onBookmark_(e, key, value) {
-    e.preventDefault();
-    e.stopPropagation();
-
-    const bookmarks = Object.assign({}, this.state.bookmarks);
-    bookmarks[key] = value;
-    this.setState({ bookmarks });
-    localStorage.setItem(this.bookmarkStorageKey, JSON.stringify(bookmarks));
-  }
-
-  onUnBookmark_(e, key) {
-    e.preventDefault();
-    e.stopPropagation();
-
-    const bookmarks = Object.assign({}, this.state.bookmarks);
-    delete bookmarks[key];
-    this.setState({ bookmarks });
-    localStorage.setItem(this.bookmarkStorageKey, JSON.stringify(bookmarks));
-  }
-
   renderActionItem() {
     const { actionItems } = this.props;
     if (actionItems) {
@@ -399,16 +357,7 @@ export class Dropdown extends DropdownMixin {
   }
 
   render() {
-    const {
-      active,
-      autocompleteText,
-      selectedKey,
-      items,
-      title,
-      bookmarks,
-      keyboardHoverKey,
-      favoriteKey,
-    } = this.state;
+    const { active, autocompleteText, selectedKey, items, title, keyboardHoverKey } = this.state;
     const {
       ariaLabel,
       autocompleteFilter,
@@ -417,13 +366,16 @@ export class Dropdown extends DropdownMixin {
       buttonClassName,
       menuClassName,
       storageKey,
-      canFavorite,
       dropDownClassName,
       titlePrefix,
       describedBy,
       disabled,
+      bookmarks,
+      onBookmark,
+      favoriteKey,
+      canFavorite,
+      onFavorite,
     } = this.props;
-
     const spacerBefore = this.props.spacerBefore || new Set();
     const headerBefore = this.props.headerBefore || {};
     const rows = [];
@@ -440,13 +392,14 @@ export class Dropdown extends DropdownMixin {
             key={key}
             itemKey={key}
             content={content}
-            onUnBookmark={this.onUnBookmark}
             onclick={this.onClick}
             selected={selected}
             hover={hover}
-            canFavorite={canFavorite}
-            onFavorite={this.onFavorite}
+            isBookmarked
+            onBookmark={onBookmark}
             favoriteKey={favoriteKey}
+            canFavorite={canFavorite}
+            onFavorite={onFavorite}
           />,
         );
         return;
@@ -472,7 +425,7 @@ export class Dropdown extends DropdownMixin {
           key={key}
           itemKey={key}
           content={content}
-          onBookmark={storageKey && this.onBookmark}
+          onBookmark={storageKey && onBookmark}
           onclick={this.onClick}
           selected={selected}
           hover={hover}
@@ -482,7 +435,6 @@ export class Dropdown extends DropdownMixin {
     };
 
     _.each(items, (v, k) => addItem(k, v));
-
     //render PF4 dropdown markup if this is not the autocomplete filter
     if (autocompleteFilter) {
       return (
@@ -495,6 +447,7 @@ export class Dropdown extends DropdownMixin {
             )}
           >
             <button
+              aria-label={ariaLabel}
               aria-haspopup="true"
               onClick={this.toggle}
               onKeyDown={this.onKeyDown}
@@ -503,6 +456,7 @@ export class Dropdown extends DropdownMixin {
               id={this.props.id}
               aria-describedby={describedBy}
               disabled={disabled}
+              data-test={this.props.dataTest}
             >
               <div className="btn-dropdown__content-wrap">
                 <span className="pf-c-dropdown__toggle-text">
@@ -573,6 +527,7 @@ export class Dropdown extends DropdownMixin {
             onKeyDown={this.onKeyDown}
             type="button"
             id={this.props.id}
+            data-test={this.props.dataTest}
             aria-describedby={describedBy}
             disabled={disabled}
           >
@@ -596,6 +551,50 @@ export class Dropdown extends DropdownMixin {
   }
 }
 
+export const Dropdown = (props) => {
+  const { userSettingsPrefix, storageKey } = props;
+
+  // Should be undefined so that we don't save undefined-xxx.
+  const favoriteUserSettingsKey = userSettingsPrefix ? `${userSettingsPrefix}.favorite` : undefined;
+  const favoriteStorageKey = storageKey ? storageKey : undefined;
+  const bookmarkUserSettingsKey = userSettingsPrefix
+    ? `${userSettingsPrefix}.bookmarks`
+    : undefined;
+  const bookmarkStorageKey = storageKey ? `${storageKey}-bookmarks` : undefined;
+
+  const [favoriteKey, setFavoriteKey] = useUserSettingsCompatibility(
+    favoriteUserSettingsKey,
+    favoriteStorageKey,
+    undefined,
+    true,
+  );
+  const [bookmarks, setBookmarks] = useUserSettingsCompatibility(
+    bookmarkUserSettingsKey,
+    bookmarkStorageKey,
+    undefined,
+    true,
+  );
+
+  const onBookmark = React.useCallback(
+    (key, active) => {
+      setBookmarks((oldBookmarks) => ({ ...oldBookmarks, [key]: active ? true : undefined }));
+    },
+    [setBookmarks],
+  );
+
+  return (
+    <Dropdown_
+      {...props}
+      bookmarks={bookmarks}
+      onBookmark={onBookmark}
+      favoriteKey={favoriteKey}
+      onFavorite={setFavoriteKey}
+    />
+  );
+};
+
+Dropdown.displayName = 'Dropdown';
+
 Dropdown.propTypes = {
   actionItems: PropTypes.arrayOf(
     PropTypes.shape({
@@ -607,7 +606,6 @@ Dropdown.propTypes = {
   autocompletePlaceholder: PropTypes.string,
   canFavorite: PropTypes.bool,
   className: PropTypes.string,
-  defaultBookmarks: PropTypes.objectOf(PropTypes.string),
   dropDownClassName: PropTypes.string,
   enableBookmarks: PropTypes.bool,
   headerBefore: PropTypes.objectOf(PropTypes.string),
@@ -615,16 +613,27 @@ Dropdown.propTypes = {
   menuClassName: PropTypes.string,
   buttonClassName: PropTypes.string,
   noSelection: PropTypes.bool,
+  userSettingsPrefix: PropTypes.string,
   storageKey: PropTypes.string,
   spacerBefore: PropTypes.instanceOf(Set),
   textFilter: PropTypes.string,
   title: PropTypes.node,
   disabled: PropTypes.bool,
+  id: PropTypes.string,
+  onChange: PropTypes.func,
+  selectedKey: PropTypes.string,
+  titlePrefix: PropTypes.string,
+  ariaLabel: PropTypes.string,
+  name: PropTypes.string,
+  autoSelect: PropTypes.bool,
+  describedBy: PropTypes.string,
+  required: PropTypes.bool,
+  dataTest: PropTypes.string,
 };
 
-class ActionsMenuDropdown extends DropdownMixin {
+class ActionsMenuDropdown_ extends DropdownMixin {
   render() {
-    const { actions, title = undefined } = this.props;
+    const { actions, title = undefined, t } = this.props;
     const onClick = (event, option) => {
       event.preventDefault();
 
@@ -649,13 +658,13 @@ class ActionsMenuDropdown extends DropdownMixin {
         <button
           type="button"
           aria-haspopup="true"
-          aria-label="Actions"
+          aria-label={t('dropdown~Actions')}
           aria-expanded={this.state.active}
           className="pf-c-dropdown__toggle"
           onClick={this.toggle}
           data-test-id="actions-menu-button"
         >
-          <span className="pf-c-dropdown__toggle-text">{title || 'Actions'}</span>
+          <span className="pf-c-dropdown__toggle-text">{title || t('dropdown~Actions')}</span>
           <CaretDownIcon className="pf-c-dropdown__toggle-icon" />
         </button>
         {this.state.active && <KebabItems options={actions} onClick={onClick} />}
@@ -664,6 +673,8 @@ class ActionsMenuDropdown extends DropdownMixin {
   }
 }
 
+const ActionsMenuDropdown = withTranslation()(ActionsMenuDropdown_);
+
 const ActionsMenu_ = ({ actions, impersonate, title = undefined }) => {
   const [isVisible, setVisible] = useSafetyFirst(false);
 
@@ -673,7 +684,6 @@ const ActionsMenu_ = ({ actions, impersonate, title = undefined }) => {
       setVisible(false);
       return;
     }
-
     const promises = actions.reduce((acc, action) => {
       if (action.accessReview) {
         acc.push(checkAccess(action.accessReview));
@@ -686,20 +696,20 @@ const ActionsMenu_ = ({ actions, impersonate, title = undefined }) => {
       setVisible(true);
       return;
     }
-
     Promise.all(promises)
       .then((results) => setVisible(_.some(results, 'status.allowed')))
       .catch(() => setVisible(true));
   }, [actions, impersonate, setVisible]);
-
   return isVisible ? <ActionsMenuDropdown actions={actions} title={title} /> : null;
 };
+
 export const ActionsMenu = connect(impersonateStateToProps)(ActionsMenu_);
 
 ActionsMenu.propTypes = {
   actions: PropTypes.arrayOf(
     PropTypes.shape({
-      label: PropTypes.node.isRequired,
+      label: PropTypes.node,
+      labelKey: PropTypes.string,
       href: PropTypes.string,
       callback: PropTypes.func,
       accessReview: PropTypes.object,
@@ -712,46 +722,45 @@ const containerLabel = (container) => (
   <ResourceName name={container ? container.name : ''} kind="Container" />
 );
 
-export class ContainerDropdown extends React.PureComponent {
-  getSpacer(container) {
+export const ContainerDropdown = (props) => {
+  const { t } = useTranslation();
+
+  const getSpacer = (container) => {
     const spacerBefore = new Set();
     return container ? spacerBefore.add(container.name) : spacerBefore;
-  }
+  };
 
-  getHeaders(container, initContainer) {
+  const getHeaders = (container, initContainer) => {
     return initContainer
       ? {
-          [container.name]: 'Containers',
-          [initContainer.name]: 'Init Containers',
+          [container.name]: t('dropdown~Containers'),
+          [initContainer.name]: t('dropdown~Init containers'),
         }
       : {};
-  }
+  };
 
-  render() {
-    const { currentKey, containers, initContainers, onChange } = this.props;
-    if (_.isEmpty(containers) && _.isEmpty(initContainers)) {
-      return null;
-    }
-    const firstInitContainer = _.find(initContainers, { order: 0 });
-    const firstContainer = _.find(containers, { order: 0 });
-    const spacerBefore = this.getSpacer(firstInitContainer);
-    const headerBefore = this.getHeaders(firstContainer, firstInitContainer);
-    const dropdownItems = _.mapValues(_.merge(containers, initContainers), containerLabel);
-    const title = _.get(dropdownItems, currentKey) || containerLabel(firstContainer);
-    return (
-      <Dropdown
-        className="btn-group"
-        menuClassName="dropdown-menu--text-wrap"
-        headerBefore={headerBefore}
-        items={dropdownItems}
-        spacerBefore={spacerBefore}
-        title={title}
-        onChange={onChange}
-        selectedKey={currentKey}
-      />
-    );
+  const { currentKey, containers, initContainers, onChange } = props;
+  if (_.isEmpty(containers) && _.isEmpty(initContainers)) {
+    return null;
   }
-}
+  const firstInitContainer = _.find(initContainers, { order: 0 });
+  const firstContainer = _.find(containers, { order: 0 });
+  const spacerBefore = getSpacer(firstInitContainer);
+  const headerBefore = getHeaders(firstContainer, firstInitContainer);
+  const dropdownItems = _.mapValues(_.merge(containers, initContainers), containerLabel);
+  const title = _.get(dropdownItems, currentKey) || containerLabel(firstContainer);
+  return (
+    <Dropdown
+      className="btn-group"
+      headerBefore={headerBefore}
+      items={dropdownItems}
+      spacerBefore={spacerBefore}
+      title={title}
+      onChange={onChange}
+      selectedKey={currentKey}
+    />
+  );
+};
 
 ContainerDropdown.propTypes = {
   containers: PropTypes.oneOfType([PropTypes.object, PropTypes.array]).isRequired,
