@@ -4,6 +4,8 @@ import * as React from 'react';
 import { useSelector, useDispatch, Dispatch } from 'react-redux';
 import { Map as ImmutableMap } from 'immutable';
 import { createSelectorCreator, defaultMemoize } from 'reselect';
+import { useDeepCompareMemoize } from '@console/shared/src/hooks/deep-compare-memoize';
+import { usePrevious } from '@console/shared/src/hooks/previous';
 import { makeQuery, makeReduxID } from './k8s-watcher';
 import * as k8sActions from '../../actions/k8s';
 import { K8sResourceCommon, K8sKind, K8sResourceKindReference, Selector } from '../../module/k8s';
@@ -62,21 +64,19 @@ const useModelsLoaded = (): boolean => {
 };
 
 export const useK8sWatchResource = <R extends K8sResourceCommon | K8sResourceCommon[]>(
-  resource: WatchK8sResource,
+  initResource: WatchK8sResource,
 ): WatchK8sResult<R> => {
+  const resource = useDeepCompareMemoize(initResource, true);
   const modelsLoaded = useModelsLoaded();
 
   const k8sModel = useSelector<RootState, K8sKind>(({ k8s }) =>
     resource ? k8s.getIn(['RESOURCES', 'models', resource.kind]) : null,
   );
 
-  const reduxID = React.useMemo(
-    () => getIDAndDispatch(resource, k8sModel),
-    //eslint-disable-next-line react-hooks/exhaustive-deps
-    [k8sModel, JSON.stringify(resource)],
-  );
+  const reduxID = React.useMemo(() => getIDAndDispatch(resource, k8sModel), [k8sModel, resource]);
 
   const dispatch = useDispatch();
+
   React.useEffect(() => {
     if (reduxID) {
       dispatch(reduxID.dispatch);
@@ -107,72 +107,74 @@ export const useK8sWatchResource = <R extends K8sResourceCommon | K8sResourceCom
     const loaded = resourceK8s.get('loaded');
     const loadError = resourceK8s.get('loadError');
     return [data, loaded, loadError];
-    //eslint-disable-next-line react-hooks/exhaustive-deps
-  }, [resourceK8s, JSON.stringify(resource), modelsLoaded, k8sModel]);
+  }, [resource, resourceK8s, modelsLoaded, k8sModel]);
 };
 
 export const useK8sWatchResources = <R extends ResourcesObject>(
-  resources: WatchK8sResources<R>,
+  initResources: WatchK8sResources<R>,
 ): WatchK8sResults<R> => {
+  const resources = useDeepCompareMemoize(initResources, true);
   const modelsLoaded = useModelsLoaded();
-  const k8sModelSelectorCreator = React.useMemo(
-    () =>
-      createSelectorCreator(
-        //specifying createSelectorCreator<ImmutableMap<string, any>> throws type error
-        defaultMemoize as any,
-        (oldModels: ImmutableMap<string, any>, newModels: ImmutableMap<string, any>) =>
-          Object.values(resources).every(({ kind }) => oldModels.get(kind) === newModels.get(kind)),
-      ),
-    //eslint-disable-next-line react-hooks/exhaustive-deps
-    [JSON.stringify(resources)],
+
+  const allK8sModels = useSelector<RootState, ImmutableMap<string, K8sKind>>((state: RootState) =>
+    state.k8s.getIn(['RESOURCES', 'models']),
   );
 
-  const k8sModelSelector = React.useMemo(
-    () =>
-      k8sModelSelectorCreator(
-        (state: RootState) => state.k8s.getIn(['RESOURCES', 'models']),
-        (models) => {
-          const requiredModels = Object.values(resources).map((r) => r.kind);
-          return models.filter((model, key) => requiredModels.includes(key));
-        },
-      ),
-    //eslint-disable-next-line react-hooks/exhaustive-deps
-    [k8sModelSelectorCreator, JSON.stringify(resources)],
-  );
+  const prevK8sModels = usePrevious(allK8sModels);
+  const prevResources = usePrevious(resources);
 
-  const k8sModels = useSelector<RootState, ImmutableMap<string, any>>(k8sModelSelector);
-  const hasAllModelsLoaded = React.useMemo(() => modelsLoaded || k8sModels.every((m) => !!m), [
-    k8sModels,
-    modelsLoaded,
-  ]);
+  const k8sModelsRef = React.useRef<ImmutableMap<string, K8sKind>>(ImmutableMap());
 
-  const reduxIDs = React.useMemo(
+  if (
+    prevResources !== resources ||
+    (prevK8sModels !== allK8sModels &&
+      Object.values(resources).some(
+        ({ kind }) => prevK8sModels?.get(kind) !== allK8sModels.get(kind),
+      ))
+  ) {
+    const requiredModels = Object.values(resources).map((r) => r.kind);
+    k8sModelsRef.current = allK8sModels.filter((model, key) => requiredModels.includes(key));
+  }
+
+  const k8sModels = k8sModelsRef.current;
+
+  const reduxIDs = React.useMemo<{
+    [key: string]: ReturnType<GetIDAndDispatch> & { noModel: boolean };
+  }>(
     () =>
-      hasAllModelsLoaded
+      modelsLoaded
         ? Object.keys(resources).reduce((ids, key) => {
-            const idAndDispatch = getIDAndDispatch(
-              resources[key],
-              k8sModels.get(resources[key].kind),
-            );
-            if (idAndDispatch) {
-              ids[key] = idAndDispatch;
+            const resourceModel = k8sModels.get(resources[key].kind);
+            if (!resourceModel) {
+              ids[key] = {
+                noModel: true,
+              };
+            } else {
+              const idAndDispatch = getIDAndDispatch(resources[key], resourceModel);
+              if (idAndDispatch) {
+                ids[key] = idAndDispatch;
+              }
             }
             return ids;
           }, {})
-        : {},
-    //eslint-disable-next-line react-hooks/exhaustive-deps
-    [JSON.stringify(resources), k8sModels, hasAllModelsLoaded],
+        : null,
+    [k8sModels, modelsLoaded, resources],
   );
 
   const dispatch = useDispatch();
   React.useEffect(() => {
-    Object.keys(reduxIDs)
-      .filter((k) => !!reduxIDs[k])
-      .forEach((k) => dispatch(reduxIDs[k].dispatch));
+    const reduxIDKeys = Object.keys(reduxIDs || {});
+    reduxIDKeys.forEach((k) => {
+      if (reduxIDs[k].dispatch) {
+        dispatch(reduxIDs[k].dispatch);
+      }
+    });
     return () => {
-      Object.keys(reduxIDs)
-        .filter((k) => !!reduxIDs[k])
-        .forEach((k) => dispatch(k8sActions.stopK8sWatch(reduxIDs[k].id)));
+      reduxIDKeys.forEach((k) => {
+        if (reduxIDs[k].dispatch) {
+          dispatch(k8sActions.stopK8sWatch(reduxIDs[k].id));
+        }
+      });
     };
   }, [dispatch, reduxIDs]);
 
@@ -182,8 +184,8 @@ export const useK8sWatchResources = <R extends ResourcesObject>(
         //specifying createSelectorCreator<ImmutableMap<string, K8sKind>> throws type error
         defaultMemoize as any,
         (oldK8s: ImmutableMap<string, K8sKind>, newK8s: ImmutableMap<string, K8sKind>) =>
-          Object.keys(reduxIDs)
-            .filter((id) => !!id)
+          Object.keys(reduxIDs || {})
+            .filter((k) => !reduxIDs[k].noModel)
             .every((k) => oldK8s.get(reduxIDs[k].id) === newK8s.get(reduxIDs[k].id)),
       ),
     [reduxIDs],
@@ -199,12 +201,17 @@ export const useK8sWatchResources = <R extends ResourcesObject>(
   );
 
   const resourceK8s = useSelector<RootState, K8sState>(resourceK8sSelector);
-  const noModels = modelsLoaded && !Object.keys(reduxIDs).length;
 
-  const results = React.useMemo<WatchK8sResults<R>>(() => {
-    if (Object.keys(reduxIDs).length) {
-      return Object.keys(resources).reduce((acc, key) => {
-        if (reduxIDs[key] && resourceK8s.has(reduxIDs[key].id)) {
+  const results = React.useMemo<WatchK8sResults<R>>(
+    () =>
+      Object.keys(resources).reduce((acc, key) => {
+        if (reduxIDs?.[key].noModel) {
+          acc[key] = {
+            data: resources[key].isList ? [] : {},
+            loaded: true,
+            loadError: new NoModelError(),
+          };
+        } else if (resourceK8s.has(reduxIDs?.[key].id)) {
           const data = getReduxData(resourceK8s.getIn([reduxIDs[key].id, 'data']), resources[key]);
           const loaded = resourceK8s.getIn([reduxIDs[key].id, 'loaded']);
           const loadError = resourceK8s.getIn([reduxIDs[key].id, 'loadError']);
@@ -212,23 +219,14 @@ export const useK8sWatchResources = <R extends ResourcesObject>(
         } else {
           acc[key] = {
             data: resources[key].isList ? [] : {},
-            loaded: true,
-            loadError: new NoModelError(),
+            loaded: false,
+            loadError: undefined,
           };
         }
         return acc;
-      }, {} as any);
-    }
-    return Object.keys(resources).reduce((acc, key) => {
-      const data = resources[key].isList ? [] : {};
-      acc[key] = noModels
-        ? { data, loaded: true, loadError: new NoModelError() }
-        : { data, loaded: false, loadError: undefined };
-      return acc;
-    }, {});
-    //eslint-disable-next-line react-hooks/exhaustive-deps
-  }, [reduxIDs, JSON.stringify(resources), resourceK8s, noModels]);
-
+      }, {} as any),
+    [resources, reduxIDs, resourceK8s],
+  );
   return results;
 };
 
