@@ -4,14 +4,15 @@ import * as _ from 'lodash-es';
 import * as classNames from 'classnames';
 import { DragSource, DropTarget } from 'react-dnd';
 import { DRAGGABLE_TYPE } from './draggable-item-types';
-import { Button } from '@patternfly/react-core';
+import { Button, Tooltip } from '@patternfly/react-core';
 import { PficonDragdropIcon, MinusCircleIcon, PlusCircleIcon } from '@patternfly/react-icons';
+import { withTranslation } from 'react-i18next';
 
 import { NameValueEditorPair, EnvFromPair, EnvType } from './index';
 import { ValueFromPair } from './value-from-pair';
 import withDragDropContext from './drag-drop-context';
 
-export const NameValueEditor = withDragDropContext(
+const NameValueEditor_ = withDragDropContext(
   class NameValueEditor extends React.Component {
     constructor(props) {
       super(props);
@@ -78,8 +79,6 @@ export const NameValueEditor = withDragDropContext(
 
     render() {
       const {
-        nameString,
-        valueString,
         addString,
         nameValuePairs,
         allowSorting,
@@ -88,11 +87,14 @@ export const NameValueEditor = withDragDropContext(
         configMaps,
         secrets,
         addConfigMapSecret,
+        toolTip,
+        t,
       } = this.props;
+      const nameString = this.props.nameString || t('environment~Key');
+      const valueString = this.props.valueString || t('environment~Value');
       const pairElems = nameValuePairs.map((pair, i) => {
         const key = _.get(pair, [NameValueEditorPair.Index], i);
         const isEmpty = nameValuePairs.length === 1 && nameValuePairs[0].every((value) => !value);
-
         return (
           <PairElement
             onChange={this._change}
@@ -110,6 +112,7 @@ export const NameValueEditor = withDragDropContext(
             secrets={secrets}
             isEmpty={isEmpty}
             disableReorder={nameValuePairs.length === 1}
+            toolTip={toolTip}
           />
         );
       });
@@ -128,7 +131,7 @@ export const NameValueEditor = withDragDropContext(
                 <div className="co-toolbar__group co-toolbar__group--left">
                   <Button
                     className="pf-m-link--align-left"
-                    data-test-id="pairs-list__add-btn"
+                    data-test="add-button"
                     onClick={this._append}
                     type="button"
                     variant="link"
@@ -137,7 +140,7 @@ export const NameValueEditor = withDragDropContext(
                       data-test-id="pairs-list__add-icon"
                       className="co-icon-space-r"
                     />
-                    {addString}
+                    {addString ? addString : t('environment~Add more')}
                   </Button>
                   {addConfigMapSecret && (
                     <>
@@ -151,7 +154,7 @@ export const NameValueEditor = withDragDropContext(
                           data-test-id="pairs-list__add-icon"
                           className="co-icon-space-r"
                         />
-                        Add from Config Map or Secret
+                        {t('environment~Add from ConfigMap or Secret')}
                       </Button>
                     </>
                   )}
@@ -164,6 +167,9 @@ export const NameValueEditor = withDragDropContext(
     }
   },
 );
+
+export const NameValueEditor = withTranslation()(NameValueEditor_);
+
 NameValueEditor.propTypes = {
   nameString: PropTypes.string,
   valueString: PropTypes.string,
@@ -184,11 +190,9 @@ NameValueEditor.propTypes = {
   configMaps: PropTypes.object,
   secrets: PropTypes.object,
   addConfigMapSecret: PropTypes.bool,
+  toolTip: PropTypes.string,
 };
 NameValueEditor.defaultProps = {
-  nameString: 'Key',
-  valueString: 'Value',
-  addString: 'Add More',
   allowSorting: false,
   readOnly: false,
   nameValueId: 0,
@@ -197,7 +201,7 @@ NameValueEditor.defaultProps = {
 
 NameValueEditor.displayName = 'Name Value Editor';
 
-export const EnvFromEditor = withDragDropContext(
+const EnvFromEditor_ = withDragDropContext(
   class EnvFromEditor extends React.Component {
     constructor(props) {
       super(props);
@@ -264,6 +268,7 @@ export const EnvFromEditor = withDragDropContext(
         secondTitle,
         addButtonDisabled,
         addButtonLabel,
+        t,
       } = this.props;
       const pairElems = nameValuePairs.map((pair, i) => {
         const key = _.get(pair, [EnvFromPair.Index], i);
@@ -272,7 +277,7 @@ export const EnvFromEditor = withDragDropContext(
           <EnvFromPairElement
             onChange={this._change}
             index={i}
-            nameString="config map/secret"
+            nameString={t('environment~ConfigMap/Secret')}
             valueString=""
             readOnly={readOnly}
             pair={pair}
@@ -291,8 +296,12 @@ export const EnvFromEditor = withDragDropContext(
         <>
           <div className="row pairs-list__heading">
             {!readOnly && <div className="col-xs-1 co-empty__header" />}
-            <div className="col-xs-5 text-secondary text-uppercase">{firstTitle}</div>
-            <div className="col-xs-5 text-secondary text-uppercase">{secondTitle}</div>
+            <div className="col-xs-5 text-secondary text-uppercase">
+              {firstTitle || t('environment~ConfigMap/Secret')}
+            </div>
+            <div className="col-xs-5 text-secondary text-uppercase">
+              {secondTitle || t('environment~Prefix (optional)')}
+            </div>
             <div className="col-xs-1 co-empty__header" />
           </div>
           {pairElems}
@@ -306,7 +315,8 @@ export const EnvFromEditor = withDragDropContext(
                   variant="link"
                   isDisabled={addButtonDisabled}
                 >
-                  <PlusCircleIcon /> {addButtonLabel}
+                  <PlusCircleIcon />{' '}
+                  {addButtonLabel || t('environment~Add all from ConfigMap or Secret')}
                 </Button>
               )}
             </div>
@@ -316,6 +326,7 @@ export const EnvFromEditor = withDragDropContext(
     }
   },
 );
+export const EnvFromEditor = withTranslation()(EnvFromEditor_);
 EnvFromEditor.propTypes = {
   readOnly: PropTypes.bool,
   nameValueId: PropTypes.number,
@@ -339,12 +350,8 @@ EnvFromEditor.propTypes = {
 EnvFromEditor.defaultProps = {
   readOnly: false,
   nameValueId: 0,
-  firstTitle: 'Config map/secret',
-  secondTitle: 'Prefix (Optional)',
   addButtonDisabled: false,
-  addButtonLabel: 'Add All From Config Map or Secret',
 };
-
 const pairSource = {
   beginDrag(props) {
     return {
@@ -353,20 +360,16 @@ const pairSource = {
     };
   },
 };
-
 const itemTarget = {
   hover(props, monitor, component) {
     const dragIndex = monitor.getItem().index;
     const hoverIndex = props.index;
-
     // Don't replace items with themselves or with other row groupings on the page
     if (dragIndex === hoverIndex || monitor.getItem().rowSourceId !== props.rowSourceId) {
       return;
     }
-
     // Determine rectangle on screen
     const hoverBoundingRect = component.node.getBoundingClientRect();
-
     // Get vertical middle
     const hoverMiddleY = (hoverBoundingRect.bottom - hoverBoundingRect.top) / 2;
 
@@ -411,7 +414,7 @@ const collectTargetPair = (connect) => ({
   connectDropTarget: connect.dropTarget(),
 });
 
-const PairElement = DragSource(
+const PairElement_ = DragSource(
   DRAGGABLE_TYPE.ENV_ROW,
   pairSource,
   collectSourcePair,
@@ -452,7 +455,6 @@ const PairElement = DragSource(
           connectDragPreview,
           connectDropTarget,
           nameString,
-          valueString,
           allowSorting,
           readOnly,
           pair,
@@ -460,11 +462,14 @@ const PairElement = DragSource(
           secrets,
           isEmpty,
           disableReorder,
+          toolTip,
+          t,
+          valueString,
         } = this.props;
         const deleteIcon = (
           <>
             <MinusCircleIcon className="pairs-list__side-btn pairs-list__delete-icon" />
-            <span className="sr-only">Delete</span>
+            <span className="sr-only">{t('environment~Delete')}</span>
           </>
         );
         const dragButton = (
@@ -475,12 +480,12 @@ const PairElement = DragSource(
               tabIndex="-1"
               isDisabled={disableReorder}
               variant="plain"
+              aria-label={t('environment~Drag to reorder')}
             >
               <PficonDragdropIcon className="pairs-list__action-icon--reorder" />
             </Button>
           </div>
         );
-
         return connectDropTarget(
           connectDragPreview(
             <div
@@ -488,6 +493,7 @@ const PairElement = DragSource(
                 'row',
                 isDragging ? 'pairs-list__row-dragging' : 'pairs-list__row',
               )}
+              data-test="pairs-list-row"
               ref={(node) => (this.node = node)}
             >
               {allowSorting && !readOnly && (
@@ -498,8 +504,9 @@ const PairElement = DragSource(
               <div className="col-xs-5 pairs-list__name-field">
                 <input
                   type="text"
+                  data-test="pairs-list-name"
                   className="pf-c-form-control"
-                  placeholder={nameString.toLowerCase()}
+                  placeholder={nameString}
                   value={pair[NameValueEditorPair.Name]}
                   onChange={this._onChangeName}
                   disabled={readOnly}
@@ -508,6 +515,7 @@ const PairElement = DragSource(
               {_.isPlainObject(pair[NameValueEditorPair.Value]) ? (
                 <div className="col-xs-5 pairs-list__value-pair-field">
                   <ValueFromPair
+                    data-test="pairs-list-value"
                     pair={pair[NameValueEditorPair.Value]}
                     configMaps={configMaps}
                     secrets={secrets}
@@ -519,8 +527,9 @@ const PairElement = DragSource(
                 <div className="col-xs-5 pairs-list__value-field">
                   <input
                     type="text"
+                    data-test="pairs-list-value"
                     className="pf-c-form-control"
-                    placeholder={valueString.toLowerCase()}
+                    placeholder={valueString}
                     value={pair[NameValueEditorPair.Value] || ''}
                     onChange={this._onChangeValue}
                     disabled={readOnly}
@@ -529,18 +538,20 @@ const PairElement = DragSource(
               )}
               {!readOnly && (
                 <div className="col-xs-1 pairs-list__action">
-                  <Button
-                    type="button"
-                    data-test-id="pairs-list__delete-btn"
-                    className={classNames({
-                      'pairs-list__span-btns': allowSorting,
-                    })}
-                    onClick={this._onRemove}
-                    isDisabled={isEmpty}
-                    variant="plain"
-                  >
-                    {deleteIcon}
-                  </Button>
+                  <Tooltip content={toolTip || t('environment~Remove')}>
+                    <Button
+                      type="button"
+                      data-test="delete-button"
+                      className={classNames({
+                        'pairs-list__span-btns': allowSorting,
+                      })}
+                      onClick={this._onRemove}
+                      isDisabled={isEmpty}
+                      variant="plain"
+                    >
+                      {deleteIcon}
+                    </Button>
+                  </Tooltip>
                 </div>
               )}
             </div>,
@@ -550,6 +561,7 @@ const PairElement = DragSource(
     },
   ),
 );
+const PairElement = withTranslation()(PairElement_);
 PairElement.propTypes = {
   nameString: PropTypes.string,
   valueString: PropTypes.string,
@@ -569,9 +581,9 @@ PairElement.propTypes = {
   rowSourceId: PropTypes.number.isRequired,
   configMaps: PropTypes.object,
   secrets: PropTypes.object,
+  toolTip: PropTypes.string,
 };
-
-const EnvFromPairElement = DragSource(
+const EnvFromPairElement_ = DragSource(
   DRAGGABLE_TYPE.ENV_FROM_ROW,
   pairSource,
   collectSourcePair,
@@ -584,27 +596,22 @@ const EnvFromPairElement = DragSource(
     class EnvFromPairElement extends React.Component {
       constructor(props) {
         super(props);
-
         this._onRemove = this._onRemove.bind(this);
         this._onChangePrefix = this._onChangePrefix.bind(this);
         this._onChangeResource = this._onChangeResource.bind(this);
       }
-
       _onRemove() {
         const { index, onRemove } = this.props;
         onRemove(index);
       }
-
       _onChangePrefix(e) {
         const { index, onChange } = this.props;
         onChange(e, index, EnvFromPair.Prefix);
       }
-
       _onChangeResource(e) {
         const { index, onChange } = this.props;
         onChange(e, index, EnvFromPair.Resource);
       }
-
       render() {
         const {
           isDragging,
@@ -617,14 +624,14 @@ const EnvFromPairElement = DragSource(
           configMaps,
           secrets,
           serviceAccounts,
+          t,
         } = this.props;
         const deleteButton = (
           <>
             <MinusCircleIcon className="pairs-list__side-btn pairs-list__delete-icon" />
-            <span className="sr-only">Delete</span>
+            <span className="sr-only">{t('environment~Delete')}</span>
           </>
         );
-
         return connectDropTarget(
           connectDragPreview(
             <div
@@ -642,6 +649,7 @@ const EnvFromPairElement = DragSource(
                       className="pairs-list__action-icon"
                       tabIndex="-1"
                       variant="plain"
+                      aria-label={t('environment~Drag to reorder')}
                     >
                       <PficonDragdropIcon className="pairs-list__action-icon--reorder" />
                     </Button>
@@ -662,7 +670,7 @@ const EnvFromPairElement = DragSource(
                   data-test-id="env-prefix"
                   type="text"
                   className="pf-c-form-control"
-                  placeholder={valueString.toLowerCase()}
+                  placeholder={valueString}
                   value={pair[EnvFromPair.Prefix]}
                   onChange={this._onChangePrefix}
                   disabled={readOnly}
@@ -670,15 +678,17 @@ const EnvFromPairElement = DragSource(
               </div>
               {readOnly ? null : (
                 <div className="col-xs-1 pairs-list__action">
-                  <Button
-                    type="button"
-                    data-test-id="pairs-list__delete-from-btn"
-                    className="pairs-list__span-btns"
-                    onClick={this._onRemove}
-                    variant="plain"
-                  >
-                    {deleteButton}
-                  </Button>
+                  <Tooltip content={t('environment~Remove')}>
+                    <Button
+                      type="button"
+                      data-test-id="pairs-list__delete-from-btn"
+                      className="pairs-list__span-btns"
+                      onClick={this._onRemove}
+                      variant="plain"
+                    >
+                      {deleteButton}
+                    </Button>
+                  </Tooltip>
                 </div>
               )}
             </div>,
@@ -688,6 +698,7 @@ const EnvFromPairElement = DragSource(
     },
   ),
 );
+const EnvFromPairElement = withTranslation()(EnvFromPairElement_);
 EnvFromPairElement.propTypes = {
   valueString: PropTypes.string,
   readOnly: PropTypes.bool,
