@@ -15,6 +15,7 @@ type Config struct {
 	Providers      `yaml:"providers"`
 	Helm           `yaml:"helm"`
 	MonitoringInfo `yaml:"monitoringInfo,omitempty"`
+	Plugins        map[string]string `yaml:"plugins,omitempty"`
 }
 
 // ServingInfo holds configuration for serving HTTP.
@@ -52,10 +53,11 @@ type ClusterInfo struct {
 
 // Auth holds configuration for authenticating with OpenShift. The auth method is assumed to be "openshift".
 type Auth struct {
-	ClientID            string `yaml:"clientID,omitempty"`
-	ClientSecretFile    string `yaml:"clientSecretFile,omitempty"`
-	OAuthEndpointCAFile string `yaml:"oauthEndpointCAFile,omitempty"`
-	LogoutRedirect      string `yaml:"logoutRedirect,omitempty"`
+	ClientID                 string `yaml:"clientID,omitempty"`
+	ClientSecretFile         string `yaml:"clientSecretFile,omitempty"`
+	OAuthEndpointCAFile      string `yaml:"oauthEndpointCAFile,omitempty"`
+	LogoutRedirect           string `yaml:"logoutRedirect,omitempty"`
+	InactivityTimeoutSeconds int    `yaml:"inactivityTimeoutSeconds,omitempty"`
 }
 
 // Customization holds configuration such as what logo to use.
@@ -64,6 +66,34 @@ type Customization struct {
 	DocumentationBaseURL string `yaml:"documentationBaseURL,omitempty"`
 	CustomProductName    string `yaml:"customProductName,omitempty"`
 	CustomLogoFile       string `yaml:"customLogoFile,omitempty"`
+	// developerCatalog allows to configure the shown developer catalog categories.
+	DeveloperCatalog DeveloperConsoleCatalogCustomization `yaml:"developerCatalog,omitempty"`
+}
+
+// DeveloperConsoleCatalogCustomization allow cluster admin to configure developer catalog.
+type DeveloperConsoleCatalogCustomization struct {
+	// categories which are shown the in developer catalog.
+	Categories []DeveloperConsoleCatalogCategory `json:"categories,omitempty" yaml:"categories,omitempty"`
+}
+
+// DeveloperConsoleCatalogCategoryMeta are the key identifiers of a developer catalog category.
+type DeveloperConsoleCatalogCategoryMeta struct {
+	// ID is an identifier used in the URL to enable deep linking in console.
+	// ID is required and must have 1-32 URL safe (A-Z, a-z, 0-9, - and _) characters.
+	ID string `json:"id" yaml:"id"`
+	// label defines a category display label. It is required and must have 1-64 characters.
+	Label string `json:"label" yaml:"label"`
+	// tags is a list of strings that will match the category. A selected category
+	// show all items which has at least one overlapping tag between category and item.
+	Tags []string `json:"tags,omitempty" yaml:"tags,omitempty"`
+}
+
+// DeveloperConsoleCatalogCategory for the developer console catalog.
+type DeveloperConsoleCatalogCategory struct {
+	// defines top level category ID, label and filter tags.
+	DeveloperConsoleCatalogCategoryMeta `json:",inline" yaml:",inline"`
+	// subcategories defines a list of child categories.
+	Subcategories []DeveloperConsoleCatalogCategoryMeta `json:"subcategories,omitempty" yaml:"subcategories,omitempty"`
 }
 
 type Providers struct {
